*1965 Party ID
*set directory
cd "M:\Kollman Party Project IFS\Canada"
use "1965\CES 1965 Stata.dta"

***************************************************************************
* Step 1: Condensing the dataset, variable description
***************************************************************************
keep v2 v221 v227 v222 v143 v156 v169 v182 v309 v5 v327 v311 v7 v4
numlabel, add 

*v2 = participant id
*v221 = party id
*v227 = party closer
*v222 = strength
*v143 = ideal candidate placement, proxy for self-placement, general
*v156 = Liberal placement, general
*v169 = Conservative placement, general
*v182 = NDP placement, general
*v309 = religion
*v5 = region
*v327 = union
*v311 = ethnicity
*v7 = type(urban/rural)
*v4 = weight


***************************************************************************
* Step 2: Creating year variable
***************************************************************************
gen year=1965


***************************************************************************
* Step 3: Creating party id variables
***************************************************************************
gen partyid=v221
recode partyid (10=2) (20=1) (30=3) (40=4) (50=5)(60=6) (70=7) (80=8)

gen Liberal=.
replace Liberal=1 if partyid==1
gen Conservative=. 
replace Conservative=1 if partyid==2
gen NDP=.
replace NDP=1 if partyid==3
gen SocialCredit=.
replace SocialCredit=1 if partyid==4
gen Creditiste=.
replace Creditiste=1 if partyid==5
gen UnionNationale=.
replace UnionNationale=1 if partyid==6
gen Other=.
replace Other=1 if partyid==7
gen None=.
replace None=1 if partyid==8

gen ClsrLiberal=.
replace ClsrLib=1 if v227==20
gen ClsrConservative=.
replace ClsrCons=1 if v227==10
gen ClsrNDP=.
replace ClsrNDP=1 if v227==30
gen ClsrSocialCredit=.
replace ClsrSoc=1 if v227==40
gen ClsrOther=.
replace ClsrO=1 if v227==80
gen ClsrNone=.
replace ClsrNone=1 if v227==0

gen countv=partyid
recode countv (1/8=1)

***************************************************************************************
* Step 4: Creating Partisan variables (ID or clsr) for Cons, Liberal, NDP, and others
***************************************************************************************
gen ConPart=.
replace ConPart=1 if  Conservative==1 & v222!=.
label var ConPart "identifies/leans to Conservative"
label define L2 1 "Conservative partisan"
label values ConPart L2

gen LibPart=.
replace LibPart=1 if  Liberal==1 & v222!=.
label var LibPart "identifies/leans to the Liberals"
label define L3 1 "Liberal partisan"
label values LibPart L3

gen NDPPart=.
replace NDPPart=1 if  NDP==1 & v222!=.
label var NDPPart "identifies/leans to NDP"
label define L24 1 "NDP partisan"
label values NDPPart L24

gen SocCredPart=.
replace SocCredPart=1 if SocialCredit==1 & v222!=.
label var SocCredPart "identifies/leans to Social Credit"
label define so2c 1 "Social Credit partisan"
label values SocCredPart soc2c

gen CredistePart=.
replace CredistePart=1 if Creditiste==1 & v222!=.
label var CredistePart "identifies/leans to Creditiste"
label define so4c 1 "Crediste partisan"
label values CredistePart soc4c

gen UnionNatPart=.
replace UnionNatPart=1 if UnionNationale==1 & v222!=.
label var UnionNatPart "identifies/leans to Union Nationale"
label define so6c 1 "Union Nationale partisan"
label values UnionNatPart soc6c

gen OtherPart=.
replace OtherPart=1 if  Other==1 & v222!=.
label var OtherPart "identifies/leans to other"
label define L27 1 "other partisan"
label values OtherPart L27
tab OtherPart

gen AllOthersPart=0
replace AllOthersPart=1 if (SocialCredit==1  | Creditiste==1 | UnionNationale==1 | Other==1) & v222!=.
label var AllOthersPart "identifies/leans to another party"
label define L4 1 "all other partisans"
label values AllOthersPart L4
tab AllOthersPart


***************************************************************************
* Step 5: Recoding ID strength
***************************************************************************
tab v222
*to see how strength is coded

gen idstr=v222
recode idstr (1=3) (3=1)
label define idstr2 1 "not very strongly" 2 "fairly strongly" 3 "very strongly" 
label values idstr idstr2
tab v222 idstr
*this is a check to see that the recoding is correct


****************************************************************************
*Step 6: Creating subgroup variables
****************************************************************************
*religion
tab v309, m
gen religion=v309
recode religion (0=4) (10/19=2) (20=1) (70=1) (30=3) (71=2) (79=3)
*70 is Ukranian Catholic
label define rel1 1 "Catholic" 2 "Other Christian" 3 "Non-Christian" 4 "Non-Religious"
label values religion rel1
label var religion "religion"

*region
tab v5
gen region=v5
recode region (0/3=1) (4=2) (5=3) (6/9=4)
label var region "region"
label define reg1 1 "Maritimes" 2 "Quebec" 3 "Ontario" 4 "Western Canada"
label values region reg1
label var region "region"

*union
tab v327
gen union=v327
recode union (5=2)
label define label 1 "union" 2 "not union"
label values union label
label var union "union"

*ethnicity
tab v311
gen ethnicity=v311
recode ethnicity (300/390=1) (200=2) (590=2) (999=2)
label define etn 1 "European descent" 2 "Non-European descent"
label values ethnicity etn
label var ethnicity "ethnicity"

*partisan
gen partisan=.
replace partisan=1 if LibPart==1
replace partisan=2 if ConPart==1
replace partisan=3 if NDPPart==1
replace partisan=4 if AllOthersPart==1
label define labelp 1 "Liberal Partisan" 2 "Conservative Partisan" 3 "NDP Partisan" 4 "Other-Party Partisan"
label values partisan labelp
label var partisan "partisan"

*type (urban/rural)
gen type=.
replace type=1 if v7==1 | v7==2 | v7==11 | v7==12
replace type=2 if v7==21 | v7==22 | v7==31 | v7==40 | v7==50 | v7==60 | v7==70 
label define labtyp 1 "urban" 2 "not urban"
label values type labtyp
label var type "type"

*RegionXReligion
gen regxrel=.
replace regxrel=1 if region==2 & religion==1 //Quebec & Catholic
replace regxrel=2 if region==2 & religion==2 //Quebec & non-Cath Christ.
replace regxrel=3 if (region==1 | region==3 | region==4) & religion==1 //non-Queb & Catholic
replace regxrel=4 if (region==1 | region==3 | region==4) & religion==2 //non-Queb & non-Cath Christ.

label define pop 1 "Quebec & Catholic" 2 "Quebec & non-Cath Christ"  /*
*/ 3 "non-Quebec & Catholic" 4 "non-Quebec & non-Cath Christ"
label values regxrel pop

*RegionXUnion
gen regxun=.
replace regxun=1 if region==2 & union==1 //Queb & union
replace regxun=2 if region==2 & union==2 //Queb & non-union
replace regxun=3 if (region==1 | region==3 | region==4) & union==1 //non-Q & union
replace regxun=4 if (region==1 | region==3 | region==4) & union==2 //non-Q & non-union

label define ypy 1 "Quebec & union" 2 "Quebec & non-union" /*
*/ 3 "non-Quebec & union" 4 "non-Quebec & non-union"
label values regxun ypy


****************************************************************************
* Step 7: Save, Collapse, Save
****************************************************************************
save "AUGUST\1965\1965 edited id.dta"
collapse year (count) observ=countv (sum) Liberal Conservative NDP SocialCredit Creditiste UnionNationale Other None Clsr* [pweight=v4]
save "AUGUST\1965\1965 total id.dta"
clear






***********************************************************************
*1965 Party ID, religion
*set directory
cd "M:\Kollman Party Project IFS\Canada"
use "AUGUST\1965\1965 edited id.dta"

count if religion==.
drop if religion==.

sort religion
quietly: by religion: sum idstr

collapse year (count)observ=countv (sum) Liberal Conservative NDP SocialCredit Creditiste UnionNationale Other None Clsr* [pweight=v4], by(religion)
gen sub_n="religion"

decode religion, gen(group)
replace group="_1cath" in 1
replace group="_2chr" in 2
replace group="_3other" in 3
replace group="_4nrel" in 4

order year sub_n religion group

drop religion
quietly: reshape wide observ Liberal Conservative NDP SocialCredit Creditiste UnionNationale Other None Clsr*, i(year sub_n) j(group) string
save "AUGUST\1965\1965 religion id.dta"
clear



***********************************************************************
*1965 Party ID, region
*set directory
cd "M:\Kollman Party Project IFS\Canada"
use "AUGUST\1965\1965 edited id.dta"

count if region==.
drop if region==.

sort region
quietly: by region: sum idstr

collapse year (count)observ=countv (sum) Liberal Conservative NDP SocialCredit Creditiste UnionNationale Other None Clsr* [pweight=v4], by(region)
gen sub_n="region"

decode region, gen(group)
replace group="_1Marit" in 1
replace group="_2Queb" in 2
replace group="_3Ontar" in 3
replace group="_4West" in 4

order year sub_n region group

drop region
quietly: reshape wide observ Liberal Conservative NDP SocialCredit Creditiste UnionNationale Other None Clsr*, i(year sub_n) j(group) string
save "AUGUST\1965\1965 region id.dta"
clear



***********************************************************************
*1965 Party ID, union
*set directory
cd "M:\Kollman Party Project IFS\Canada"
use "AUGUST\1965\1965 edited id.dta"

count if union==.
drop if union==.

sort union
quietly: by union: sum idstr

collapse year (count)observ=countv (sum) Liberal Conservative NDP SocialCredit Creditiste UnionNationale Other None Clsr* [pweight=v4], by(union)
gen sub_n="union"

decode union, gen(group)
replace group="_1union" in 1
replace group="_2nunion" in 2

order year sub_n union group

drop union
quietly: reshape wide observ Liberal Conservative NDP SocialCredit Creditiste UnionNationale Other None Clsr*, i(year sub_n) j(group) string
save "AUGUST\1965\1965 union id.dta"
clear



***********************************************************************
*1965 Party ID, ethnicity
*set directory
cd "M:\Kollman Party Project IFS\Canada"
use "AUGUST\1965\1965 edited id.dta"

count if ethnicity==.
drop if ethnicity==.

sort ethnicity
quietly: by ethnicity: sum idstr

collapse year (count)observ=countv (sum) Liberal Conservative NDP SocialCredit Creditiste UnionNationale Other None Clsr* [pweight=v4], by(ethnicity)
gen sub_n="ethnicity"

decode ethnicity, gen(group)
replace group="_1Euro" in 1
replace group="_2nEuro" in 2

order year sub_n ethnicity group

drop ethnicity
quietly: reshape wide observ Liberal Conservative NDP SocialCredit Creditiste UnionNationale Other None Clsr*, i(year sub_n) j(group) string
save "AUGUST\1965\1965 ethnicity id.dta"
clear



***********************************************************************
*1965 Party ID, partisan
*set directory
cd "M:\Kollman Party Project IFS\Canada"
use "AUGUST\1965\1965 edited id.dta"

count if partisan==.
drop if partisan==.

sort partisan
quietly: by partisan: sum idstr

collapse year (count)observ=countv (sum) Liberal Conservative NDP SocialCredit Creditiste UnionNationale Other None Clsr* [pweight=v4], by(partisan)
gen sub_n="partisan"

decode partisan, gen(group)
replace group="_1LibPar" in 1
replace group="_2ConPar" in 2
replace group="_3NDPPar" in 3
replace group="_4OtherPar" in 4

order year sub_n partisan group

drop partisan
quietly: reshape wide observ Liberal Conservative NDP SocialCredit Creditiste UnionNationale Other None Clsr*, i(year sub_n) j(group) string
save "AUGUST\1965\1965 partisan id.dta"
clear



***********************************************************************
*1965 Party ID, type
*set directory
cd "M:\Kollman Party Project IFS\Canada"
use "AUGUST\1965\1965 edited id.dta"

count if type==.
drop if type==.

sort type
quietly: by type: sum idstr

collapse year (count)observ=countv (sum) Liberal Conservative NDP SocialCredit Creditiste UnionNationale Other None Clsr* [pweight=v4], by(type)
gen sub_n="type"

decode type, gen(group)
replace group="_1urban" in 1
replace group="_2nurban" in 2

order year sub_n type group

drop type
quietly: reshape wide observ Liberal Conservative NDP SocialCredit Creditiste UnionNationale Other None Clsr*, i(year sub_n) j(group) string
save "AUGUST\1965\1965 type id.dta"
clear



***********************************************************************
*1965 Party ID, regxrel
*set directory
cd "M:\Kollman Party Project IFS\Canada"
use "AUGUST\1965\1965 edited id.dta"

count if regxrel==.
drop if regxrel==.

sort regxrel
quietly: by regxrel: sum idstr

collapse year (count)observ=countv (sum) Liberal Conservative NDP SocialCredit Creditiste UnionNationale Other None Clsr* [pweight=v4], by(regxrel)
gen sub_n="regxrel"

decode regxrel, gen(group)
replace group="_1QbCat" in 1
replace group="_2QbChr" in 2
replace group="_3NQbCat" in 3
replace group="_4NQbChr" in 4

order year sub_n regxrel group

drop regxrel
quietly: reshape wide observ Liberal Conservative NDP SocialCredit Creditiste UnionNationale Other None Clsr*, i(year sub_n) j(group) string
save "AUGUST\1965\1965 regxrel id.dta"
clear




***********************************************************************
*1965 Party ID, regxun
*set directory
cd "M:\Kollman Party Project IFS\Canada"
use "AUGUST\1965\1965 edited id.dta"

count if regxun==.
drop if regxun==.

sort regxun
quietly: by regxun: sum idstr

collapse year (count)observ=countv (sum) Liberal Conservative NDP SocialCredit Creditiste UnionNationale Other None Clsr* [pweight=v4], by(regxun)
gen sub_n="regxun"

decode regxun, gen(group)
replace group="_1QbU" in 1
replace group="_2QbNonU" in 2
replace group="_3NQbU" in 3
replace group="_4NQbNonU" in 4

order year sub_n regxun group

drop regxun
quietly: reshape wide observ Liberal Conservative NDP SocialCredit Creditiste UnionNationale Other None Clsr*, i(year sub_n) j(group) string
save "AUGUST\1965\1965 regxun id.dta"
clear
