*1979 Party ID
*set directory
cd "M:\Kollman Party Project IFS\Canada"
use "1979\CES_1979.dta"

***************************************************************************
* Step 1: Condensing the dataset, variable description
***************************************************************************
keep V9 V1192 V1193 V1194 V1195 V1406 V1407 V1408 V1409 V1506 V1005 V1512 V1514 V1532  V1536 V4001
numlabel, add

*V9 = participant id
*V1192 = party id
*V1194, V1195 = party closer
*V1193 = strength
*V1406 = self-placement, general
*V1407 = Liberal placement, general
*V1408 = Progressive Conservative placement, general
*V1409 = NDP placement, general
*V1506 = religion
*V1005 = region
*V1512, V1514 = union
*V1532 = ethnicity
*V1536 = type (urban/rural)
*V4001 = weight


***************************************************************************
* Step 2: Creating year variable
***************************************************************************
gen year=1979


***************************************************************************
* Step 3: Creating party id variables
***************************************************************************
gen partyid=V1192
recode partyid (5=.)
gen countv=partyid
recode countv (0/99=1)

tab V1192, m
label define idlabel 0 "none" 1 "Liberal" 2 "Progressive Conservative" 3 "NDP" 4 "Social Credit" 5 "PC & Lib" 6 "Lib and NDP" 7 "Other" 97 "Refused" 98 "Don't know" 99 "Not interview in 79"
label values V1192 idlabel

label define id3label 0 "refused" 1 "yes" 2 "no" 8 "dk" 9 "inap"
label values V1194 id3label

label define id1label  1 "Liberal" 2 "Progressive Conservative" 3 "NDP" 4 "Social Credit" 5 "PC & Lib" 6 "Lib and NDP" 7 "Other" 8 "Don't know" 9 "inapp." 0 "refused"
label values V1195 id1label

gen Liberal=.
replace Liberal=1 if V1192==1
gen ProgressiveC=. 
replace ProgressiveC=1 if V1192==2
gen NDP=.
replace NDP=1 if V1192==3
gen SocialCredit=.
replace SocialCredit=1 if V1192==4
gen Other=.
replace Other=1 if V1192==7
gen None=.
replace None=1 if V1192==0
gen DontKnow=.
replace DontKnow=1 if V1192==98
gen Refused=.
replace Refused=1 if V1192==97

gen ClsrLiberal=.
replace ClsrLiberal=1 if V1195==1
gen ClsrProgressiveC=.
replace ClsrProgressive=1 if V1195==2
gen ClsrNDP=.
replace ClsrNDP=1 if V1195==3
gen ClsrSocialCredit=.
replace ClsrSoc=1 if V1195==4
gen ClsrNone=.
replace ClsrNone=1 if V1194==2
gen ClsrDontKnow=.
replace ClsrDont=1 if V1194==8
gen ClsrRefused=.
replace ClsrRe=1 if V1195==0 | V1194==0


***************************************************************************************
* Step 4: Creating Partisan variables (ID or clsr) for Liberal, ProgressiveCon,  NDP, and others
***************************************************************************************
gen LibPart=.
replace LibPart=1 if  Liberal==1 & (V1193<8 & V1193!=.)
label var LibPart "identifies/leans to the Liberals"
label define L3 1 "Liberal partisan"
label values LibPart L3
tab LibPart

gen ProgCPart=.
replace ProgCPart=1 if  ProgressiveC==1 & (V1193<8 & V1193!=.)
label var ProgCPart "identifies/leans to Progressive Conservative"
label define L2 1 "Progressive Conservative partisan"
label values ProgCPart L2
tab ProgCPart

gen NDPPart=.
replace NDPPart=1 if  NDP==1 & (V1193<8 & V1193!=.)
label var NDPPart "identifies/leans to NDP"
label define L24 1 "NDP partisan"
label values NDPPart L24
tab NDPPart

gen SocCredPart=.
replace SocCredPart=1 if SocialCredit==1 & (V1193<8 & V1193!=.)
label var SocCredPart "identifies/leans to Social Credit"
label define so2c 1 "Social Credit partisan"
label values SocCredPart soc2c

gen OtherPart=.
replace OtherPart=1 if  Other==1 & (V1193<8 & V1193!=.)
label var OtherPart "identifies/leans to other"
label define L27 1 "other partisan"
label values OtherPart L27
tab OtherPart

gen AllOthersPart=.
replace AllOthersPart=1 if (SocialCredit==1  | Other==1) & (V1193<8 & V1193!=.)
label var AllOthersPart "identifies/leans to another party"
label define L4 1 "all other partisans"
label values AllOthersPart L4
tab AllOthersPart


***************************************************************************
* Step 5: Recoding ID strength
***************************************************************************
tab V1193
*to see how strength is coded

label define strlab 1 "very strongly" 2 "fairly strongly" 3 "not very strongly" 8 "don't know" 9 "inapp."
label values V1193 strlab

gen idstr=V1193
recode idstr (1=3) (3=1) (8/9=.)
label define idstr2 1 "not very strongly" 2 "fairly strongly" 3 "very strongly" 
label values idstr idstr2
tab V1193 idstr
*this is a check to see that the recoding is correct


***************************************************************************
*Step 6: Creating subgroup variables
***************************************************************************
*religion
tab V1506
gen religion=V1506
*7 is Ukranian Catholic
recode religion (0=4) (2/6=2) (7=1) (8=2) (9=3) (10/11=2) (12=3) (13/14=2) (15=4) (16/25=2) (26/28=3) (29=.) (88=.) (99=.)
label define rel1 1 "Catholic" 2 "Other Christian" 3 "Non-Christian"  4 "Non-Religious"
label values religion rel1
label var religion "religion"

*region
tab V1005
gen region=V1005
recode region (0/3=1) (4=2) (5=3) (6/9=4) (99=.)
label var region "region"
label define reg1 1 "Maritimes" 2 "Quebec" 3 "Ontario" 4 "Western Canada" 99 "no interview"
label values region reg1
label var region "region"

*union
tab V1512
tab V1514
gen union=.
replace union=2 if V1512==2 | V1514==2
replace union=1 if V1512==1 | V1514==1
label define label 1 "union" 2 "not union"
label values union label
label var union "union"

*ethnicity
tab V1532 
gen ethnicity=V1532
recode ethnicity (3/10=1) (12/20=1) (22=1) (25=1) (27/30=1) (11=2) (21=2) (23/24=2) (26=2) (31=2) (88=.) (99=.)
label define etn 1 "European descent" 2 "Non-European descent"
label values ethnicity etn
label var ethnicity "ethnicity"

*partisan
gen partisan=.
replace partisan=1 if LibPart==1
replace partisan=2 if ProgCPart==1
replace partisan=3 if NDPPart==1
replace partisan=4 if AllOthersPart==1
label define labelp 1 "Liberal Partisan" 2 "Progressive Cons Partisan" 3 "NDP Partisan" 4 "Other-Party Partisan"
label values partisan labelp
label var partisan "partisan"

*type (urban/rural)
tab V1536
label define tclass 0 "not interviewed" 1 "over 500,000 (city core)" 2 "over 500,000 (adjacent suburb)" 3 "over 500,000 (distant suburb)" 4 "100,000-500,000" 5 "30,000-100,00" 6 "10,000-30,000" 7 "1,000-10,000" 8 "rural non-farm" 9 "farm"
gen type2=V1536
label values type tclass
recode type2 (0=.)
gen type=type2
recode type (2/3=1) (4/9=2)
label define labeltyp 1 "urban" 2 "non-urban"
label values type labeltyp

*RegionXReligion
gen regxrel=.
replace regxrel=1 if region==2 & religion==1 //Quebec & Catholic
replace regxrel=2 if region==2 & religion==2 //Quebec & non-Cath Christ.
replace regxrel=3 if (region==1 | region==3 | region==4) & religion==1 //non-Queb & Catholic
replace regxrel=4 if (region==1 | region==3 | region==4) & religion==2 //non-Queb & non-Cath Christ.

label define pop 1 "Quebec & Catholic" 2 "Quebec & non-Cath Christ"  /*
*/ 3 "non-Quebec & Catholic" 4 "non-Quebec & non-Cath Christ"
label values regxrel pop

*RegionXUnion
gen regxun=.
replace regxun=1 if region==2 & union==1 //Queb & union
replace regxun=2 if region==2 & union==2 //Queb & non-union
replace regxun=3 if (region==1 | region==3 | region==4) & union==1 //non-Q & union
replace regxun=4 if (region==1 | region==3 | region==4) & union==2 //non-Q & non-union

label define ypy 1 "Quebec & union" 2 "Quebec & non-union" /*
*/ 3 "non-Quebec & union" 4 "non-Quebec & non-union"
label values regxun ypy


****************************************************************************
* Step 7: Save, Collapse, Save
****************************************************************************
save "AUGUST\1979\1979 edited id.dta"
collapse year (count) observ=countv (sum) Liberal ProgressiveC NDP SocialCredit Other None DontKnow Refused Clsr* [pweight=V4001]
save "AUGUST\1979\1979 total id.dta"
clear




***********************************************************************
***********************************************************************
***********************************************************************
*1979 Party ID, religion
*set directory
cd "M:\Kollman Party Project IFS\Canada"
use "AUGUST\1979\1979 edited id.dta"

count if religion==.
drop if religion==.

sort religion
quietly: by religion: sum idstr

collapse year (count) observ=countv (sum)Liberal ProgressiveC NDP SocialCredit Other None DontKnow Refused Clsr*  [pweight=V4001], by(religion)
gen sub_n="religion"

decode religion, gen(group)
replace group="_1cath" in 1
replace group="_2chr" in 2
replace group="_3other" in 3
replace group="_4nrel" in 4

order year sub_n religion group

drop religion
quietly: reshape wide observ Liberal ProgressiveC NDP SocialCredit Other None DontKnow Refused Clsr*, i(year sub_n) j(group) string
save "AUGUST\1979\1979 religion id.dta"
clear




***********************************************************************
***********************************************************************
***********************************************************************
*1979 Party ID, region
*set directory
cd "M:\Kollman Party Project IFS\Canada"
use "AUGUST\1979\1979 edited id.dta"

count if region==.
drop if region==.

sort region
quietly: by region: sum idstr

collapse year (count) observ=countv (sum)Liberal ProgressiveC NDP SocialCredit Other None DontKnow Refused Clsr* [pweight=V4001], by(region)
gen sub_n="region"

decode region, gen(group)
replace group="_1Marit" in 1
replace group="_2Queb" in 2
replace group="_3Ontar" in 3
replace group="_4West" in 4

order year sub_n region group

drop region
quietly: reshape wide observ Liberal ProgressiveC NDP SocialCredit Other None DontKnow Refused Clsr*, i(year sub_n) j(group) string
save "AUGUST\1979\1979 region id.dta"
clear




***********************************************************************
***********************************************************************
***********************************************************************
*1979 Party ID, union
*set directory
cd "M:\Kollman Party Project IFS\Canada"
use "AUGUST\1979\1979 edited id.dta"

count if union==.
drop if union==.

sort union
quietly: by union: sum idstr

collapse year (count) observ=countv (sum)Liberal ProgressiveC NDP SocialCredit Other None DontKnow Refused Clsr* [pweight=V4001], by(union)
gen sub_n="union"

decode union, gen(group)
replace group="_1union" in 1
replace group="_2nunion" in 2

order year sub_n union group

drop union
quietly: reshape wide observ Liberal ProgressiveC NDP SocialCredit Other None DontKnow Refused Clsr*, i(year sub_n) j(group) string
save "AUGUST\1979\1979 union id.dta"
clear




***********************************************************************
***********************************************************************
***********************************************************************
*1979 Party ID, ethnicity
*set directory
cd "M:\Kollman Party Project IFS\Canada"
use "AUGUST\1979\1979 edited id.dta"

count if ethnicity==.
drop if ethnicity==.

sort ethnicity
quietly: by ethnicity: sum idstr

collapse year (count) observ=countv (sum)Liberal ProgressiveC NDP SocialCredit Other None DontKnow Refused Clsr* [pweight=V4001], by(ethnicity)
gen sub_n="ethnicity"

decode ethnicity, gen(group)
replace group="_1Euro" in 1
replace group="_2nEuro" in 2

order year sub_n ethnicity group

drop ethnicity
quietly: reshape wide observ Liberal ProgressiveC NDP SocialCredit Other None DontKnow Refused Clsr*, i(year sub_n) j(group) string
save "AUGUST\1979\1979 ethnicity id.dta"
clear





***********************************************************************
***********************************************************************
***********************************************************************
*1979 Party ID, partisan
*set directory
cd "M:\Kollman Party Project IFS\Canada"
use "AUGUST\1979\1979 edited id.dta"

count if partisan==.
drop if partisan==.

sort partisan
quietly: by partisan: sum idstr

collapse year (count) observ=countv (sum)Liberal ProgressiveC NDP SocialCredit Other None DontKnow Refused Clsr* [pweight=V4001], by(partisan)
gen sub_n="partisan"

decode partisan, gen(group)
replace group="_1LibPar" in 1
replace group="_2ProgCPar" in 2
replace group="_3NDPPar" in 3
replace group="_4OtherPar" in 4

order year sub_n partisan group

drop partisan
quietly: reshape wide observ Liberal ProgressiveC NDP SocialCredit Other None DontKnow Refused Clsr*, i(year sub_n) j(group) string
save "AUGUST\1979\1979 partisan id.dta"
clear




***********************************************************************
***********************************************************************
***********************************************************************
*1979 Party ID, type
*set directory
cd "M:\Kollman Party Project IFS\Canada"
use "AUGUST\1979\1979 edited id.dta"

count if type==.
drop if type==.

sort type
quietly: by type: sum idstr

collapse year (count) observ=countv (sum)Liberal ProgressiveC NDP SocialCredit Other None DontKnow Refused Clsr* [pweight=V4001], by(type)
gen sub_n="type"

decode type, gen(group)
replace group="_1urban" in 1
replace group="_2nurban" in 2

order year sub_n type group

drop type
quietly: reshape wide observ Liberal ProgressiveC NDP SocialCredit Other None DontKnow Refused Clsr*, i(year sub_n) j(group) string
save "AUGUST\1979\1979 type id.dta"
clear



***********************************************************************
***********************************************************************
***********************************************************************
*1979 Party ID, regxrel
*set directory
cd "M:\Kollman Party Project IFS\Canada"
use "AUGUST\1979\1979 edited id.dta"

count if regxrel==.
drop if regxrel==.

sort regxrel
quietly: by regxrel: sum idstr

collapse year (count) observ=countv (sum)Liberal ProgressiveC NDP SocialCredit Other None DontKnow Refused Clsr* [pweight=V4001], by(regxrel)
gen sub_n="regxrel"

decode regxrel, gen(group)
replace group="_1QbCat" in 1
replace group="_2QbChr" in 2
replace group="_3NQbCat" in 3
replace group="_4NQbChr" in 4

order year sub_n regxrel group

drop regxrel
quietly: reshape wide observ Liberal ProgressiveC NDP SocialCredit Other None DontKnow Refused Clsr*, i(year sub_n) j(group) string
save "AUGUST\1979\1979 regxrel id.dta"
clear



***********************************************************************
***********************************************************************
***********************************************************************
*1979 Party ID, regxun
*set directory
cd "M:\Kollman Party Project IFS\Canada"
use "AUGUST\1979\1979 edited id.dta"

count if regxun==.
drop if regxun==.

sort regxun
quietly: by regxun: sum idstr

collapse year (count) observ=countv (sum)Liberal ProgressiveC NDP SocialCredit Other None DontKnow Refused Clsr* [pweight=V4001], by(regxun)
gen sub_n="regxun"

decode regxun, gen(group)
replace group="_1QbU" in 1
replace group="_2QbNonU" in 2
replace group="_3NQbU" in 3
replace group="_4NQbNonU" in 4

order year sub_n regxun group

drop regxun
quietly: reshape wide observ Liberal ProgressiveC NDP SocialCredit Other None DontKnow Refused Clsr*, i(year sub_n) j(group) string
save "AUGUST\1979\1979 regxun id.dta"
clear


