*1984 Party ID
*set directory
cd "M:\Kollman Party Project IFS\Canada"
use "1984\CES 1984 Stata.dta"

***************************************************************************
* Step 1: Condensing the dataset, variable description
***************************************************************************
keep var001 var081 var082 var085 var086 var507 var509 var510 var511 var371 var463 var378 var381 var343 var464 wtfactor
numlabel, add

*var001 = participant id
*var081 = party id
*var085, var086 = party closer
*var082 = strength
*var507 = self-placement, general
*var509 = Liberal placement, general
*var510 = Progressive Conservative placement, general
*var511 = NDP placement, general
*var371 = religion
*var463 = region
*var378, var381 = union
*var434 = ethnicity
*var464 = type(urban/rural)
*wtfactor = weight

***************************************************************************
* Step 2: Creating year variable
***************************************************************************
gen year=1984


***************************************************************************
* Step 3: Creating party id variables
***************************************************************************
gen partyid=var081
recode partyid (8/12=.) 
gen countv=partyid
recode countv (1/20=1)

gen Liberal=.
replace Liberal=1 if var081==1
gen ProgressiveC=. 
replace ProgressiveC=1 if var081==2
gen NDP=.
replace NDP=1 if var081==3
gen SocialCredit=.
replace SocialCredit=1 if var081==4
gen PartiNationaliste=.
replace PartiNationaliste=1 if var081==5
gen Other=.
replace Other=1 if var081==19
gen None=.
replace None=1 if var081==20

gen ClsrLiberal=.
replace ClsrLiberal=1 if var086==1
gen ClsrProgressiveC=.
replace ClsrPro=1 if var086==2
gen ClsrNDP=.
replace ClsrNDP=1 if var086==3
gen ClsrSocialCredit=.
replace ClsrSo=1 if var086==4
gen ClsrNone=.
replace ClsrNone=1 if var086==20 | var085==2

***************************************************************************************
* Step 4: Creating Partisan variables (ID or clsr) for Liberal, ProgressiveCon,  NDP, and others
***************************************************************************************
gen LibPart=.
replace LibPart=1 if  Liberal==1 & var082!=.
label var LibPart "identifies/leans to the Liberals"
label define L3 1 "Liberal partisan"
label values LibPart L3
tab LibPart

gen ProgCPart=.
replace ProgCPart=1 if  ProgressiveC==1 & var082!=.
label var ProgCPart "identifies/leans to Progressive Conservative"
label define L2 1 "Progressive Conservative partisan"
label values ProgCPart L2
tab ProgCPart

gen NDPPart=.
replace NDPPart=1 if  NDP==1 & var082!=.
label var NDPPart "identifies/leans to NDP"
label define L24 1 "NDP partisan"
label values NDPPart L24
tab NDPPart

gen SocCredPart=.
replace SocCredPart=1 if SocialCredit==1 & var082!=.
label var SocCredPart "identifies/leans to Social Credit"
label define so2c 1 "Social Credit partisan"
label values SocCredPart soc2c

gen PartiNatPart=.
replace PartiNatPart=1 if PartiNationaliste==1 & var082!=.
label var PartiNatPart "identifies/leans to Parti Nationaliste"
label define so24 1 "Parti Nationaliste partisan"
label values PartiNatPart soc24

gen OtherPart=.
replace OtherPart=1 if  Other==1 & var082!=.
label var OtherPart "identifies/leans to other"
label define L27 1 "other partisan"
label values OtherPart L27
tab OtherPart

gen AllOthersPart=.
replace AllOthersPart=1 if (SocialCredit==1 | PartiNationaliste==1 | Other==1) & var082!=. 
label var AllOthersPart "identifies/leans to another party"
label define L4 1 "all other partisans"
label values AllOthersPart L4
tab AllOthersPart


***************************************************************************
* Step 5: Recoding ID strength
***************************************************************************
tab var082
*to see how strength is coded

gen idstr=var082
recode idstr (1=3) (3=1)
label define idstr2 1 "not very strongly" 2 "fairly strongly" 3 "very strongly" 
label values idstr idstr2
tab var082 idstr
*this is a check to see that the recoding is correct


***************************************************************************
*Step 6: Creating subgroup variables
***************************************************************************
*religion
tab var371
gen religion=var371
*7 is Ukranian Catholic
recode religion (0=4) (2/6=2) (7=1) (8=2) (9=3) (10/11=2) (12=3) (13/29=2) (30/33=3) (34=4) (35=.)
label define rel1 1 "Catholic" 2 "Other Christian" 3 "Non-Christian"  4 "Non-Religious"
label values religion rel1
label var religion "religion"

*region
tab var463
gen region=var463
recode region (0/3=1) (4=2) (5=3) (6/9=4)
label var region "region"
label define reg1 1 "Maritimes" 2 "Quebec" 3 "Ontario" 4 "Western Canada"
label values region reg1
label var region "region"

*union
tab var378
tab var381
gen union=.
replace union=2 if var378==2 | var381==2
replace union=1 if var378==1 | var381==1
label define unlab 1 "union" 2 "non-union"
label values union unlab
label var union "union"

*ethnicity
tab var343
gen ethnicity=var343
recode ethnicity (3/10=1) (12/20=1) (24/25=1) (27=1) (30/31=1) (11=2) (21/23=2) (26=2) (28=20) (33=2)
label define etn 1 "European descent" 2 "Non-European descent"
label values ethnicity etn
label var ethnicity "ethnicity"

*partisan
gen partisan=.
replace partisan=1 if LibPart==1
replace partisan=2 if ProgCPart==1
replace partisan=3 if NDPPart==1
replace partisan=4 if AllOthersPart==1
label define labelp 1 "Liberal Partisan" 2 "Progressive Cons Partisan" 3 "NDP Partisan" 4 "Other-Party Partisan"
label values partisan labelp
label var partisan "partisan"

*type(urban/rural)
tab var464, m
gen type=2
replace type=1 if var464==1
label define labtyp 1 "urban" 2 "not urban"
label values type labtyp
label var type "type"

*RegionXReligion
gen regxrel=.
replace regxrel=1 if region==2 & religion==1 //Quebec & Catholic
replace regxrel=2 if region==2 & religion==2 //Quebec & non-Cath Christ.
replace regxrel=3 if (region==1 | region==3 | region==4) & religion==1 //non-Queb & Catholic
replace regxrel=4 if (region==1 | region==3 | region==4) & religion==2 //non-Queb & non-Cath Christ.

label define pop 1 "Quebec & Catholic" 2 "Quebec & non-Cath Christ"  /*
*/ 3 "non-Quebec & Catholic" 4 "non-Quebec & non-Cath Christ"
label values regxrel pop

*RegionXUnion
gen regxun=.
replace regxun=1 if region==2 & union==1 //Queb & union
replace regxun=2 if region==2 & union==2 //Queb & non-union
replace regxun=3 if (region==1 | region==3 | region==4) & union==1 //non-Q & union
replace regxun=4 if (region==1 | region==3 | region==4) & union==2 //non-Q & non-union

label define ypy 1 "Quebec & union" 2 "Quebec & non-union" /*
*/ 3 "non-Quebec & union" 4 "non-Quebec & non-union"
label values regxun ypy


***************************************************************************
*Step 7: Save, Collapse, Save
***************************************************************************
save "AUGUST\1984\1984 edited id.dta"
collapse year (count) observ=countv (sum) Liberal ProgressiveC NDP SocialCredit PartiNationaliste Other None Clsr* [pweight=wtfactor]
save "AUGUST\1984\1984 total id.dta"
clear





***********************************************************************
***********************************************************************
***********************************************************************
*1984 Party ID, religion
*set directory
cd "M:\Kollman Party Project IFS\Canada"
use "AUGUST\1984\1984 edited id.dta"

count if religion==.
drop if religion==.

sort religion
quietly: by religion: sum idstr

collapse year (count)observ=countv (sum) Liberal ProgressiveC NDP SocialCredit PartiNationaliste Other None Clsr* [pweight=wtfactor], by(religion)
gen sub_n="religion"

decode religion, gen(group)
replace group="_1cath" in 1
replace group="_2chr" in 2
replace group="_3other" in 3
replace group="_4nrel" in 4

order year sub_n religion group

drop religion
quietly: reshape wide observ Liberal ProgressiveC NDP SocialCredit PartiNationaliste Other None Clsr*, i(year sub_n) j(group) string
save "AUGUST\1984\1984 religion id.dta"
clear



***********************************************************************
*1984 Party ID, region
*set directory
cd "M:\Kollman Party Project IFS\Canada"
use "AUGUST\1984\1984 edited id.dta"

count if region==.
drop if region==.

sort region
quietly: by region: sum idstr

collapse year (count)observ=countv (sum) Liberal ProgressiveC NDP SocialCredit PartiNationaliste Other None Clsr* [pweight=wtfactor], by(region)
gen sub_n="region"

decode region, gen(group)
replace group="_1Marit" in 1
replace group="_2Queb" in 2
replace group="_3Ontar" in 3
replace group="_4West" in 4

order year sub_n region group

drop region
quietly: reshape wide observ Liberal ProgressiveC NDP SocialCredit PartiNationaliste Other None Clsr*, i(year sub_n) j(group) string
save "AUGUST\1984\1984 region id.dta"
clear



***********************************************************************
*1984 Party ID, union
*set directory
cd "M:\Kollman Party Project IFS\Canada"
use "AUGUST\1984\1984 edited id.dta"

count if union==.
drop if union==.

sort union
quietly: by union: sum idstr

collapse year (count)observ=countv (sum) Liberal ProgressiveC NDP SocialCredit PartiNationaliste Other None Clsr* [pweight=wtfactor], by(union)
gen sub_n="union"

decode union, gen(group)
replace group="_1union" in 1
replace group="_2nunion" in 2

order year sub_n union group

drop union
quietly: reshape wide observ Liberal ProgressiveC NDP SocialCredit PartiNationaliste Other None Clsr*, i(year sub_n) j(group) string
save "AUGUST\1984\1984 union id.dta"
clear



***********************************************************************
*1984 Party ID, ethnicity
*set directory
cd "M:\Kollman Party Project IFS\Canada"
use "AUGUST\1984\1984 edited id.dta"

count if ethnicity==.
drop if ethnicity==.

sort ethnicity
quietly: by ethnicity: sum idstr

collapse year (count)observ=countv (sum) Liberal ProgressiveC NDP SocialCredit PartiNationaliste Other None Clsr* [pweight=wtfactor], by(ethnicity)
gen sub_n="ethnicity"

decode ethnicity, gen(group)
replace group="_1Euro" in 1
replace group="_2nEuro" in 2

order year sub_n ethnicity group

drop ethnicity
quietly: reshape wide observ Liberal ProgressiveC NDP SocialCredit PartiNationaliste Other None Clsr*, i(year sub_n) j(group) string
save "AUGUST\1984\1984 ethnicity id.dta"
clear



***********************************************************************
*1984 Party ID, partisan
*set directory
cd "M:\Kollman Party Project IFS\Canada"
use "AUGUST\1984\1984 edited id.dta"

count if partisan==.
drop if partisan==.

sort partisan
quietly: by partisan: sum idstr

collapse year (count)observ=countv (sum) Liberal ProgressiveC NDP SocialCredit PartiNationaliste Other None Clsr* [pweight=wtfactor], by(partisan)
gen sub_n="partisan"

decode partisan, gen(group)
replace group="_1LibPar" in 1
replace group="_2ProgCPar" in 2
replace group="_3NDPPar" in 3
replace group="_4OtherPar" in 4

order year sub_n partisan group

drop partisan
quietly: reshape wide observ Liberal ProgressiveC NDP SocialCredit PartiNationaliste Other None Clsr*, i(year sub_n) j(group) string
save "AUGUST\1984\1984 partisan id.dta"
clear


***********************************************************************
*1984 Party ID, type
*set directory
cd "M:\Kollman Party Project IFS\Canada"
use "AUGUST\1984\1984 edited id.dta"

count if type==.
drop if type==.

sort type
quietly: by type: sum idstr

collapse year (count)observ=countv (sum) Liberal ProgressiveC NDP SocialCredit PartiNationaliste Other None Clsr* [pweight=wtfactor], by(type)
gen sub_n="type"

decode type, gen(group)
replace group="_1urban" in 1
replace group="_2nurban" in 2

order year sub_n type group

drop type
quietly: reshape wide observ Liberal ProgressiveC NDP SocialCredit PartiNationaliste Other None Clsr*, i(year sub_n) j(group) string
save "AUGUST\1984\1984 type id.dta"
clear




***********************************************************************
*1984 Party ID, regxrel
*set directory
cd "M:\Kollman Party Project IFS\Canada"
use "AUGUST\1984\1984 edited id.dta"

count if regxrel==.
drop if regxrel==.

sort regxrel
quietly: by regxrel: sum idstr

collapse year (count)observ=countv (sum) Liberal ProgressiveC NDP SocialCredit PartiNationaliste Other None Clsr* [pweight=wtfactor], by(regxrel)
gen sub_n="regxrel"

decode regxrel, gen(group)
replace group="_1QbCat" in 1
replace group="_2QbChr" in 2
replace group="_3NQbCat" in 3
replace group="_4NQbChr" in 4

order year sub_n regxrel group

drop regxrel
quietly: reshape wide observ Liberal ProgressiveC NDP SocialCredit PartiNationaliste Other None Clsr*, i(year sub_n) j(group) string
save "AUGUST\1984\1984 regxrel id.dta"
clear


***********************************************************************
*1984 Party ID, regxun
*set directory
cd "M:\Kollman Party Project IFS\Canada"
use "AUGUST\1984\1984 edited id.dta"

count if regxun==.
drop if regxun==.

sort regxun
quietly: by regxun: sum idstr

collapse year (count)observ=countv (sum) Liberal ProgressiveC NDP SocialCredit PartiNationaliste Other None Clsr* [pweight=wtfactor], by(regxun)
gen sub_n="regxun"

decode regxun, gen(group)
replace group="_1QbU" in 1
replace group="_2QbNonU" in 2
replace group="_3NQbU" in 3
replace group="_4NQbNonU" in 4

order year sub_n regxun group

drop regxun
quietly: reshape wide observ Liberal ProgressiveC NDP SocialCredit PartiNationaliste Other None Clsr*, i(year sub_n) j(group) string
save "AUGUST\1984\1984 regxun id.dta"
clear


