*1997 Party ID
*set directory
cd "M:\Kollman Party Project IFS\Canada"
use "1997\CES 1997 Stata.dta"

***************************************************************************
* Step 1: Condensing the dataset, variable description
***************************************************************************
keep idnum cpsk1 cpsk2 cpsk3 cpsk4 mbsi3 mbsi3a mbsi3b mbsi16a mbsi16b mbsi16c mbsi16d cpsm10 province cpsm9 cpsm13 areacode cpsnwgt1
numlabel, add

*idnum = participant id
*cpsk1 = party id
*cpsk3, cpsk4 = closer
*cpsk2 = strength
*mbsi3, mbsi3a = party id
*mbsi3b = strength
*mbsi16a = self-placement, general
*mbsi16b = Liberal placement, general
*mbsi16c = Conservative placement, general
*mbsi16d = NDP placement, general
*cpsm10 = religion
*province = region
*cpsm9 = union
*cpsm13 = ethnicity
*areacode = type(urban/rural)
*cpsnwgt1 = weight


***************************************************************************
* Step 2: Creating year variable
***************************************************************************
gen year=1997


***************************************************************************
* Step 3: Creating party id and party clsr variables
***************************************************************************
gen countv=cpsk1
recode countv (0/99=1)

gen Liberal=.
replace Liberal=1 if cpsk1==1
gen ProgressiveC=. 
replace ProgressiveC=1 if cpsk1==2
gen NDP=.
replace NDP=1 if cpsk1==3
gen Reform=.
replace Reform=1 if cpsk1==4
gen BlocQuebecois=.
replace BlocQuebecois=1 if cpsk1==5
gen Other=.
replace Other=1 if cpsk1==6
gen None=.
replace None=1 if cpsk1==0
gen DontKnow=.
replace DontKnow=1 if cpsk1==98
gen Refused=.
replace Refused=1 if cpsk1==99

gen ClsrLiberal=.
replace ClsrLi=1 if cpsk4==1
gen ClsrProgressiveC=.
replace ClsrProg=1 if cpsk4==2
gen ClsrNDP=.
replace ClsrNDP=1 if cpsk4==3
gen ClsrReform=.
replace ClsrReform=1 if cpsk4==4
gen ClsrBlocQuebecois=.
replace ClsrBloc=1 if cpsk4==5
gen ClsrOther=.
replace ClsrO=1 if cpsk4==6
gen ClsrNone=.
replace ClsrNone=1 if cpsk4==0 | cpsk3==5
gen ClsrDontKnow=.
replace ClsrDontKnow=1 if cpsk4==98 | cpsk3==8
gen ClsrRefused=.
replace ClsrRefus=1 if cpsk4==99 | cpsk3==9

***************************************************************************************
*  Step 4: Creating Partisan variables (ID or clsr) for Liberal, ProgressiveCon,  NDP, and others
***************************************************************************************
gen LibPart=.
replace LibPart=1 if  Liberal==1 & (cpsk2<8 & cpsk2!=.)
label var LibPart "identifies/leans to the Liberals"
label define L3 1 "Liberal partisan"
label values LibPart L3
tab LibPart

gen ProgCPart=.
replace ProgCPart=1 if  ProgressiveC==1 & (cpsk2<8 & cpsk2!=.)
label var ProgCPart "identifies/leans to Progressive Conservative"
label define L2 1 "Progressive Conservative partisan"
label values ProgCPart L2
tab ProgCPart

gen NDPPart=.
replace NDPPart=1 if  NDP==1 & (cpsk2<8 & cpsk2!=.)
label var NDPPart "identifies/leans to NDP"
label define L24 1 "NDP partisan"
label values NDPPart L24
tab NDPPart

gen ReformPart=.
replace ReformPart=1 if Reform==1 & (cpsk2<8 & cpsk2!=.)
label var ReformPart "identifies/leans to Reform"
label define L241 1 "Reform partisan"
label values ReformPart L21
tab ReformPart

gen BlocQPar=.
replace BlocQPar=1 if BlocQuebecois==1 & (cpsk2<8 & cpsk2!=.)
label var BlocQPar "identifies/leans to Bloc Quebecois"
label define queb 1 "Bloc Quebecois partisan"
label values BlocQPar queb
tab BlocQPar

gen OtherPart=.
replace OtherPart=1 if  Other==1  & (cpsk2<8 & cpsk2!=.)
label var OtherPart "identifies/leans to other"
label define L27 1 "other partisan"
label values OtherPart L27
tab OtherPart

gen AllOthersPart=.
replace AllOthersPart=1 if (Reform==1 | BlocQuebecois==1 | Other==1) &  (cpsk2<8 & cpsk2!=.)
label var AllOthersPart "identifies/leans to another party"
label define L4 1 "all other partisans"
label values AllOthersPart L4
tab AllOthersPart


***************************************************************************
* Step 5: Recoding ID strength
***************************************************************************
tab cpsk2
*to see how strength is coded

gen idstr=cpsk2
recode idstr (1=3) (3=2) (5=1) (8/9=.)
label define idstr2 1 "not very strongly" 2 "fairly strongly" 3 "very strongly" 
label values idstr idstr2
tab cpsk2 idstr
*this is a check to see that the recoding is correct


****************************************************************************
*Step 6: Creating subgroup variables
****************************************************************************
*religion
tab cpsm10
gen religion=cpsm10
recode religion (0=4) (1=2) (2=1) (4=3) (5=3) (98/99=.)
label define rel1 1 "Catholic" 2 "Other Christian" 3 "Non-Christian"  4 "Non-Religious"
label values religion rel1
label var religion "religion"

*region
tab province
gen region=province
recode region (10/13=1) (24=2) (35=3) (46/59=4) (60/61=.)
label var region "region"
label define reg1 1 "Maritimes" 2 "Quebec" 3 "Ontario" 4 "Western Canada"
label values region reg1
label var region "region"

*union
tab cpsm9
gen union=cpsm9
recode union (5=2) (8/9=.)
label define unlab 1 "union" 2 "non-union"
label values union unlab
label var union "union"

*ethnicity
tab cpsm13
gen ethnicity=cpsm13
recode ethnicity (0=2) (1/4=1) (6/11=1) (13=1) (18/23=1)(28=1) (30=1) (31=1) (5=2) (12=2) (14/17=2) (24/27=2) (29=2) (97/99=.)
label define etn 1 "European descent" 2 "Non-European descent"
label values ethnicity etn
label var ethnicity "ethnicity"

*partisan
gen partisan=.
replace partisan=1 if LibPart==1
replace partisan=2 if ProgCPart==1
replace partisan=3 if NDPPart==1
replace partisan=4 if AllOthersPart==1
label define labelp 1 "Liberal Partisan" 2 "Progressive Cons Partisan" 3 "NDP Partisan" 4 "Other-Party Partisan"
label values partisan labelp
tab partisan
label var partisan "partisan"

*type(urban/rural)
tab areacode, m
gen type=2
replace type=1 if areacode==514 | areacode==416 | areacode==250 | areacode==604
label define labtyp 1 "urban" 2 "not urban"
label values type labtyp
label var type "type"
	//Montreal = 514
	//Toronto = 416
	//Vancouver = 250, 604

*RegionXReligion
gen regxrel=.
replace regxrel=1 if region==2 & religion==1 //Quebec & Catholic
replace regxrel=2 if region==2 & religion==2 //Quebec & non-Cath Christ.
replace regxrel=3 if (region==1 | region==3 | region==4) & religion==1 //non-Queb & Catholic
replace regxrel=4 if (region==1 | region==3 | region==4) & religion==2 //non-Queb & non-Cath Christ.

label define pop 1 "Quebec & Catholic" 2 "Quebec & non-Cath Christ"  /*
*/ 3 "non-Quebec & Catholic" 4 "non-Quebec & non-Cath Christ"
label values regxrel pop

*RegionXUnion
gen regxun=.
replace regxun=1 if region==2 & union==1 //Queb & union
replace regxun=2 if region==2 & union==2 //Queb & non-union
replace regxun=3 if (region==1 | region==3 | region==4) & union==1 //non-Q & union
replace regxun=4 if (region==1 | region==3 | region==4) & union==2 //non-Q & non-union

label define ypy 1 "Quebec & union" 2 "Quebec & non-union" /*
*/ 3 "non-Quebec & union" 4 "non-Quebec & non-union"
label values regxun ypy

	
****************************************************************************
*Step 8: Save, Collapse, Save
****************************************************************************
save "AUGUST\1997\1997 edited id.dta"
collapse year (count) observ=countv (sum) Liberal ProgressiveC NDP Reform BlocQuebecois Other None DontKnow Refused Clsr* [pweight=cpsnwgt1]
save "AUGUST\1997\1997 total id.dta"
clear





***********************************************************************
***********************************************************************
***********************************************************************
*1997 Party ID, religion
*set directory
cd "M:\Kollman Party Project IFS\Canada"
use "AUGUST\1997\1997 edited id.dta"

count if religion==.
drop if religion==.

sort religion
quietly: by religion: sum idstr

collapse year (count) observ=countv (sum) Liberal ProgressiveC NDP Reform BlocQuebecois Other None DontKnow Refused Clsr* [pweight=cpsnwgt1], by(religion)
gen sub_n="religion"

decode religion, gen(group)
replace group="_1cath" in 1
replace group="_2chr" in 2
replace group="_3other" in 3
replace group="_4nrel" in 4

order year sub_n religion group

drop religion
quietly: reshape wide observ Liberal ProgressiveC NDP Reform BlocQuebecois Other None DontKnow Refused Clsr*, i(year sub_n) j(group) string
save "AUGUST\1997\1997 religion id.dta"
clear


***********************************************************************
*1997 Party ID, region
*set directory
cd "M:\Kollman Party Project IFS\Canada"
use "AUGUST\1997\1997 edited id.dta"

count if region==.
drop if region==.

sort region
quietly: by region: sum idstr

collapse year (count) observ=countv (sum) Liberal ProgressiveC NDP Reform BlocQuebecois Other None DontKnow Refused Clsr* [pweight=cpsnwgt1], by(region)
gen sub_n="region"

decode region, gen(group)
replace group="_1Marit" in 1
replace group="_2Queb" in 2
replace group="_3Ontar" in 3
replace group="_4West" in 4

order year sub_n region group

drop region
quietly: reshape wide observ Liberal ProgressiveC NDP Reform BlocQuebecois Other None DontKnow Refused Clsr*, i(year sub_n) j(group) string
save "AUGUST\1997\1997 region id.dta"
clear



***********************************************************************
*1997 Party ID, union
*set directory
cd "M:\Kollman Party Project IFS\Canada"
use "AUGUST\1997\1997 edited id.dta"

count if union==.
drop if union==.

sort union
quietly: by union: sum idstr

collapse year (count) observ=countv (sum) Liberal ProgressiveC NDP Reform BlocQuebecois Other None DontKnow Refused Clsr* [pweight=cpsnwgt1], by(union)
gen sub_n="union"

decode union, gen(group)
replace group="_1union" in 1
replace group="_2nunion" in 2

order year sub_n union group

drop union
quietly: reshape wide observ Liberal ProgressiveC NDP Reform BlocQuebecois Other None DontKnow Refused Clsr*, i(year sub_n) j(group) string
save "AUGUST\1997\1997 union id.dta"
clear



***********************************************************************
*1997 Party ID, ethnicity
*set directory
cd "M:\Kollman Party Project IFS\Canada"
use "AUGUST\1997\1997 edited id.dta"

count if ethnicity==.
drop if ethnicity==.

sort ethnicity
quietly: by ethnicity: sum idstr

collapse year (count) observ=countv (sum) Liberal ProgressiveC NDP Reform BlocQuebecois Other None DontKnow Refused Clsr* [pweight=cpsnwgt1], by(ethnicity)
gen sub_n="ethnicity"

decode ethnicity, gen(group)
replace group="_1Euro" in 1
replace group="_2nEuro" in 2

order year sub_n ethnicity group

drop ethnicity
quietly: reshape wide observ Liberal ProgressiveC NDP Reform BlocQuebecois Other None DontKnow Refused Clsr*, i(year sub_n) j(group) string
save "AUGUST\1997\1997 ethnicity id.dta"
clear



***********************************************************************
*1997 Party ID, partisan
*set directory
cd "M:\Kollman Party Project IFS\Canada"
use "AUGUST\1997\1997 edited id.dta"

count if partisan==.
drop if partisan==.

sort partisan
quietly: by partisan: sum idstr

collapse year (count) observ=countv (sum) Liberal ProgressiveC NDP Reform BlocQuebecois Other None DontKnow Refused Clsr* [pweight=cpsnwgt1], by(partisan)
gen sub_n="partisan"

decode partisan, gen(group)
replace group="_1LibPar" in 1
replace group="_2ProgCPar" in 2
replace group="_3NDPPar" in 3
replace group="_4OtherPar" in 4

order year sub_n partisan group

drop partisan
quietly: reshape wide observ Liberal ProgressiveC NDP Reform BlocQuebecois Other None DontKnow Refused Clsr*, i(year sub_n) j(group) string
save "AUGUST\1997\1997 partisan id.dta"
clear




***********************************************************************
*1997 Party ID, type
*set directory
cd "M:\Kollman Party Project IFS\Canada"
use "AUGUST\1997\1997 edited id.dta"

count if type==.
drop if type==.

sort type
quietly: by type: sum idstr

collapse year (count) observ=countv (sum) Liberal ProgressiveC NDP Reform BlocQuebecois Other None DontKnow Refused Clsr* [pweight=cpsnwgt1], by(type)
gen sub_n="type"

decode type, gen(group)
replace group="_1urban" in 1
replace group="_2nurban" in 2

order year sub_n type group

drop type
quietly: reshape wide observ Liberal ProgressiveC NDP Reform BlocQuebecois Other None DontKnow Refused Clsr*, i(year sub_n) j(group) string
save "AUGUST\1997\1997 type id.dta"
clear



***********************************************************************
*1997 Party ID, regxrel
*set directory
cd "M:\Kollman Party Project IFS\Canada"
use "AUGUST\1997\1997 edited id.dta"

count if regxrel==.
drop if regxrel==.

sort regxrel
quietly: by regxrel: sum idstr

collapse year (count) observ=countv (sum) Liberal ProgressiveC NDP Reform BlocQuebecois Other None DontKnow Refused Clsr* [pweight=cpsnwgt1], by(regxrel)
gen sub_n="regxrel"

decode regxrel, gen(group)
replace group="_1QbCat" in 1
replace group="_2QbChr" in 2
replace group="_3NQbCat" in 3
replace group="_4NQbChr" in 4

order year sub_n regxrel group

drop regxrel
quietly: reshape wide observ Liberal ProgressiveC NDP Reform BlocQuebecois Other None DontKnow Refused Clsr*, i(year sub_n) j(group) string
save "AUGUST\1997\1997 regxrel id.dta"
clear



***********************************************************************
*1997 Party ID, regxun
*set directory
cd "M:\Kollman Party Project IFS\Canada"
use "AUGUST\1997\1997 edited id.dta"

count if regxun==.
drop if regxun==.

sort regxun
quietly: by regxun: sum idstr

collapse year (count) observ=countv (sum) Liberal ProgressiveC NDP Reform BlocQuebecois Other None DontKnow Refused Clsr* [pweight=cpsnwgt1], by(regxun)
gen sub_n="regxun"

decode regxun, gen(group)
replace group="_1QbU" in 1
replace group="_2QbNonU" in 2
replace group="_3NQbU" in 3
replace group="_4NQbNonU" in 4

order year sub_n regxun group

drop regxun
quietly: reshape wide observ Liberal ProgressiveC NDP Reform BlocQuebecois Other None DontKnow Refused Clsr*, i(year sub_n) j(group) string
save "AUGUST\1997\1997 regxun id.dta"
clear
