*2000 Party distance
*set directory
cd "M:\Kollman Party Project IFS\Canada"
use "AUGUST\2000\2000 edited id.dta"

**************************************************************************
* TOTAL POPULATION Step 1: Recoding
**************************************************************************
*see how non-rating responses are coded
tab cpspla36, mi
	*Self = 7, 97, 98, 99
tab cpspla33, mi
	*Liberal = 7, 97, 98, 99
tab cpspla34, mi
	*Conservative = 7, 97, 98, 99
tab cpspla31, mi
	*NDP = 7, 97, 98, 99

recode cpspla3* (1=2.5) (3=7.5) 
	
gen SelfPlacement= cpspla36
gen LibPlacement = cpspla33
gen ConPlacement = cpspla34
gen NDPPlacement = cpspla31

label define L09 0 "spend more" 10 "cut taxes"
label values *Placement L09

recode *Placement (7/99=12)
recode cpspla3* (7/99=.)

save "AUGUST\2000\2000 edited distance.dta", replace

collapse year (mean) proxyLib=cpspla33 proxyCon=cpspla34 proxyNDP=cpspla31 [pweight=cesnwgt]

save "AUGUST\2000\2000 proxies distance.dta", replace
clear

use "AUGUST\2000\2000 edited distance.dta"
merge m:1 year using "AUGUST\2000\2000 proxies distance.dta"
drop _merge

************************************************************************
* TOTAL POPULATION Step 2: Party distance
************************************************************************
egen sdSelf = sd(cpspla36)
egen sdLib = sd(cpspla33)
egen sdCon = sd(cpspla34)
egen sdNDP = sd(cpspla31)

gen partydis1 = (abs(SelfPlacement - LibPlacement)) + (abs(SelfPlacement - ConPlacement)) + (abs(SelfPlacement - NDPPlacement)) if SelfPlacement!=12 & LibPlacement!=12 & ConPlacement!=12 & NDPPlacement!=12
*this is for all those who gave placements for all parties

gen partydis2 = (abs(SelfPlacement - proxyLib)) + (abs(SelfPlacement - proxyCon)) + (abs(SelfPlacement - proxyNDP)) if SelfPlacement!=12 & LibPlacement==12 & ConPlacement==12 & NDPPlacement==12
*this is for all those who gave no placements for any party

gen partydis3 = (abs(SelfPlacement - proxyLib)) + (abs(SelfPlacement - ConPlacement)) + (abs(SelfPlacement - NDPPlacement)) if SelfPlacement!=12 & LibPlacement==12 & ConPlacement!=12 & NDPPlacement!=12
*this is for those who answered Con and NDP

gen partydis4 = (abs(SelfPlacement - LibPlacement)) + (abs(SelfPlacement - proxyCon)) + (abs(SelfPlacement - NDPPlacement)) if SelfPlacement!=12 & LibPlacement!=12 & ConPlacement==12 & NDPPlacement!=12
*this is for those who answered Lib and NDP

gen partydis5 = (abs(SelfPlacement - LibPlacement)) + (abs(SelfPlacement - ConPlacement)) + (abs(SelfPlacement - proxyNDP)) if SelfPlacement!=12 & LibPlacement!=12 & ConPlacement!=12 & NDPPlacement==12
*this is for those who answered Lib and Con

gen partydis6 = (abs(SelfPlacement - LibPlacement)) + (abs(SelfPlacement - proxyCon)) + (abs(SelfPlacement - proxyNDP)) if SelfPlacement!=12 & LibPlacement!=12 & ConPlacement==12 & NDPPlacement==12
*this is for those who only answered Lib

gen partydis7 = (abs(SelfPlacement - proxyLib)) + (abs(SelfPlacement - ConPlacement)) + (abs(SelfPlacement - proxyNDP)) if SelfPlacement!=12 & LibPlacement==12 & ConPlacement!=12 & NDPPlacement==12
*this is for those who only answered Con

gen partydis8 = (abs(SelfPlacement - proxyLib)) + (abs(SelfPlacement - proxyCon)) + (abs(SelfPlacement - NDPPlacement)) if SelfPlacement!=12 & LibPlacement==12 & ConPlacement==12 & NDPPlacement!=12
*this is for those who only answered NDP

gen partydis = .a
replace partydis = partydis1 if partydis1!=.
replace partydis = partydis2 if partydis2!=.
replace partydis = partydis3 if partydis3!=.
replace partydis = partydis4 if partydis4!=.
replace partydis = partydis5 if partydis5!=.
replace partydis = partydis6 if partydis6!=.
replace partydis = partydis7 if partydis7!=.
replace partydis = partydis8 if partydis8!=.

egen sdPartyDis = sd(partydis)

************************************************************************
* TOTAL POPULATION Step 3: Distance for Individual Parties
************************************************************************
*Liberal
gen lib_pd1 = (abs(SelfPlacement - LibPlacement)) if SelfPlacement!=12 & LibPlacement!=12 
gen lib_pd2 = (abs(SelfPlacement - proxyLib)) if SelfPlacement!=12 & LibPlacement==12 

gen lib_pd = .a
replace lib_pd = lib_pd1 if lib_pd1!=.
replace lib_pd = lib_pd2 if lib_pd2!=.

egen sdPD_lib = sd(lib_pd)

*Conservative
gen con_pd1 = (abs(SelfPlacement - ConPlacement)) if SelfPlacement!=12 & ConPlacement!=12 
gen con_pd2 = (abs(SelfPlacement - proxyCon)) if SelfPlacement!=12 & ConPlacement==12 

gen con_pd = .a
replace con_pd = con_pd1 if con_pd1!=.
replace con_pd = con_pd2 if con_pd2!=.

egen sdPD_con = sd(con_pd)

*NDP
gen ndp_pd1 = (abs(SelfPlacement - NDPPlacement)) if SelfPlacement!=12 & NDPPlacement!=12 
gen ndp_pd2 = (abs(SelfPlacement - proxyNDP)) if SelfPlacement!=12 & NDPPlacement==12 

gen ndp_pd = .a
replace ndp_pd = ndp_pd1 if ndp_pd1!=.
replace ndp_pd = ndp_pd2 if ndp_pd2!=.

egen sdPD_ndp = sd(ndp_pd)


*****************************************************************************
* TOTAL POPULATION Step 4: Two-Party Utility
*****************************************************************************
*LIB
gen libdu1 = abs(SelfPlacement - LibPlacement) if SelfPlacement!=12 & LibPlacement!=12
gen libdu2 = abs(SelfPlacement - proxyLib) if SelfPlacement!=12 & LibPlacement==12
gen libdu=.a
replace libdu=libdu1 if libdu1!=.
replace libdu=libdu2 if libdu2!=.

*CON
gen condu1= abs(SelfPlacement - ConPlacement) if SelfPlacement!=12 & ConPlacement!=12
gen condu2= abs(SelfPlacement - proxyCon) if SelfPlacement!=12 & ConPlacement==12
gen condu=.a
replace condu=condu1 if condu1!=.
replace condu=condu2 if condu2!=.

gen indiff= abs(libdu - condu)
egen sd_indiff=sd(indiff)

*alienation, indifference, interaction 6/8/2016
order libdu condu, last
egen alien = rowmin(libdu-condu)
egen sd_alien=sd(alien)

gen indiff_nonab = libdu-condu
gen interact = alien*indiff_nonab
egen sd_interact=sd(interact)

******************************************************************************
* TOTAL POPULATION Step 5: Collapsing
******************************************************************************
collapse year sd* (mean) meanSelf=cpspla36 meanLib=cpspla33 meanCon=cpspla34 /*
*/ meanNDP=cpspla31 meanPartyDis=partydis meanPD_lib=lib_pd meanPD_con=con_pd /*
*/ meanPD_ndp=ndp_pd mean_indiff=indiff mean_alien=alien mean_interact=interact [pweight=cesnwgt]
order year mean* sd*
save "AUGUST\2000\2000 total distance.dta", replace

clear
////////






*************************************************************************
*************************************************************************
*************************************************************************
**Distance for religion, 2000
use "AUGUST\2000\2000 edited distance.dta"

**************************************************************************
* RELIGION Step 1: Dropping missing observations
**************************************************************************
count if religion==.
drop if religion==.

save "AUGUST\2000\2000 religion edited distance.dta", replace

collapse year (mean) proxyLib=cpspla33 proxyCon=cpspla34 proxyNDP=cpspla31 [pweight=cesnwgt], by(religion)
gen sub_n="religion"

decode religion, gen(group)
replace group="_1cath" in 1
replace group="_2chr" in 2
replace group="_3other" in 3
replace group="_4nrel" in 4

order year sub_n religion group

drop religion
quietly: reshape wide proxyLib proxyCon proxyNDP, i(year sub_n) j(group) string

save "AUGUST\2000\2000 religion edited weight distance.dta", replace
clear

use "AUGUST\2000\2000 religion edited distance.dta"
merge m:1 year using "AUGUST\2000\2000 religion edited weight distance.dta"
drop _merge

gen proxyLib=.
replace proxyLib=proxyLib_1cath if religion==1
replace proxyLib=proxyLib_2chr if religion==2
replace proxyLib=proxyLib_3other if religion==3
replace proxyLib=proxyLib_4nrel if religion==4

gen proxyCon=.
replace proxyCon=proxyCon_1cath if religion==1
replace proxyCon=proxyCon_2chr if religion==2
replace proxyCon=proxyCon_3other if religion==3
replace proxyCon=proxyCon_4nrel if religion==4

gen proxyNDP=.
replace proxyNDP=proxyNDP_1cath if religion==1
replace proxyNDP=proxyNDP_2chr if religion==2
replace proxyNDP=proxyNDP_3other if religion==3
replace proxyNDP=proxyNDP_4nrel if religion==4

drop proxy*1cath proxy*2chr proxy*3other proxy*4nrel

************************************************************************
* RELIGION Step 2: Means, standard deviations, and distance
************************************************************************
by religion, sort: egen sdSelf = sd(cpspla36)
by religion, sort: egen sdLib = sd(cpspla33)
by religion, sort: egen sdCon = sd(cpspla34)
by religion, sort: egen sdNDP = sd(cpspla31)

gen partydis1 = (abs(SelfPlacement - LibPlacement)) + (abs(SelfPlacement - ConPlacement)) + (abs(SelfPlacement - NDPPlacement)) if SelfPlacement!=12 & LibPlacement!=12 & ConPlacement!=12 & NDPPlacement!=12
*this is for all those who gave placements for all parties

gen partydis2 = (abs(SelfPlacement - proxyLib)) + (abs(SelfPlacement - proxyCon)) + (abs(SelfPlacement - proxyNDP)) if SelfPlacement!=12 & LibPlacement==12 & ConPlacement==12 & NDPPlacement==12
*this is for all those who gave no placements for any party

gen partydis3 = (abs(SelfPlacement - proxyLib)) + (abs(SelfPlacement - ConPlacement)) + (abs(SelfPlacement - NDPPlacement)) if SelfPlacement!=12 & LibPlacement==12 & ConPlacement!=12 & NDPPlacement!=12
*this is for those who answered Con and NDP

gen partydis4 = (abs(SelfPlacement - LibPlacement)) + (abs(SelfPlacement - proxyCon)) + (abs(SelfPlacement - NDPPlacement)) if SelfPlacement!=12 & LibPlacement!=12 & ConPlacement==12 & NDPPlacement!=12
*this is for those who answered Lib and NDP

gen partydis5 = (abs(SelfPlacement - LibPlacement)) + (abs(SelfPlacement - ConPlacement)) + (abs(SelfPlacement - proxyNDP)) if SelfPlacement!=12 & LibPlacement!=12 & ConPlacement!=12 & NDPPlacement==12
*this is for those who answered Lib and Con

gen partydis6 = (abs(SelfPlacement - LibPlacement)) + (abs(SelfPlacement - proxyCon)) + (abs(SelfPlacement - proxyNDP)) if SelfPlacement!=12 & LibPlacement!=12 & ConPlacement==12 & NDPPlacement==12
*this is for those who only answered Lib

gen partydis7 = (abs(SelfPlacement - proxyLib)) + (abs(SelfPlacement - ConPlacement)) + (abs(SelfPlacement - proxyNDP)) if SelfPlacement!=12 & LibPlacement==12 & ConPlacement!=12 & NDPPlacement==12
*this is for those who only answered Con

gen partydis8 = (abs(SelfPlacement - proxyLib)) + (abs(SelfPlacement - proxyCon)) + (abs(SelfPlacement - NDPPlacement)) if SelfPlacement!=12 & LibPlacement==12 & ConPlacement==12 & NDPPlacement!=12
*this is for those who only answered NDP

gen partydis = .a
replace partydis = partydis1 if partydis1!=.
replace partydis = partydis2 if partydis2!=.
replace partydis = partydis3 if partydis3!=.
replace partydis = partydis4 if partydis4!=.
replace partydis = partydis5 if partydis5!=.
replace partydis = partydis6 if partydis6!=.
replace partydis = partydis7 if partydis7!=.
replace partydis = partydis8 if partydis8!=.

by religion, sort: egen sdPartyDis = sd(partydis)

************************************************************************
* RELIGION Step 3: Distance for individual parties, added 9/24/14
************************************************************************
*Liberal
gen lib_pd1 = (abs(SelfPlacement - LibPlacement)) if SelfPlacement!=12 & LibPlacement!=12 
gen lib_pd2 = (abs(SelfPlacement - proxyLib)) if SelfPlacement!=12 & LibPlacement==12 

gen lib_pd = .a
replace lib_pd = lib_pd1 if lib_pd1!=.
replace lib_pd = lib_pd2 if lib_pd2!=.

by religion, sort: egen sdPD_lib = sd(lib_pd)

*Conservative
gen con_pd1 = (abs(SelfPlacement - ConPlacement)) if SelfPlacement!=12 & ConPlacement!=12 
gen con_pd2 = (abs(SelfPlacement - proxyCon)) if SelfPlacement!=12 & ConPlacement==12 

gen con_pd = .a
replace con_pd = con_pd1 if con_pd1!=.
replace con_pd = con_pd2 if con_pd2!=.

by religion, sort: egen sdPD_con = sd(con_pd)

*NDP
gen ndp_pd1 = (abs(SelfPlacement - NDPPlacement)) if SelfPlacement!=12 & NDPPlacement!=12 
gen ndp_pd2 = (abs(SelfPlacement - proxyNDP)) if SelfPlacement!=12 & NDPPlacement==12 

gen ndp_pd = .a
replace ndp_pd = ndp_pd1 if ndp_pd1!=.
replace ndp_pd = ndp_pd2 if ndp_pd2!=.

by religion, sort: egen sdPD_ndp = sd(ndp_pd)

******************************************************************************
* RELIGION Step 4: Two-party utility
******************************************************************************
*LIB
gen libdu1 = abs(SelfPlacement - LibPlacement) if SelfPlacement!=12 & LibPlacement!=12
gen libdu2 = abs(SelfPlacement - proxyLib) if SelfPlacement!=12 & LibPlacement==12
gen libdu=.a
replace libdu=libdu1 if libdu1!=.
replace libdu=libdu2 if libdu2!=.

*CON
gen condu1= abs(SelfPlacement - ConPlacement) if SelfPlacement!=12 & ConPlacement!=12
gen condu2= abs(SelfPlacement - proxyCon) if SelfPlacement!=12 & ConPlacement==12
gen condu=.a
replace condu=condu1 if condu1!=.
replace condu=condu2 if condu2!=.

gen indiff= abs(libdu - condu)
by religion, sort: egen sd_indiff=sd(indiff)

*alienation, indifference, interaction 6/8/2016
order libdu condu, last
egen alien = rowmin(libdu-condu)
by religion, sort: egen sd_alien=sd(alien)

gen indiff_nonab = libdu-condu
gen interact = alien*indiff_nonab
by religion, sort: egen sd_interact=sd(interact)

save "AUGUST\2000\2000 religion distance_2.dta", replace

******************************************************************************
* RELIGION Step 5: Collapsing
******************************************************************************
collapse year sdSelf sdLib sdCon sdNDP sdPartyDis sdPD_lib sdPD_con sdPD_ndp /*
*/ sd_indiff sd_alien sd_interact, by(religion)
gen sub_n="religion"

decode religion, gen(group)
replace group="_1cath" in 1
replace group="_2chr" in 2
replace group="_3other" in 3
replace group="_4nrel" in 4

order year sub_n religion group
drop religion
quietly: reshape wide sdSelf sdLib sdCon sdNDP sdPartyDis sdPD_lib sdPD_con /*
*/ sdPD_ndp sd_indiff sd_alien sd_interact, i(year sub_n) j(group) string
save "AUGUST\2000\2000 religion sd distance.dta", replace
clear

use "AUGUST\2000\2000 religion distance_2.dta"
collapse year (mean) meanSelf=cpspla36 meanLib=cpspla33 meanCon=cpspla34 /*
*/ meanNDP=cpspla31 meanPartyDis=partydis meanPD_lib=lib_pd meanPD_con=con_pd /*
*/ meanPD_ndp=ndp_pd mean_indiff=indiff mean_alien=alien mean_interact=interact [pweight=cesnwgt], by(religion)
gen sub_n="religion"

decode religion, gen(group)
replace group="_1cath" in 1
replace group="_2chr" in 2
replace group="_3other" in 3
replace group="_4nrel" in 4

order year sub_n religion group

drop religion
quietly: reshape wide meanSelf meanLib meanCon meanNDP meanPartyDis meanPD_lib /*
*/ meanPD_con meanPD_ndp mean_indiff mean_alien mean_interact, i(year sub_n) j(group) string
save "AUGUST\2000\2000 religion means distance.dta", replace

merge 1:1 year using "AUGUST\2000\2000 religion sd distance.dta"
drop _merge 
save "AUGUST\2000\2000 religion comp distance.dta", replace
clear








*************************************************************************
*************************************************************************
*************************************************************************
**Distance for region, 2000
use "AUGUST\2000\2000 edited distance.dta"

**************************************************************************
* REGION Step 1: Dropping missing observations
**************************************************************************
count if region==.
drop if region==.

save "AUGUST\2000\2000 region edited distance.dta", replace

collapse year (mean) proxyLib=cpspla33 proxyCon=cpspla34 proxyNDP=cpspla31 [pweight=cesnwgt], by(region)
gen sub_n="region"

decode region, gen(group)
replace group="_1Marit" in 1
replace group="_2Queb" in 2
replace group="_3Ontar" in 3
replace group="_4West" in 4

order year sub_n region group

drop region
quietly: reshape wide proxyLib proxyCon proxyNDP, i(year sub_n) j(group) string

save "AUGUST\2000\2000 region edited weight distance.dta", replace
clear

use "AUGUST\2000\2000 region edited distance.dta"
merge m:1 year using "AUGUST\2000\2000 region edited weight distance.dta"
drop _merge

gen proxyLib=.
replace proxyLib=proxyLib_1Marit if region==1
replace proxyLib=proxyLib_2Queb if region==2
replace proxyLib=proxyLib_3Ontar if region==3
replace proxyLib=proxyLib_4West if region==4

gen proxyCon=.
replace proxyCon=proxyCon_1Marit if region==1
replace proxyCon=proxyCon_2Queb if region==2
replace proxyCon=proxyCon_3Ontar if region==3
replace proxyCon=proxyCon_4West if region==4

gen proxyNDP=.
replace proxyNDP=proxyNDP_1Marit if region==1
replace proxyNDP=proxyNDP_2Queb if region==2
replace proxyNDP=proxyNDP_3Ontar if region==3
replace proxyNDP=proxyNDP_4West if region==4

drop proxy*1Marit proxy*2Queb proxy*3Ontar proxy*4West

************************************************************************
* REGION Step 2: Means, standard deviations, and distance
************************************************************************
by region, sort: egen sdSelf = sd(cpspla36)
by region, sort: egen sdLib = sd(cpspla33)
by region, sort: egen sdCon = sd(cpspla34)
by region, sort: egen sdNDP = sd(cpspla31)

gen partydis1 = (abs(SelfPlacement - LibPlacement)) + (abs(SelfPlacement - ConPlacement)) + (abs(SelfPlacement - NDPPlacement)) if SelfPlacement!=12 & LibPlacement!=12 & ConPlacement!=12 & NDPPlacement!=12
*this is for all those who gave placements for all parties

gen partydis2 = (abs(SelfPlacement - proxyLib)) + (abs(SelfPlacement - proxyCon)) + (abs(SelfPlacement - proxyNDP)) if SelfPlacement!=12 & LibPlacement==12 & ConPlacement==12 & NDPPlacement==12
*this is for all those who gave no placements for any party

gen partydis3 = (abs(SelfPlacement - proxyLib)) + (abs(SelfPlacement - ConPlacement)) + (abs(SelfPlacement - NDPPlacement)) if SelfPlacement!=12 & LibPlacement==12 & ConPlacement!=12 & NDPPlacement!=12
*this is for those who answered Con and NDP

gen partydis4 = (abs(SelfPlacement - LibPlacement)) + (abs(SelfPlacement - proxyCon)) + (abs(SelfPlacement - NDPPlacement)) if SelfPlacement!=12 & LibPlacement!=12 & ConPlacement==12 & NDPPlacement!=12
*this is for those who answered Lib and NDP

gen partydis5 = (abs(SelfPlacement - LibPlacement)) + (abs(SelfPlacement - ConPlacement)) + (abs(SelfPlacement - proxyNDP)) if SelfPlacement!=12 & LibPlacement!=12 & ConPlacement!=12 & NDPPlacement==12
*this is for those who answered Lib and Con

gen partydis6 = (abs(SelfPlacement - LibPlacement)) + (abs(SelfPlacement - proxyCon)) + (abs(SelfPlacement - proxyNDP)) if SelfPlacement!=12 & LibPlacement!=12 & ConPlacement==12 & NDPPlacement==12
*this is for those who only answered Lib

gen partydis7 = (abs(SelfPlacement - proxyLib)) + (abs(SelfPlacement - ConPlacement)) + (abs(SelfPlacement - proxyNDP)) if SelfPlacement!=12 & LibPlacement==12 & ConPlacement!=12 & NDPPlacement==12
*this is for those who only answered Con

gen partydis8 = (abs(SelfPlacement - proxyLib)) + (abs(SelfPlacement - proxyCon)) + (abs(SelfPlacement - NDPPlacement)) if SelfPlacement!=12 & LibPlacement==12 & ConPlacement==12 & NDPPlacement!=12
*this is for those who only answered NDP

gen partydis = .a
replace partydis = partydis1 if partydis1!=.
replace partydis = partydis2 if partydis2!=.
replace partydis = partydis3 if partydis3!=.
replace partydis = partydis4 if partydis4!=.
replace partydis = partydis5 if partydis5!=.
replace partydis = partydis6 if partydis6!=.
replace partydis = partydis7 if partydis7!=.
replace partydis = partydis8 if partydis8!=.

by region, sort: egen sdPartyDis = sd(partydis)

************************************************************************
* REGION Step 3: Distance for individual parties, added 9/24/14
************************************************************************
*Liberal
gen lib_pd1 = (abs(SelfPlacement - LibPlacement)) if SelfPlacement!=12 & LibPlacement!=12 
gen lib_pd2 = (abs(SelfPlacement - proxyLib)) if SelfPlacement!=12 & LibPlacement==12 

gen lib_pd = .a
replace lib_pd = lib_pd1 if lib_pd1!=.
replace lib_pd = lib_pd2 if lib_pd2!=.

by region, sort: egen sdPD_lib = sd(lib_pd)

*Conservative
gen con_pd1 = (abs(SelfPlacement - ConPlacement)) if SelfPlacement!=12 & ConPlacement!=12 
gen con_pd2 = (abs(SelfPlacement - proxyCon)) if SelfPlacement!=12 & ConPlacement==12 

gen con_pd = .a
replace con_pd = con_pd1 if con_pd1!=.
replace con_pd = con_pd2 if con_pd2!=.

by region, sort: egen sdPD_con = sd(con_pd)

*NDP
gen ndp_pd1 = (abs(SelfPlacement - NDPPlacement)) if SelfPlacement!=12 & NDPPlacement!=12 
gen ndp_pd2 = (abs(SelfPlacement - proxyNDP)) if SelfPlacement!=12 & NDPPlacement==12 

gen ndp_pd = .a
replace ndp_pd = ndp_pd1 if ndp_pd1!=.
replace ndp_pd = ndp_pd2 if ndp_pd2!=.

by region, sort: egen sdPD_ndp = sd(ndp_pd)

******************************************************************************
* REGION Step 4: Two-party utility
******************************************************************************
*LIB
gen libdu1 = abs(SelfPlacement - LibPlacement) if SelfPlacement!=12 & LibPlacement!=12
gen libdu2 = abs(SelfPlacement - proxyLib) if SelfPlacement!=12 & LibPlacement==12
gen libdu=.a
replace libdu=libdu1 if libdu1!=.
replace libdu=libdu2 if libdu2!=.

*CON
gen condu1= abs(SelfPlacement - ConPlacement) if SelfPlacement!=12 & ConPlacement!=12
gen condu2= abs(SelfPlacement - proxyCon) if SelfPlacement!=12 & ConPlacement==12
gen condu=.a
replace condu=condu1 if condu1!=.
replace condu=condu2 if condu2!=.

gen indiff= abs(libdu - condu)
by region, sort: egen sd_indiff=sd(indiff)

*alienation, indifference, interaction 6/8/2016
order libdu condu, last
egen alien = rowmin(libdu-condu)
by region, sort: egen sd_alien=sd(alien)

gen indiff_nonab = libdu-condu
gen interact = alien*indiff_nonab
by region, sort: egen sd_interact=sd(interact)

save "AUGUST\2000\2000 region distance_2.dta", replace

******************************************************************************
* REGION Step 5: Collapsing
******************************************************************************
collapse year sdSelf sdLib sdCon sdNDP sdPartyDis sdPD_lib sdPD_con sdPD_ndp /*
*/ sd_indiff sd_alien sd_interact, by(region)
gen sub_n="region"

decode region, gen(group)
replace group="_1Marit" in 1
replace group="_2Queb" in 2
replace group="_3Ontar" in 3
replace group="_4West" in 4

order year sub_n region group
drop region
quietly: reshape wide sdSelf sdLib sdCon sdNDP sdPartyDis sdPD_lib sdPD_con /*
*/  sdPD_ndp sd_indiff sd_alien sd_interact, i(year sub_n) j(group) string
save "AUGUST\2000\2000 region sd distance.dta", replace
clear

use "AUGUST\2000\2000 region distance_2.dta"
collapse year (mean) meanSelf=cpspla36 meanLib=cpspla33 meanCon=cpspla34 /*
*/ meanNDP=cpspla31 meanPartyDis=partydis meanPD_lib=lib_pd meanPD_con=con_pd /*
*/ meanPD_ndp=ndp_pd mean_indiff=indiff mean_alien=alien mean_interact=interact [pweight=cesnwgt], by(region)
gen sub_n="region"

decode region, gen(group)
replace group="_1Marit" in 1
replace group="_2Queb" in 2
replace group="_3Ontar" in 3
replace group="_4West" in 4

order year sub_n region group

drop region
quietly: reshape wide meanSelf meanLib meanCon meanNDP meanPartyDis meanPD_lib /*
*/ meanPD_con meanPD_ndp mean_indiff mean_alien mean_interact, i(year sub_n) j(group) string
save "AUGUST\2000\2000 region means distance.dta", replace

merge 1:1 year using "AUGUST\2000\2000 region sd distance.dta"
drop _merge 
save "AUGUST\2000\2000 region comp distance.dta", replace
clear





*************************************************************************
*************************************************************************
*************************************************************************
**Distance for union, 2000
use "AUGUST\2000\2000 edited distance.dta"

**************************************************************************
* UNION Step 1: Dropping missing observations
**************************************************************************
count if union==.
drop if union==.

save "AUGUST\2000\2000 union edited distance.dta", replace

collapse year (mean) proxyLib=cpspla33 proxyCon=cpspla34 proxyNDP=cpspla31 [pweight=cesnwgt], by(union)
gen sub_n="union"

decode union, gen(group)
replace group="_1union" in 1
replace group="_2nunion" in 2

order year sub_n union group

drop union
quietly: reshape wide proxyLib proxyCon proxyNDP, i(year sub_n) j(group) string

save "AUGUST\2000\2000 union edited weight distance.dta", replace
clear

use "AUGUST\2000\2000 union edited distance.dta"
merge m:1 year using "AUGUST\2000\2000 union edited weight distance.dta"
drop _merge

gen proxyLib=.
replace proxyLib=proxyLib_1union if union==1
replace proxyLib=proxyLib_2nunion if union==2

gen proxyCon=.
replace proxyCon=proxyCon_1union if union==1
replace proxyCon=proxyCon_2nunion if union==2

gen proxyNDP=.
replace proxyNDP=proxyNDP_1union if union==1
replace proxyNDP=proxyNDP_2nunion if union==2

drop proxy*1union proxy*2nunion

************************************************************************
* UNION Step 2: Means, standard deviations, and distance
************************************************************************
by union, sort: egen sdSelf = sd(cpspla36)
by union, sort: egen sdLib = sd(cpspla33)
by union, sort: egen sdCon = sd(cpspla34)
by union, sort: egen sdNDP = sd(cpspla31)

gen partydis1 = (abs(SelfPlacement - LibPlacement)) + (abs(SelfPlacement - ConPlacement)) + (abs(SelfPlacement - NDPPlacement)) if SelfPlacement!=12 & LibPlacement!=12 & ConPlacement!=12 & NDPPlacement!=12
*this is for all those who gave placements for all parties

gen partydis2 = (abs(SelfPlacement - proxyLib)) + (abs(SelfPlacement - proxyCon)) + (abs(SelfPlacement - proxyNDP)) if SelfPlacement!=12 & LibPlacement==12 & ConPlacement==12 & NDPPlacement==12
*this is for all those who gave no placements for any party

gen partydis3 = (abs(SelfPlacement - proxyLib)) + (abs(SelfPlacement - ConPlacement)) + (abs(SelfPlacement - NDPPlacement)) if SelfPlacement!=12 & LibPlacement==12 & ConPlacement!=12 & NDPPlacement!=12
*this is for those who answered Con and NDP

gen partydis4 = (abs(SelfPlacement - LibPlacement)) + (abs(SelfPlacement - proxyCon)) + (abs(SelfPlacement - NDPPlacement)) if SelfPlacement!=12 & LibPlacement!=12 & ConPlacement==12 & NDPPlacement!=12
*this is for those who answered Lib and NDP

gen partydis5 = (abs(SelfPlacement - LibPlacement)) + (abs(SelfPlacement - ConPlacement)) + (abs(SelfPlacement - proxyNDP)) if SelfPlacement!=12 & LibPlacement!=12 & ConPlacement!=12 & NDPPlacement==12
*this is for those who answered Lib and Con

gen partydis6 = (abs(SelfPlacement - LibPlacement)) + (abs(SelfPlacement - proxyCon)) + (abs(SelfPlacement - proxyNDP)) if SelfPlacement!=12 & LibPlacement!=12 & ConPlacement==12 & NDPPlacement==12
*this is for those who only answered Lib

gen partydis7 = (abs(SelfPlacement - proxyLib)) + (abs(SelfPlacement - ConPlacement)) + (abs(SelfPlacement - proxyNDP)) if SelfPlacement!=12 & LibPlacement==12 & ConPlacement!=12 & NDPPlacement==12
*this is for those who only answered Con

gen partydis8 = (abs(SelfPlacement - proxyLib)) + (abs(SelfPlacement - proxyCon)) + (abs(SelfPlacement - NDPPlacement)) if SelfPlacement!=12 & LibPlacement==12 & ConPlacement==12 & NDPPlacement!=12
*this is for those who only answered NDP

gen partydis = .a
replace partydis = partydis1 if partydis1!=.
replace partydis = partydis2 if partydis2!=.
replace partydis = partydis3 if partydis3!=.
replace partydis = partydis4 if partydis4!=.
replace partydis = partydis5 if partydis5!=.
replace partydis = partydis6 if partydis6!=.
replace partydis = partydis7 if partydis7!=.
replace partydis = partydis8 if partydis8!=.

by union, sort: egen sdPartyDis = sd(partydis)

************************************************************************
* UNION Step 3: Distance for individual parties, added 9/24/14
************************************************************************
*Liberal
gen lib_pd1 = (abs(SelfPlacement - LibPlacement)) if SelfPlacement!=12 & LibPlacement!=12 
gen lib_pd2 = (abs(SelfPlacement - proxyLib)) if SelfPlacement!=12 & LibPlacement==12 

gen lib_pd = .a
replace lib_pd = lib_pd1 if lib_pd1!=.
replace lib_pd = lib_pd2 if lib_pd2!=.

by union, sort: egen sdPD_lib = sd(lib_pd)

*Conservative
gen con_pd1 = (abs(SelfPlacement - ConPlacement)) if SelfPlacement!=12 & ConPlacement!=12 
gen con_pd2 = (abs(SelfPlacement - proxyCon)) if SelfPlacement!=12 & ConPlacement==12 

gen con_pd = .a
replace con_pd = con_pd1 if con_pd1!=.
replace con_pd = con_pd2 if con_pd2!=.

by union, sort: egen sdPD_con = sd(con_pd)

*NDP
gen ndp_pd1 = (abs(SelfPlacement - NDPPlacement)) if SelfPlacement!=12 & NDPPlacement!=12 
gen ndp_pd2 = (abs(SelfPlacement - proxyNDP)) if SelfPlacement!=12 & NDPPlacement==12 

gen ndp_pd = .a
replace ndp_pd = ndp_pd1 if ndp_pd1!=.
replace ndp_pd = ndp_pd2 if ndp_pd2!=.

by union, sort: egen sdPD_ndp = sd(ndp_pd)

******************************************************************************
* UNION Step 4: Two-party utility
******************************************************************************
*LIB
gen libdu1 = abs(SelfPlacement - LibPlacement) if SelfPlacement!=12 & LibPlacement!=12
gen libdu2 = abs(SelfPlacement - proxyLib) if SelfPlacement!=12 & LibPlacement==12
gen libdu=.a
replace libdu=libdu1 if libdu1!=.
replace libdu=libdu2 if libdu2!=.

*CON
gen condu1= abs(SelfPlacement - ConPlacement) if SelfPlacement!=12 & ConPlacement!=12
gen condu2= abs(SelfPlacement - proxyCon) if SelfPlacement!=12 & ConPlacement==12
gen condu=.a
replace condu=condu1 if condu1!=.
replace condu=condu2 if condu2!=.

gen indiff= abs(libdu - condu)
by union, sort: egen sd_indiff=sd(indiff)

*alienation, indifference, interaction 6/8/2016
order libdu condu, last
egen alien = rowmin(libdu-condu)
by union, sort: egen sd_alien=sd(alien)

gen indiff_nonab = libdu-condu
gen interact = alien*indiff_nonab
by union, sort: egen sd_interact=sd(interact)

save "AUGUST\2000\2000 union distance_2.dta", replace

******************************************************************************
* UNION Step 5: Collapsing
******************************************************************************
collapse year sdSelf sdLib sdCon sdNDP sdPartyDis sdPD_lib sdPD_con sdPD_ndp /*
*/ sd_indiff sd_alien sd_interact, by(union)
gen sub_n="union"

decode union, gen(group)
replace group="_1union" in 1
replace group="_2nunion" in 2

order year sub_n union group
drop union
quietly: reshape wide sdSelf sdLib sdCon sdNDP sdPartyDis sdPD_lib sdPD_con /*
*/ sdPD_ndp sd_indiff sd_alien sd_interact, i(year sub_n) j(group) string
save "AUGUST\2000\2000 union sd distance.dta", replace
clear

use "AUGUST\2000\2000 union distance_2.dta"
collapse year (mean) meanSelf=cpspla36 meanLib=cpspla33 meanCon=cpspla34 /*
*/ meanNDP=cpspla31 meanPartyDis=partydis meanPD_lib=lib_pd meanPD_con=con_pd /*
*/ meanPD_ndp=ndp_pd mean_indiff=indiff mean_alien=alien mean_interact=interact [pweight=cesnwgt], by(union)
gen sub_n="union"

decode union, gen(group)
replace group="_1union" in 1
replace group="_2nunion" in 2

order year sub_n union group

drop union
quietly: reshape wide meanSelf meanLib meanCon meanNDP meanPartyDis meanPD_lib /*
*/ meanPD_con meanPD_ndp mean_indiff mean_alien mean_interact, i(year sub_n) j(group) string
save "AUGUST\2000\2000 union means distance.dta", replace

merge 1:1 year using "AUGUST\2000\2000 union sd distance.dta"
drop _merge 
save "AUGUST\2000\2000 union comp distance.dta", replace
clear




*************************************************************************
*************************************************************************
*************************************************************************
**Distance for ethnicity, 2000
use "AUGUST\2000\2000 edited distance.dta"

**************************************************************************
* ETHNICITY Step 1: Dropping missing observations
**************************************************************************
count if ethnicity==.
drop if ethnicity==.

save "AUGUST\2000\2000 ethnicity edited distance.dta", replace

collapse year (mean) proxyLib=cpspla33 proxyCon=cpspla34 proxyNDP=cpspla31 [pweight=cesnwgt], by(ethnicity)
gen sub_n="ethnicity"

decode ethnicity, gen(group)
replace group="_1Euro" in 1
replace group="_2nEuro" in 2

order year sub_n ethnicity group

drop ethnicity
quietly: reshape wide proxyLib proxyCon proxyNDP, i(year sub_n) j(group) string

save "AUGUST\2000\2000 ethnicity edited weight distance.dta", replace
clear

use "AUGUST\2000\2000 ethnicity edited distance.dta"
merge m:1 year using "AUGUST\2000\2000 ethnicity edited weight distance.dta"
drop _merge

gen proxyLib=.
replace proxyLib=proxyLib_1Euro if ethnicity==1
replace proxyLib=proxyLib_2nEuro if ethnicity==2

gen proxyCon=.
replace proxyCon=proxyCon_1Euro if ethnicity==1
replace proxyCon=proxyCon_2nEuro if ethnicity==2

gen proxyNDP=.
replace proxyNDP=proxyNDP_1Euro if ethnicity==1
replace proxyNDP=proxyNDP_2nEuro if ethnicity==2

drop proxy*1Euro proxy*2nEuro

************************************************************************
* ETHNICITY Step 2: Means, standard deviations, and distance
************************************************************************
by ethnicity, sort: egen sdSelf = sd(cpspla36)
by ethnicity, sort: egen sdLib = sd(cpspla33)
by ethnicity, sort: egen sdCon = sd(cpspla34)
by ethnicity, sort: egen sdNDP = sd(cpspla31)

gen partydis1 = (abs(SelfPlacement - LibPlacement)) + (abs(SelfPlacement - ConPlacement)) + (abs(SelfPlacement - NDPPlacement)) if SelfPlacement!=12 & LibPlacement!=12 & ConPlacement!=12 & NDPPlacement!=12
*this is for all those who gave placements for all parties

gen partydis2 = (abs(SelfPlacement - proxyLib)) + (abs(SelfPlacement - proxyCon)) + (abs(SelfPlacement - proxyNDP)) if SelfPlacement!=12 & LibPlacement==12 & ConPlacement==12 & NDPPlacement==12
*this is for all those who gave no placements for any party

gen partydis3 = (abs(SelfPlacement - proxyLib)) + (abs(SelfPlacement - ConPlacement)) + (abs(SelfPlacement - NDPPlacement)) if SelfPlacement!=12 & LibPlacement==12 & ConPlacement!=12 & NDPPlacement!=12
*this is for those who answered Con and NDP

gen partydis4 = (abs(SelfPlacement - LibPlacement)) + (abs(SelfPlacement - proxyCon)) + (abs(SelfPlacement - NDPPlacement)) if SelfPlacement!=12 & LibPlacement!=12 & ConPlacement==12 & NDPPlacement!=12
*this is for those who answered Lib and NDP

gen partydis5 = (abs(SelfPlacement - LibPlacement)) + (abs(SelfPlacement - ConPlacement)) + (abs(SelfPlacement - proxyNDP)) if SelfPlacement!=12 & LibPlacement!=12 & ConPlacement!=12 & NDPPlacement==12
*this is for those who answered Lib and Con

gen partydis6 = (abs(SelfPlacement - LibPlacement)) + (abs(SelfPlacement - proxyCon)) + (abs(SelfPlacement - proxyNDP)) if SelfPlacement!=12 & LibPlacement!=12 & ConPlacement==12 & NDPPlacement==12
*this is for those who only answered Lib

gen partydis7 = (abs(SelfPlacement - proxyLib)) + (abs(SelfPlacement - ConPlacement)) + (abs(SelfPlacement - proxyNDP)) if SelfPlacement!=12 & LibPlacement==12 & ConPlacement!=12 & NDPPlacement==12
*this is for those who only answered Con

gen partydis8 = (abs(SelfPlacement - proxyLib)) + (abs(SelfPlacement - proxyCon)) + (abs(SelfPlacement - NDPPlacement)) if SelfPlacement!=12 & LibPlacement==12 & ConPlacement==12 & NDPPlacement!=12
*this is for those who only answered NDP

gen partydis = .a
replace partydis = partydis1 if partydis1!=.
replace partydis = partydis2 if partydis2!=.
replace partydis = partydis3 if partydis3!=.
replace partydis = partydis4 if partydis4!=.
replace partydis = partydis5 if partydis5!=.
replace partydis = partydis6 if partydis6!=.
replace partydis = partydis7 if partydis7!=.
replace partydis = partydis8 if partydis8!=.

by ethnicity, sort: egen sdPartyDis = sd(partydis)

************************************************************************
* ETHNICITY Step 3: Distance for individual parties, added 9/24/14
************************************************************************
*Liberal
gen lib_pd1 = (abs(SelfPlacement - LibPlacement)) if SelfPlacement!=12 & LibPlacement!=12 
gen lib_pd2 = (abs(SelfPlacement - proxyLib)) if SelfPlacement!=12 & LibPlacement==12 

gen lib_pd = .a
replace lib_pd = lib_pd1 if lib_pd1!=.
replace lib_pd = lib_pd2 if lib_pd2!=.

by ethnicity, sort: egen sdPD_lib = sd(lib_pd)

*Conservative
gen con_pd1 = (abs(SelfPlacement - ConPlacement)) if SelfPlacement!=12 & ConPlacement!=12 
gen con_pd2 = (abs(SelfPlacement - proxyCon)) if SelfPlacement!=12 & ConPlacement==12 

gen con_pd = .a
replace con_pd = con_pd1 if con_pd1!=.
replace con_pd = con_pd2 if con_pd2!=.

by ethnicity, sort: egen sdPD_con = sd(con_pd)

*NDP
gen ndp_pd1 = (abs(SelfPlacement - NDPPlacement)) if SelfPlacement!=12 & NDPPlacement!=12 
gen ndp_pd2 = (abs(SelfPlacement - proxyNDP)) if SelfPlacement!=12 & NDPPlacement==12 

gen ndp_pd = .a
replace ndp_pd = ndp_pd1 if ndp_pd1!=.
replace ndp_pd = ndp_pd2 if ndp_pd2!=.

by ethnicity, sort: egen sdPD_ndp = sd(ndp_pd)

******************************************************************************
* ETHNICITY Step 4: Two-party utility
******************************************************************************
*LIB
gen libdu1 = abs(SelfPlacement - LibPlacement) if SelfPlacement!=12 & LibPlacement!=12
gen libdu2 = abs(SelfPlacement - proxyLib) if SelfPlacement!=12 & LibPlacement==12
gen libdu=.a
replace libdu=libdu1 if libdu1!=.
replace libdu=libdu2 if libdu2!=.

*CON
gen condu1= abs(SelfPlacement - ConPlacement) if SelfPlacement!=12 & ConPlacement!=12
gen condu2= abs(SelfPlacement - proxyCon) if SelfPlacement!=12 & ConPlacement==12
gen condu=.a
replace condu=condu1 if condu1!=.
replace condu=condu2 if condu2!=.

gen indiff= abs(libdu - condu)
by ethnicity, sort: egen sd_indiff=sd(indiff)

*alienation, indifference, interaction 6/8/2016
order libdu condu, last
egen alien = rowmin(libdu-condu)
by ethnicity, sort: egen sd_alien=sd(alien)

gen indiff_nonab = libdu-condu
gen interact = alien*indiff_nonab
by ethnicity, sort: egen sd_interact=sd(interact)

save "AUGUST\2000\2000 ethnicity distance_2.dta", replace

******************************************************************************
* ETHNICITY Step 5: Collapsing
******************************************************************************
collapse year sdSelf sdLib sdCon sdNDP sdPartyDis sdPD_lib sdPD_con sdPD_ndp /*
*/ sd_indiff sd_alien sd_interact, by(ethnicity)
gen sub_n="ethnicity"

decode ethnicity, gen(group)
replace group="_1Euro" in 1
replace group="_2nEuro" in 2

order year sub_n ethnicity group
drop ethnicity
quietly: reshape wide sdSelf sdLib sdCon sdNDP sdPartyDis sdPD_lib sdPD_con /*
*/ sdPD_ndp sd_indiff sd_alien sd_interact, i(year sub_n) j(group) string
save "AUGUST\2000\2000 ethnicity sd distance.dta", replace
clear

use "AUGUST\2000\2000 ethnicity distance_2.dta"
collapse year (mean) meanSelf=cpspla36 meanLib=cpspla33 meanCon=cpspla34 /*
*/ meanNDP=cpspla31 meanPartyDis=partydis meanPD_lib=lib_pd meanPD_con=con_pd /*
*/ meanPD_ndp=ndp_pd mean_indiff=indiff mean_alien=alien mean_interact=interact [pweight=cesnwgt], by(ethnicity)
gen sub_n="ethnicity"

decode ethnicity, gen(group)
replace group="_1Euro" in 1
replace group="_2nEuro" in 2

order year sub_n ethnicity group

drop ethnicity
quietly: reshape wide meanSelf meanLib meanCon meanNDP meanPartyDis meanPD_lib /*
*/ meanPD_con meanPD_ndp mean_indiff mean_alien mean_interact, i(year sub_n) j(group) string
save "AUGUST\2000\2000 ethnicity means distance.dta", replace

merge 1:1 year using "AUGUST\2000\2000 ethnicity sd distance.dta"
drop _merge 
save "AUGUST\2000\2000 ethnicity comp distance.dta", replace
clear






*************************************************************************
*************************************************************************
*************************************************************************
**Distance for partisan, 2000
use "AUGUST\2000\2000 edited distance.dta"

**************************************************************************
* PARTISAN Step 1: Dropping missing observations
**************************************************************************
count if partisan==.
drop if partisan==.

save "AUGUST\2000\2000 partisan edited distance.dta", replace

collapse year (mean) proxyLib=cpspla33 proxyCon=cpspla34 proxyNDP=cpspla31 [pweight=cesnwgt], by(partisan)
gen sub_n="partisan"

decode partisan, gen(group)
replace group="_1LibPar" in 1
replace group="_2ConPar" in 2
replace group="_3NDPPar" in 3
replace group="_4OtherPar" in 4

order year sub_n partisan group

drop partisan
quietly: reshape wide proxyLib proxyCon proxyNDP, i(year sub_n) j(group) string

save "AUGUST\2000\2000 partisan edited weight distance.dta", replace
clear

use "AUGUST\2000\2000 partisan edited distance.dta"
merge m:1 year using "AUGUST\2000\2000 partisan edited weight distance.dta"
drop _merge

gen proxyLib=.
replace proxyLib=proxyLib_1LibPar if partisan==1
replace proxyLib=proxyLib_2ConPar if partisan==2
replace proxyLib=proxyLib_3NDPPar if partisan==3
replace proxyLib=proxyLib_4OtherPar if partisan==4

gen proxyCon=.
replace proxyCon=proxyCon_1LibPar if partisan==1
replace proxyCon=proxyCon_2ConPar if partisan==2
replace proxyCon=proxyCon_3NDPPar if partisan==3
replace proxyCon=proxyCon_4OtherPar if partisan==4

gen proxyNDP=.
replace proxyNDP=proxyNDP_1LibPar if partisan==1
replace proxyNDP=proxyNDP_2ConPar if partisan==2
replace proxyNDP=proxyNDP_3NDPPar if partisan==3
replace proxyNDP=proxyNDP_4OtherPar if partisan==4

drop proxy*1LibPar proxy*2ConPar proxy*3NDPPar proxy*4OtherPar

************************************************************************
* PARTISAN Step 2: Means, standard deviations, and distance
************************************************************************
by partisan, sort: egen sdSelf = sd(cpspla36)
by partisan, sort: egen sdLib = sd(cpspla33)
by partisan, sort: egen sdCon = sd(cpspla34)
by partisan, sort: egen sdNDP = sd(cpspla31)

gen partydis1 = (abs(SelfPlacement - LibPlacement)) + (abs(SelfPlacement - ConPlacement)) + (abs(SelfPlacement - NDPPlacement)) if SelfPlacement!=12 & LibPlacement!=12 & ConPlacement!=12 & NDPPlacement!=12
*this is for all those who gave placements for all parties

gen partydis2 = (abs(SelfPlacement - proxyLib)) + (abs(SelfPlacement - proxyCon)) + (abs(SelfPlacement - proxyNDP)) if SelfPlacement!=12 & LibPlacement==12 & ConPlacement==12 & NDPPlacement==12
*this is for all those who gave no placements for any party

gen partydis3 = (abs(SelfPlacement - proxyLib)) + (abs(SelfPlacement - ConPlacement)) + (abs(SelfPlacement - NDPPlacement)) if SelfPlacement!=12 & LibPlacement==12 & ConPlacement!=12 & NDPPlacement!=12
*this is for those who answered Con and NDP

gen partydis4 = (abs(SelfPlacement - LibPlacement)) + (abs(SelfPlacement - proxyCon)) + (abs(SelfPlacement - NDPPlacement)) if SelfPlacement!=12 & LibPlacement!=12 & ConPlacement==12 & NDPPlacement!=12
*this is for those who answered Lib and NDP

gen partydis5 = (abs(SelfPlacement - LibPlacement)) + (abs(SelfPlacement - ConPlacement)) + (abs(SelfPlacement - proxyNDP)) if SelfPlacement!=12 & LibPlacement!=12 & ConPlacement!=12 & NDPPlacement==12
*this is for those who answered Lib and Con

gen partydis6 = (abs(SelfPlacement - LibPlacement)) + (abs(SelfPlacement - proxyCon)) + (abs(SelfPlacement - proxyNDP)) if SelfPlacement!=12 & LibPlacement!=12 & ConPlacement==12 & NDPPlacement==12
*this is for those who only answered Lib

gen partydis7 = (abs(SelfPlacement - proxyLib)) + (abs(SelfPlacement - ConPlacement)) + (abs(SelfPlacement - proxyNDP)) if SelfPlacement!=12 & LibPlacement==12 & ConPlacement!=12 & NDPPlacement==12
*this is for those who only answered Con

gen partydis8 = (abs(SelfPlacement - proxyLib)) + (abs(SelfPlacement - proxyCon)) + (abs(SelfPlacement - NDPPlacement)) if SelfPlacement!=12 & LibPlacement==12 & ConPlacement==12 & NDPPlacement!=12
*this is for those who only answered NDP

gen partydis = .a
replace partydis = partydis1 if partydis1!=.
replace partydis = partydis2 if partydis2!=.
replace partydis = partydis3 if partydis3!=.
replace partydis = partydis4 if partydis4!=.
replace partydis = partydis5 if partydis5!=.
replace partydis = partydis6 if partydis6!=.
replace partydis = partydis7 if partydis7!=.
replace partydis = partydis8 if partydis8!=.

by partisan, sort: egen sdPartyDis = sd(partydis)

************************************************************************
* PARTISAN Step 3: Distance for individual parties, added 9/24/14
************************************************************************
*Liberal
gen lib_pd1 = (abs(SelfPlacement - LibPlacement)) if SelfPlacement!=12 & LibPlacement!=12 
gen lib_pd2 = (abs(SelfPlacement - proxyLib)) if SelfPlacement!=12 & LibPlacement==12 

gen lib_pd = .a
replace lib_pd = lib_pd1 if lib_pd1!=.
replace lib_pd = lib_pd2 if lib_pd2!=.

by partisan, sort: egen sdPD_lib = sd(lib_pd)

*Conservative
gen con_pd1 = (abs(SelfPlacement - ConPlacement)) if SelfPlacement!=12 & ConPlacement!=12 
gen con_pd2 = (abs(SelfPlacement - proxyCon)) if SelfPlacement!=12 & ConPlacement==12 

gen con_pd = .a
replace con_pd = con_pd1 if con_pd1!=.
replace con_pd = con_pd2 if con_pd2!=.

by partisan, sort: egen sdPD_con = sd(con_pd)

*NDP
gen ndp_pd1 = (abs(SelfPlacement - NDPPlacement)) if SelfPlacement!=12 & NDPPlacement!=12 
gen ndp_pd2 = (abs(SelfPlacement - proxyNDP)) if SelfPlacement!=12 & NDPPlacement==12 

gen ndp_pd = .a
replace ndp_pd = ndp_pd1 if ndp_pd1!=.
replace ndp_pd = ndp_pd2 if ndp_pd2!=.

by partisan, sort: egen sdPD_ndp = sd(ndp_pd)

******************************************************************************
* PARTISAN Step 4: Two-party utility
******************************************************************************
*LIB
gen libdu1 = abs(SelfPlacement - LibPlacement) if SelfPlacement!=12 & LibPlacement!=12
gen libdu2 = abs(SelfPlacement - proxyLib) if SelfPlacement!=12 & LibPlacement==12
gen libdu=.a
replace libdu=libdu1 if libdu1!=.
replace libdu=libdu2 if libdu2!=.

*CON
gen condu1= abs(SelfPlacement - ConPlacement) if SelfPlacement!=12 & ConPlacement!=12
gen condu2= abs(SelfPlacement - proxyCon) if SelfPlacement!=12 & ConPlacement==12
gen condu=.a
replace condu=condu1 if condu1!=.
replace condu=condu2 if condu2!=.

gen indiff= abs(libdu - condu)
by partisan, sort: egen sd_indiff=sd(indiff)

*alienation, indifference, interaction 6/8/2016
order libdu condu, last
egen alien = rowmin(libdu-condu)
by partisan, sort: egen sd_alien=sd(alien)

gen indiff_nonab = libdu-condu
gen interact = alien*indiff_nonab
by partisan, sort: egen sd_interact=sd(interact)

save "AUGUST\2000\2000 partisan distance_2.dta", replace

******************************************************************************
* PARTISAN Step 5: Collapsing
******************************************************************************
collapse year sdSelf sdLib sdCon sdNDP sdPartyDis sdPD_lib sdPD_con sdPD_ndp /*
*/ sd_indiff sd_alien sd_interact, by(partisan)
gen sub_n="partisan"

decode partisan, gen(group)
replace group="_1LibPar" in 1
replace group="_2ConPar" in 2
replace group="_3NDPPar" in 3
replace group="_4OtherPar" in 4

order year sub_n partisan group
drop partisan
quietly: reshape wide sdSelf sdLib sdCon sdNDP sdPartyDis sdPD_lib sdPD_con /*
*/ sdPD_ndp sd_indiff sd_alien sd_interact, i(year sub_n) j(group) string
save "AUGUST\2000\2000 partisan sd distance.dta", replace
clear

use "AUGUST\2000\2000 partisan distance_2.dta"
collapse year (mean) meanSelf=cpspla36 meanLib=cpspla33 meanCon=cpspla34 /*
*/ meanNDP=cpspla31 meanPartyDis=partydis meanPD_lib=lib_pd meanPD_con=con_pd /*
*/ meanPD_ndp=ndp_pd mean_indiff=indiff mean_alien=alien mean_interact=interact [pweight=cesnwgt], by(partisan)
gen sub_n="partisan"

decode partisan, gen(group)
replace group="_1LibPar" in 1
replace group="_2ConPar" in 2
replace group="_3NDPPar" in 3
replace group="_4OtherPar" in 4

order year sub_n partisan group

drop partisan
quietly: reshape wide meanSelf meanLib meanCon meanNDP meanPartyDis meanPD_lib /*
*/ meanPD_con meanPD_ndp mean_indiff mean_alien mean_interact, i(year sub_n) j(group) string
save "AUGUST\2000\2000 partisan means distance.dta", replace

merge 1:1 year using "AUGUST\2000\2000 partisan sd distance.dta"
drop _merge 
save "AUGUST\2000\2000 partisan comp distance.dta", replace
clear





*************************************************************************
*************************************************************************
*************************************************************************
**Distance for type, 2000
use "AUGUST\2000\2000 edited distance.dta"

**************************************************************************
* TYPE Step 1: Dropping missing observations
**************************************************************************
count if type==.
drop if type==.

save "AUGUST\2000\2000 type edited distance.dta", replace

collapse year (mean) proxyLib=cpspla33 proxyCon=cpspla34 proxyNDP=cpspla31 [pweight=cesnwgt], by(type)
gen sub_n="type"

decode type, gen(group)
replace group="_1urban" in 1
replace group="_2nurban" in 2

order year sub_n type group

drop type
quietly: reshape wide proxyLib proxyCon proxyNDP, i(year sub_n) j(group) string

save "AUGUST\2000\2000 type edited weight distance.dta", replace
clear

use "AUGUST\2000\2000 type edited distance.dta"
merge m:1 year using "AUGUST\2000\2000 type edited weight distance.dta"
drop _merge

gen proxyLib=.
replace proxyLib=proxyLib_1urban if type==1
replace proxyLib=proxyLib_2nurban if type==2

gen proxyCon=.
replace proxyCon=proxyCon_1urban if type==1
replace proxyCon=proxyCon_2nurban if type==2

gen proxyNDP=.
replace proxyNDP=proxyNDP_1urban if type==1
replace proxyNDP=proxyNDP_2nurban if type==2

drop proxy*1urban proxy*2nurban

************************************************************************
* TYPE Step 2: Means, standard deviations, and distance
************************************************************************
by type, sort: egen sdSelf = sd(cpspla36)
by type, sort: egen sdLib = sd(cpspla33)
by type, sort: egen sdCon = sd(cpspla34)
by type, sort: egen sdNDP = sd(cpspla31)

gen partydis1 = (abs(SelfPlacement - LibPlacement)) + (abs(SelfPlacement - ConPlacement)) + (abs(SelfPlacement - NDPPlacement)) if SelfPlacement!=12 & LibPlacement!=12 & ConPlacement!=12 & NDPPlacement!=12
*this is for all those who gave placements for all parties

gen partydis2 = (abs(SelfPlacement - proxyLib)) + (abs(SelfPlacement - proxyCon)) + (abs(SelfPlacement - proxyNDP)) if SelfPlacement!=12 & LibPlacement==12 & ConPlacement==12 & NDPPlacement==12
*this is for all those who gave no placements for any party

gen partydis3 = (abs(SelfPlacement - proxyLib)) + (abs(SelfPlacement - ConPlacement)) + (abs(SelfPlacement - NDPPlacement)) if SelfPlacement!=12 & LibPlacement==12 & ConPlacement!=12 & NDPPlacement!=12
*this is for those who answered Con and NDP

gen partydis4 = (abs(SelfPlacement - LibPlacement)) + (abs(SelfPlacement - proxyCon)) + (abs(SelfPlacement - NDPPlacement)) if SelfPlacement!=12 & LibPlacement!=12 & ConPlacement==12 & NDPPlacement!=12
*this is for those who answered Lib and NDP

gen partydis5 = (abs(SelfPlacement - LibPlacement)) + (abs(SelfPlacement - ConPlacement)) + (abs(SelfPlacement - proxyNDP)) if SelfPlacement!=12 & LibPlacement!=12 & ConPlacement!=12 & NDPPlacement==12
*this is for those who answered Lib and Con

gen partydis6 = (abs(SelfPlacement - LibPlacement)) + (abs(SelfPlacement - proxyCon)) + (abs(SelfPlacement - proxyNDP)) if SelfPlacement!=12 & LibPlacement!=12 & ConPlacement==12 & NDPPlacement==12
*this is for those who only answered Lib

gen partydis7 = (abs(SelfPlacement - proxyLib)) + (abs(SelfPlacement - ConPlacement)) + (abs(SelfPlacement - proxyNDP)) if SelfPlacement!=12 & LibPlacement==12 & ConPlacement!=12 & NDPPlacement==12
*this is for those who only answered Con

gen partydis8 = (abs(SelfPlacement - proxyLib)) + (abs(SelfPlacement - proxyCon)) + (abs(SelfPlacement - NDPPlacement)) if SelfPlacement!=12 & LibPlacement==12 & ConPlacement==12 & NDPPlacement!=12
*this is for those who only answered NDP

gen partydis = .a
replace partydis = partydis1 if partydis1!=.
replace partydis = partydis2 if partydis2!=.
replace partydis = partydis3 if partydis3!=.
replace partydis = partydis4 if partydis4!=.
replace partydis = partydis5 if partydis5!=.
replace partydis = partydis6 if partydis6!=.
replace partydis = partydis7 if partydis7!=.
replace partydis = partydis8 if partydis8!=.

by type, sort: egen sdPartyDis = sd(partydis)

************************************************************************
* TYPE Step 3: Distance for individual parties, added 9/24/14
************************************************************************
*Liberal
gen lib_pd1 = (abs(SelfPlacement - LibPlacement)) if SelfPlacement!=12 & LibPlacement!=12 
gen lib_pd2 = (abs(SelfPlacement - proxyLib)) if SelfPlacement!=12 & LibPlacement==12 

gen lib_pd = .a
replace lib_pd = lib_pd1 if lib_pd1!=.
replace lib_pd = lib_pd2 if lib_pd2!=.

by type, sort: egen sdPD_lib = sd(lib_pd)

*Conservative
gen con_pd1 = (abs(SelfPlacement - ConPlacement)) if SelfPlacement!=12 & ConPlacement!=12 
gen con_pd2 = (abs(SelfPlacement - proxyCon)) if SelfPlacement!=12 & ConPlacement==12 

gen con_pd = .a
replace con_pd = con_pd1 if con_pd1!=.
replace con_pd = con_pd2 if con_pd2!=.

by type, sort: egen sdPD_con = sd(con_pd)

*NDP
gen ndp_pd1 = (abs(SelfPlacement - NDPPlacement)) if SelfPlacement!=12 & NDPPlacement!=12 
gen ndp_pd2 = (abs(SelfPlacement - proxyNDP)) if SelfPlacement!=12 & NDPPlacement==12 

gen ndp_pd = .a
replace ndp_pd = ndp_pd1 if ndp_pd1!=.
replace ndp_pd = ndp_pd2 if ndp_pd2!=.

by type, sort: egen sdPD_ndp = sd(ndp_pd)

******************************************************************************
* TYPE Step 4: Two-party utility
******************************************************************************
*LIB
gen libdu1 = abs(SelfPlacement - LibPlacement) if SelfPlacement!=12 & LibPlacement!=12
gen libdu2 = abs(SelfPlacement - proxyLib) if SelfPlacement!=12 & LibPlacement==12
gen libdu=.a
replace libdu=libdu1 if libdu1!=.
replace libdu=libdu2 if libdu2!=.

*CON
gen condu1= abs(SelfPlacement - ConPlacement) if SelfPlacement!=12 & ConPlacement!=12
gen condu2= abs(SelfPlacement - proxyCon) if SelfPlacement!=12 & ConPlacement==12
gen condu=.a
replace condu=condu1 if condu1!=.
replace condu=condu2 if condu2!=.

gen indiff= abs(libdu - condu)
by type, sort: egen sd_indiff=sd(indiff)

*alienation, indifference, interaction 6/8/2016
order libdu condu, last
egen alien = rowmin(libdu-condu)
by type, sort: egen sd_alien=sd(alien)

gen indiff_nonab = libdu-condu
gen interact = alien*indiff_nonab
by type, sort: egen sd_interact=sd(interact)

save "AUGUST\2000\2000 type distance_2.dta", replace

******************************************************************************
* TYPE Step 5: Collapsing
******************************************************************************
collapse year sdSelf sdLib sdCon sdNDP sdPartyDis sdPD_lib sdPD_con sdPD_ndp /*
*/ sd_indiff sd_alien sd_interact, by(type)
gen sub_n="type"

decode type, gen(group)
replace group="_1urban" in 1
replace group="_2nurban" in 2

order year sub_n type group
drop type
quietly: reshape wide sdSelf sdLib sdCon sdNDP sdPartyDis sdPD_lib sdPD_con /*
*/ sdPD_ndp sd_indiff sd_alien sd_interact, i(year sub_n) j(group) string
save "AUGUST\2000\2000 type sd distance.dta", replace
clear

use "AUGUST\2000\2000 type distance_2.dta"
collapse year (mean) meanSelf=cpspla36 meanLib=cpspla33 meanCon=cpspla34 /*
*/ meanNDP=cpspla31 meanPartyDis=partydis meanPD_lib=lib_pd meanPD_con=con_pd /*
*/ meanPD_ndp=ndp_pd mean_indiff=indiff mean_alien=alien mean_interact=interact [pweight=cesnwgt], by(type)
gen sub_n="type"

decode type, gen(group)
replace group="_1urban" in 1
replace group="_2nurban" in 2

order year sub_n type group

drop type
quietly: reshape wide meanSelf meanLib meanCon meanNDP meanPartyDis meanPD_lib /*
*/ meanPD_con meanPD_ndp mean_indiff mean_alien mean_interact, i(year sub_n) j(group) string
save "AUGUST\2000\2000 type means distance.dta", replace

merge 1:1 year using "AUGUST\2000\2000 type sd distance.dta"
drop _merge 
save "AUGUST\2000\2000 type comp distance.dta", replace
clear







*************************************************************************
*************************************************************************
*************************************************************************
**Distance for regxrel, 2000
use "AUGUST\2000\2000 edited distance.dta"

**************************************************************************
* RegXRel Step 1: Dropping missing observations
**************************************************************************
count if regxrel==.
drop if regxrel==.

save "AUGUST\2000\2000 regxrel edited distance.dta", replace

collapse year (mean) proxyLib=cpspla33 proxyCon=cpspla34 proxyNDP=cpspla31 [pweight=cesnwgt], by(regxrel)
gen sub_n="regxrel"

decode regxrel, gen(group)
replace group="_1QbCat" in 1
replace group="_2QbChr" in 2
replace group="_3NQbCat" in 3
replace group="_4NQbChr" in 4

order year sub_n regxrel group

drop regxrel
quietly: reshape wide proxyLib proxyCon proxyNDP, i(year sub_n) j(group) string

save "AUGUST\2000\2000 regxrel edited weight distance.dta", replace
clear

use "AUGUST\2000\2000 regxrel edited distance.dta"
merge m:1 year using "AUGUST\2000\2000 regxrel edited weight distance.dta"
drop _merge

gen proxyLib=.
replace proxyLib=proxyLib_1 if regxrel==1
replace proxyLib=proxyLib_2 if regxrel==2
replace proxyLib=proxyLib_3 if regxrel==3
replace proxyLib=proxyLib_4 if regxrel==4

gen proxyCon=.
replace proxyCon=proxyCon_1 if regxrel==1
replace proxyCon=proxyCon_2 if regxrel==2
replace proxyCon=proxyCon_3 if regxrel==3
replace proxyCon=proxyCon_4 if regxrel==4

gen proxyNDP=.
replace proxyNDP=proxyNDP_1 if regxrel==1
replace proxyNDP=proxyNDP_2 if regxrel==2
replace proxyNDP=proxyNDP_3 if regxrel==3
replace proxyNDP=proxyNDP_4 if regxrel==4

drop proxy*1QbCat proxy*2QbChr proxy*3NQbCat proxy*4NQbChr

************************************************************************
* RegXRel Step 2: Means, standard deviations, and distance
************************************************************************
by regxrel, sort: egen sdSelf = sd(cpspla36)
by regxrel, sort: egen sdLib = sd(cpspla33)
by regxrel, sort: egen sdCon = sd(cpspla34)
by regxrel, sort: egen sdNDP = sd(cpspla31)

gen partydis1 = (abs(SelfPlacement - LibPlacement)) + (abs(SelfPlacement - ConPlacement)) + (abs(SelfPlacement - NDPPlacement)) if SelfPlacement!=12 & LibPlacement!=12 & ConPlacement!=12 & NDPPlacement!=12
*this is for all those who gave placements for all parties

gen partydis2 = (abs(SelfPlacement - proxyLib)) + (abs(SelfPlacement - proxyCon)) + (abs(SelfPlacement - proxyNDP)) if SelfPlacement!=12 & LibPlacement==12 & ConPlacement==12 & NDPPlacement==12
*this is for all those who gave no placements for any party

gen partydis3 = (abs(SelfPlacement - proxyLib)) + (abs(SelfPlacement - ConPlacement)) + (abs(SelfPlacement - NDPPlacement)) if SelfPlacement!=12 & LibPlacement==12 & ConPlacement!=12 & NDPPlacement!=12
*this is for those who answered Con and NDP

gen partydis4 = (abs(SelfPlacement - LibPlacement)) + (abs(SelfPlacement - proxyCon)) + (abs(SelfPlacement - NDPPlacement)) if SelfPlacement!=12 & LibPlacement!=12 & ConPlacement==12 & NDPPlacement!=12
*this is for those who answered Lib and NDP

gen partydis5 = (abs(SelfPlacement - LibPlacement)) + (abs(SelfPlacement - ConPlacement)) + (abs(SelfPlacement - proxyNDP)) if SelfPlacement!=12 & LibPlacement!=12 & ConPlacement!=12 & NDPPlacement==12
*this is for those who answered Lib and Con

gen partydis6 = (abs(SelfPlacement - LibPlacement)) + (abs(SelfPlacement - proxyCon)) + (abs(SelfPlacement - proxyNDP)) if SelfPlacement!=12 & LibPlacement!=12 & ConPlacement==12 & NDPPlacement==12
*this is for those who only answered Lib

gen partydis7 = (abs(SelfPlacement - proxyLib)) + (abs(SelfPlacement - ConPlacement)) + (abs(SelfPlacement - proxyNDP)) if SelfPlacement!=12 & LibPlacement==12 & ConPlacement!=12 & NDPPlacement==12
*this is for those who only answered Con

gen partydis8 = (abs(SelfPlacement - proxyLib)) + (abs(SelfPlacement - proxyCon)) + (abs(SelfPlacement - NDPPlacement)) if SelfPlacement!=12 & LibPlacement==12 & ConPlacement==12 & NDPPlacement!=12
*this is for those who only answered NDP

gen partydis = .a
replace partydis = partydis1 if partydis1!=.
replace partydis = partydis2 if partydis2!=.
replace partydis = partydis3 if partydis3!=.
replace partydis = partydis4 if partydis4!=.
replace partydis = partydis5 if partydis5!=.
replace partydis = partydis6 if partydis6!=.
replace partydis = partydis7 if partydis7!=.
replace partydis = partydis8 if partydis8!=.

by regxrel, sort: egen sdPartyDis = sd(partydis)

************************************************************************
* RegXRel Step 3: Distance for individual parties, added 9/24/14
************************************************************************
*Liberal
gen lib_pd1 = (abs(SelfPlacement - LibPlacement)) if SelfPlacement!=12 & LibPlacement!=12 
gen lib_pd2 = (abs(SelfPlacement - proxyLib)) if SelfPlacement!=12 & LibPlacement==12 

gen lib_pd = .a
replace lib_pd = lib_pd1 if lib_pd1!=.
replace lib_pd = lib_pd2 if lib_pd2!=.

by regxrel, sort: egen sdPD_lib = sd(lib_pd)

*Conservative
gen con_pd1 = (abs(SelfPlacement - ConPlacement)) if SelfPlacement!=12 & ConPlacement!=12 
gen con_pd2 = (abs(SelfPlacement - proxyCon)) if SelfPlacement!=12 & ConPlacement==12 

gen con_pd = .a
replace con_pd = con_pd1 if con_pd1!=.
replace con_pd = con_pd2 if con_pd2!=.

by regxrel, sort: egen sdPD_con = sd(con_pd)

*NDP
gen ndp_pd1 = (abs(SelfPlacement - NDPPlacement)) if SelfPlacement!=12 & NDPPlacement!=12 
gen ndp_pd2 = (abs(SelfPlacement - proxyNDP)) if SelfPlacement!=12 & NDPPlacement==12 

gen ndp_pd = .a
replace ndp_pd = ndp_pd1 if ndp_pd1!=.
replace ndp_pd = ndp_pd2 if ndp_pd2!=.

by regxrel, sort: egen sdPD_ndp = sd(ndp_pd)

******************************************************************************
* RegXRel Step 4: Two-party utility
******************************************************************************
*LIB
gen libdu1 = abs(SelfPlacement - LibPlacement) if SelfPlacement!=12 & LibPlacement!=12
gen libdu2 = abs(SelfPlacement - proxyLib) if SelfPlacement!=12 & LibPlacement==12
gen libdu=.a
replace libdu=libdu1 if libdu1!=.
replace libdu=libdu2 if libdu2!=.

*CON
gen condu1= abs(SelfPlacement - ConPlacement) if SelfPlacement!=12 & ConPlacement!=12
gen condu2= abs(SelfPlacement - proxyCon) if SelfPlacement!=12 & ConPlacement==12
gen condu=.a
replace condu=condu1 if condu1!=.
replace condu=condu2 if condu2!=.

gen indiff= abs(libdu - condu)
by regxrel, sort: egen sd_indiff=sd(indiff)

*alienation, indifference, interaction 6/8/2016
order libdu condu, last
egen alien = rowmin(libdu-condu)
by regxrel, sort: egen sd_alien=sd(alien)

gen indiff_nonab = libdu-condu
gen interact = alien*indiff_nonab
by regxrel, sort: egen sd_interact=sd(interact)

save "AUGUST\2000\2000 regxrel distance_2.dta", replace

******************************************************************************
* RegXRel Step 5: Collapsing
******************************************************************************
collapse year sdSelf sdLib sdCon sdNDP sdPartyDis sdPD_lib sdPD_con sdPD_ndp /*
*/ sd_indiff sd_alien sd_interact, by(regxrel)
gen sub_n="regxrel"

decode regxrel, gen(group)
replace group="_1QbCat" in 1
replace group="_2QbChr" in 2
replace group="_3NQbCat" in 3
replace group="_4NQbChr" in 4

order year sub_n regxrel group
drop regxrel
quietly: reshape wide sdSelf sdLib sdCon sdNDP sdPartyDis sdPD_lib sdPD_con /*
*/ sdPD_ndp sd_indiff sd_alien sd_interact, i(year sub_n) j(group) string
save "AUGUST\2000\2000 regxrel sd distance.dta", replace
clear

use "AUGUST\2000\2000 regxrel distance_2.dta"
collapse year (mean) meanSelf=cpspla36 meanLib=cpspla33 meanCon=cpspla34 /*
*/ meanNDP=cpspla31 meanPartyDis=partydis meanPD_lib=lib_pd meanPD_con=con_pd /*
*/ meanPD_ndp=ndp_pd mean_indiff=indiff mean_alien=alien mean_interact=interact [pweight=cesnwgt], by(regxrel)
gen sub_n="regxrel"

decode regxrel, gen(group)
replace group="_1QbCat" in 1
replace group="_2QbChr" in 2
replace group="_3NQbCat" in 3
replace group="_4NQbChr" in 4

order year sub_n regxrel group

drop regxrel
quietly: reshape wide meanSelf meanLib meanCon meanNDP meanPartyDis meanPD_lib /*
*/ meanPD_con meanPD_ndp mean_indiff mean_alien mean_interact, i(year sub_n) j(group) string
save "AUGUST\2000\2000 regxrel means distance.dta", replace

merge 1:1 year using "AUGUST\2000\2000 regxrel sd distance.dta"
drop _merge 
save "AUGUST\2000\2000 regxrel comp distance.dta", replace
clear




*************************************************************************
*************************************************************************
*************************************************************************
**Distance for v2_regxrel, 2000
use "AUGUST\2000\2000 edited distance.dta"

**************************************************************************
* v2_regxrel Step 1: Dropping missing observations
**************************************************************************
count if v2_regxrel==.
drop if v2_regxrel==.

save "AUGUST\2000\2000 v2_regxrel edited distance.dta", replace

collapse year (mean) proxyLib=cpspla33 proxyCon=cpspla34 proxyNDP=cpspla31 [pweight=cesnwgt], by(v2_regxrel)
gen sub_n="v2_regxrel"

decode v2_regxrel, gen(group)
replace group="_1QbCat12" in 1
replace group="_2QbChr12" in 2
replace group="_3QbOth12" in 3
replace group="_4MariCat12" in 4
replace group="_5MariChr12" in 5
replace group="_6MariOth12" in 6
replace group="_7OntarCat12" in 7
replace group="_8OntarChr12" in 8
replace group="_9OntarOth12" in 9
replace group="_10WestCat12" in 10
replace group="_11WestChr12" in 11
replace group="_12WestOth12" in 12
order year sub_n v2_regxrel group

drop v2_regxrel
quietly: reshape wide proxyLib proxyCon proxyNDP, i(year sub_n) j(group) string

save "AUGUST\2000\2000 v2_regxrel edited weight distance.dta", replace
clear

use "AUGUST\2000\2000 v2_regxrel edited distance.dta"
merge m:1 year using "AUGUST\2000\2000 v2_regxrel edited weight distance.dta"
drop _merge

gen proxyLib=.
replace proxyLib=proxyLib_1Q if v2_regxrel==1
replace proxyLib=proxyLib_2 if v2_regxrel==2
replace proxyLib=proxyLib_3 if v2_regxrel==3
replace proxyLib=proxyLib_4 if v2_regxrel==4
replace proxyLib=proxyLib_5 if v2_regxrel==5
replace proxyLib=proxyLib_6 if v2_regxrel==6
replace proxyLib=proxyLib_7 if v2_regxrel==7
replace proxyLib=proxyLib_8 if v2_regxrel==8
replace proxyLib=proxyLib_9 if v2_regxrel==9
replace proxyLib=proxyLib_10 if v2_regxrel==10
replace proxyLib=proxyLib_11 if v2_regxrel==11
replace proxyLib=proxyLib_12 if v2_regxrel==12

gen proxyCon=.
replace proxyCon=proxyCon_1Q if v2_regxrel==1
replace proxyCon=proxyCon_2 if v2_regxrel==2
replace proxyCon=proxyCon_3 if v2_regxrel==3
replace proxyCon=proxyCon_4 if v2_regxrel==4
replace proxyCon=proxyCon_5 if v2_regxrel==5
replace proxyCon=proxyCon_6 if v2_regxrel==6
replace proxyCon=proxyCon_7 if v2_regxrel==7
replace proxyCon=proxyCon_8 if v2_regxrel==8
replace proxyCon=proxyCon_9 if v2_regxrel==9
replace proxyCon=proxyCon_10 if v2_regxrel==10
replace proxyCon=proxyCon_11 if v2_regxrel==11
replace proxyCon=proxyCon_12 if v2_regxrel==12

gen proxyNDP=.
replace proxyNDP=proxyNDP_1Q if v2_regxrel==1
replace proxyNDP=proxyNDP_2 if v2_regxrel==2
replace proxyNDP=proxyNDP_3 if v2_regxrel==3
replace proxyNDP=proxyNDP_4 if v2_regxrel==4
replace proxyNDP=proxyNDP_5 if v2_regxrel==5
replace proxyNDP=proxyNDP_6 if v2_regxrel==6
replace proxyNDP=proxyNDP_7 if v2_regxrel==7
replace proxyNDP=proxyNDP_8 if v2_regxrel==8
replace proxyNDP=proxyNDP_9 if v2_regxrel==9
replace proxyNDP=proxyNDP_10 if v2_regxrel==10
replace proxyNDP=proxyNDP_11 if v2_regxrel==11
replace proxyNDP=proxyNDP_12 if v2_regxrel==12

drop proxy*12

************************************************************************
* v2_regxrel Step 2: Means, standard deviations, and distance
************************************************************************
by v2_regxrel, sort: egen sdSelf = sd(cpspla36)
by v2_regxrel, sort: egen sdLib = sd(cpspla33)
by v2_regxrel, sort: egen sdCon = sd(cpspla34)
by v2_regxrel, sort: egen sdNDP = sd(cpspla31)

gen partydis1 = (abs(SelfPlacement - LibPlacement)) + (abs(SelfPlacement - ConPlacement)) + (abs(SelfPlacement - NDPPlacement)) if SelfPlacement!=12 & LibPlacement!=12 & ConPlacement!=12 & NDPPlacement!=12
*this is for all those who gave placements for all parties

gen partydis2 = (abs(SelfPlacement - proxyLib)) + (abs(SelfPlacement - proxyCon)) + (abs(SelfPlacement - proxyNDP)) if SelfPlacement!=12 & LibPlacement==12 & ConPlacement==12 & NDPPlacement==12
*this is for all those who gave no placements for any party

gen partydis3 = (abs(SelfPlacement - proxyLib)) + (abs(SelfPlacement - ConPlacement)) + (abs(SelfPlacement - NDPPlacement)) if SelfPlacement!=12 & LibPlacement==12 & ConPlacement!=12 & NDPPlacement!=12
*this is for those who answered Con and NDP

gen partydis4 = (abs(SelfPlacement - LibPlacement)) + (abs(SelfPlacement - proxyCon)) + (abs(SelfPlacement - NDPPlacement)) if SelfPlacement!=12 & LibPlacement!=12 & ConPlacement==12 & NDPPlacement!=12
*this is for those who answered Lib and NDP

gen partydis5 = (abs(SelfPlacement - LibPlacement)) + (abs(SelfPlacement - ConPlacement)) + (abs(SelfPlacement - proxyNDP)) if SelfPlacement!=12 & LibPlacement!=12 & ConPlacement!=12 & NDPPlacement==12
*this is for those who answered Lib and Con

gen partydis6 = (abs(SelfPlacement - LibPlacement)) + (abs(SelfPlacement - proxyCon)) + (abs(SelfPlacement - proxyNDP)) if SelfPlacement!=12 & LibPlacement!=12 & ConPlacement==12 & NDPPlacement==12
*this is for those who only answered Lib

gen partydis7 = (abs(SelfPlacement - proxyLib)) + (abs(SelfPlacement - ConPlacement)) + (abs(SelfPlacement - proxyNDP)) if SelfPlacement!=12 & LibPlacement==12 & ConPlacement!=12 & NDPPlacement==12
*this is for those who only answered Con

gen partydis8 = (abs(SelfPlacement - proxyLib)) + (abs(SelfPlacement - proxyCon)) + (abs(SelfPlacement - NDPPlacement)) if SelfPlacement!=12 & LibPlacement==12 & ConPlacement==12 & NDPPlacement!=12
*this is for those who only answered NDP

gen partydis = .a
replace partydis = partydis1 if partydis1!=.
replace partydis = partydis2 if partydis2!=.
replace partydis = partydis3 if partydis3!=.
replace partydis = partydis4 if partydis4!=.
replace partydis = partydis5 if partydis5!=.
replace partydis = partydis6 if partydis6!=.
replace partydis = partydis7 if partydis7!=.
replace partydis = partydis8 if partydis8!=.

by v2_regxrel, sort: egen sdPartyDis = sd(partydis)

************************************************************************
* v2_regxrel Step 3: Distance for individual parties, added 9/24/14
************************************************************************
*Liberal
gen lib_pd1 = (abs(SelfPlacement - LibPlacement)) if SelfPlacement!=12 & LibPlacement!=12 
gen lib_pd2 = (abs(SelfPlacement - proxyLib)) if SelfPlacement!=12 & LibPlacement==12 

gen lib_pd = .a
replace lib_pd = lib_pd1 if lib_pd1!=.
replace lib_pd = lib_pd2 if lib_pd2!=.

by v2_regxrel, sort: egen sdPD_lib = sd(lib_pd)

*Conservative
gen con_pd1 = (abs(SelfPlacement - ConPlacement)) if SelfPlacement!=12 & ConPlacement!=12 
gen con_pd2 = (abs(SelfPlacement - proxyCon)) if SelfPlacement!=12 & ConPlacement==12 

gen con_pd = .a
replace con_pd = con_pd1 if con_pd1!=.
replace con_pd = con_pd2 if con_pd2!=.

by v2_regxrel, sort: egen sdPD_con = sd(con_pd)

*NDP
gen ndp_pd1 = (abs(SelfPlacement - NDPPlacement)) if SelfPlacement!=12 & NDPPlacement!=12 
gen ndp_pd2 = (abs(SelfPlacement - proxyNDP)) if SelfPlacement!=12 & NDPPlacement==12 

gen ndp_pd = .a
replace ndp_pd = ndp_pd1 if ndp_pd1!=.
replace ndp_pd = ndp_pd2 if ndp_pd2!=.

by v2_regxrel, sort: egen sdPD_ndp = sd(ndp_pd)

******************************************************************************
* v2_regxrel Step 4: Two-party utility
******************************************************************************
*LIB
gen libdu1 = abs(SelfPlacement - LibPlacement) if SelfPlacement!=12 & LibPlacement!=12
gen libdu2 = abs(SelfPlacement - proxyLib) if SelfPlacement!=12 & LibPlacement==12
gen libdu=.a
replace libdu=libdu1 if libdu1!=.
replace libdu=libdu2 if libdu2!=.

*CON
gen condu1= abs(SelfPlacement - ConPlacement) if SelfPlacement!=12 & ConPlacement!=12
gen condu2= abs(SelfPlacement - proxyCon) if SelfPlacement!=12 & ConPlacement==12
gen condu=.a
replace condu=condu1 if condu1!=.
replace condu=condu2 if condu2!=.

gen indiff= abs(libdu - condu)
by v2_regxrel, sort: egen sd_indiff=sd(indiff)

*alienation, indifference, interaction 6/8/2016
order libdu condu, last
egen alien = rowmin(libdu-condu)
by v2_regxrel, sort: egen sd_alien=sd(alien)

gen indiff_nonab = libdu-condu
gen interact = alien*indiff_nonab
by v2_regxrel, sort: egen sd_interact=sd(interact)

save "AUGUST\2000\2000 v2_regxrel distance_2.dta", replace

******************************************************************************
* v2_regxrel Step 5: Collapsing
******************************************************************************
collapse year sdSelf sdLib sdCon sdNDP sdPartyDis sdPD_lib sdPD_con sdPD_ndp /*
*/ sd_indiff sd_alien sd_interact, by(v2_regxrel)
gen sub_n="v2_regxrel"

decode v2_regxrel, gen(group)
replace group="_1QbCat12" in 1
replace group="_2QbChr12" in 2
replace group="_3QbOth12" in 3
replace group="_4MariCat12" in 4
replace group="_5MariChr12" in 5
replace group="_6MariOth12" in 6
replace group="_7OntarCat12" in 7
replace group="_8OntarChr12" in 8
replace group="_9OntarOth12" in 9
replace group="_10WestCat12" in 10
replace group="_11WestChr12" in 11
replace group="_12WestOth12" in 12

order year sub_n v2_regxrel group
drop v2_regxrel
quietly: reshape wide sdSelf sdLib sdCon sdNDP sdPartyDis sdPD_lib sdPD_con /*
*/ sdPD_ndp sd_indiff sd_alien sd_interact, i(year sub_n) j(group) string
save "AUGUST\2000\2000 v2_regxrel sd distance.dta", replace
clear

use "AUGUST\2000\2000 v2_regxrel distance_2.dta"
collapse year (mean) meanSelf=cpspla36 meanLib=cpspla33 meanCon=cpspla34 /*
*/ meanNDP=cpspla31 meanPartyDis=partydis meanPD_lib=lib_pd meanPD_con=con_pd /*
*/ meanPD_ndp=ndp_pd mean_indiff=indiff mean_alien=alien mean_interact=interact [pweight=cesnwgt], by(v2_regxrel)
gen sub_n="v2_regxrel"

decode v2_regxrel, gen(group)
replace group="_1QbCat12" in 1
replace group="_2QbChr12" in 2
replace group="_3QbOth12" in 3
replace group="_4MariCat12" in 4
replace group="_5MariChr12" in 5
replace group="_6MariOth12" in 6
replace group="_7OntarCat12" in 7
replace group="_8OntarChr12" in 8
replace group="_9OntarOth12" in 9
replace group="_10WestCat12" in 10
replace group="_11WestChr12" in 11
replace group="_12WestOth12" in 12

order year sub_n v2_regxrel group

drop v2_regxrel
quietly: reshape wide meanSelf meanLib meanCon meanNDP meanPartyDis meanPD_lib /*
*/ meanPD_con meanPD_ndp mean_indiff mean_alien mean_interact, i(year sub_n) j(group) string
save "AUGUST\2000\2000 v2_regxrel means distance.dta", replace

merge 1:1 year using "AUGUST\2000\2000 v2_regxrel sd distance.dta"
drop _merge 
save "AUGUST\2000\2000 v2_regxrel comp distance.dta", replace
clear








*************************************************************************
*************************************************************************
*************************************************************************
**Distance for regxun, 2000
use "AUGUST\2000\2000 edited distance.dta"

**************************************************************************
* RegXUn Step 1: Dropping missing observations
**************************************************************************
count if regxun==.
drop if regxun==.

save "AUGUST\2000\2000 regxun edited distance.dta", replace

collapse year (mean) proxyLib=cpspla33 proxyCon=cpspla34 proxyNDP=cpspla31 [pweight=cesnwgt], by(regxun)
gen sub_n="regxun"

decode regxun, gen(group)
replace group="_1QbU" in 1
replace group="_2QbNonU" in 2
replace group="_3NQbU" in 3
replace group="_4NQbNonU" in 4

order year sub_n regxun group

drop regxun
quietly: reshape wide proxyLib proxyCon proxyNDP, i(year sub_n) j(group) string

save "AUGUST\2000\2000 regxun edited weight distance.dta", replace
clear

use "AUGUST\2000\2000 regxun edited distance.dta"
merge m:1 year using "AUGUST\2000\2000 regxun edited weight distance.dta"
drop _merge

gen proxyLib=.
replace proxyLib=proxyLib_1 if regxun==1
replace proxyLib=proxyLib_2 if regxun==2
replace proxyLib=proxyLib_3 if regxun==3
replace proxyLib=proxyLib_4 if regxun==4

gen proxyCon=.
replace proxyCon=proxyCon_1 if regxun==1
replace proxyCon=proxyCon_2 if regxun==2
replace proxyCon=proxyCon_3 if regxun==3
replace proxyCon=proxyCon_4 if regxun==4

gen proxyNDP=.
replace proxyNDP=proxyNDP_1 if regxun==1
replace proxyNDP=proxyNDP_2 if regxun==2
replace proxyNDP=proxyNDP_3 if regxun==3
replace proxyNDP=proxyNDP_4 if regxun==4

drop proxy*1QbU proxy*2QbNonU proxy*3NQbU proxy*4NQbNonU

************************************************************************
* RegXUn Step 2: Means, standard deviations, and distance
************************************************************************
by regxun, sort: egen sdSelf = sd(cpspla36)
by regxun, sort: egen sdLib = sd(cpspla33)
by regxun, sort: egen sdCon = sd(cpspla34)
by regxun, sort: egen sdNDP = sd(cpspla31)

gen partydis1 = (abs(SelfPlacement - LibPlacement)) + (abs(SelfPlacement - ConPlacement)) + (abs(SelfPlacement - NDPPlacement)) if SelfPlacement!=12 & LibPlacement!=12 & ConPlacement!=12 & NDPPlacement!=12
*this is for all those who gave placements for all parties

gen partydis2 = (abs(SelfPlacement - proxyLib)) + (abs(SelfPlacement - proxyCon)) + (abs(SelfPlacement - proxyNDP)) if SelfPlacement!=12 & LibPlacement==12 & ConPlacement==12 & NDPPlacement==12
*this is for all those who gave no placements for any party

gen partydis3 = (abs(SelfPlacement - proxyLib)) + (abs(SelfPlacement - ConPlacement)) + (abs(SelfPlacement - NDPPlacement)) if SelfPlacement!=12 & LibPlacement==12 & ConPlacement!=12 & NDPPlacement!=12
*this is for those who answered Con and NDP

gen partydis4 = (abs(SelfPlacement - LibPlacement)) + (abs(SelfPlacement - proxyCon)) + (abs(SelfPlacement - NDPPlacement)) if SelfPlacement!=12 & LibPlacement!=12 & ConPlacement==12 & NDPPlacement!=12
*this is for those who answered Lib and NDP

gen partydis5 = (abs(SelfPlacement - LibPlacement)) + (abs(SelfPlacement - ConPlacement)) + (abs(SelfPlacement - proxyNDP)) if SelfPlacement!=12 & LibPlacement!=12 & ConPlacement!=12 & NDPPlacement==12
*this is for those who answered Lib and Con

gen partydis6 = (abs(SelfPlacement - LibPlacement)) + (abs(SelfPlacement - proxyCon)) + (abs(SelfPlacement - proxyNDP)) if SelfPlacement!=12 & LibPlacement!=12 & ConPlacement==12 & NDPPlacement==12
*this is for those who only answered Lib

gen partydis7 = (abs(SelfPlacement - proxyLib)) + (abs(SelfPlacement - ConPlacement)) + (abs(SelfPlacement - proxyNDP)) if SelfPlacement!=12 & LibPlacement==12 & ConPlacement!=12 & NDPPlacement==12
*this is for those who only answered Con

gen partydis8 = (abs(SelfPlacement - proxyLib)) + (abs(SelfPlacement - proxyCon)) + (abs(SelfPlacement - NDPPlacement)) if SelfPlacement!=12 & LibPlacement==12 & ConPlacement==12 & NDPPlacement!=12
*this is for those who only answered NDP

gen partydis = .a
replace partydis = partydis1 if partydis1!=.
replace partydis = partydis2 if partydis2!=.
replace partydis = partydis3 if partydis3!=.
replace partydis = partydis4 if partydis4!=.
replace partydis = partydis5 if partydis5!=.
replace partydis = partydis6 if partydis6!=.
replace partydis = partydis7 if partydis7!=.
replace partydis = partydis8 if partydis8!=.

by regxun, sort: egen sdPartyDis = sd(partydis)

************************************************************************
* RegXUn Step 3: Distance for individual parties, added 9/24/14
************************************************************************
*Liberal
gen lib_pd1 = (abs(SelfPlacement - LibPlacement)) if SelfPlacement!=12 & LibPlacement!=12 
gen lib_pd2 = (abs(SelfPlacement - proxyLib)) if SelfPlacement!=12 & LibPlacement==12 

gen lib_pd = .a
replace lib_pd = lib_pd1 if lib_pd1!=.
replace lib_pd = lib_pd2 if lib_pd2!=.

by regxun, sort: egen sdPD_lib = sd(lib_pd)

*Conservative
gen con_pd1 = (abs(SelfPlacement - ConPlacement)) if SelfPlacement!=12 & ConPlacement!=12 
gen con_pd2 = (abs(SelfPlacement - proxyCon)) if SelfPlacement!=12 & ConPlacement==12 

gen con_pd = .a
replace con_pd = con_pd1 if con_pd1!=.
replace con_pd = con_pd2 if con_pd2!=.

by regxun, sort: egen sdPD_con = sd(con_pd)

*NDP
gen ndp_pd1 = (abs(SelfPlacement - NDPPlacement)) if SelfPlacement!=12 & NDPPlacement!=12 
gen ndp_pd2 = (abs(SelfPlacement - proxyNDP)) if SelfPlacement!=12 & NDPPlacement==12 

gen ndp_pd = .a
replace ndp_pd = ndp_pd1 if ndp_pd1!=.
replace ndp_pd = ndp_pd2 if ndp_pd2!=.

by regxun, sort: egen sdPD_ndp = sd(ndp_pd)

******************************************************************************
* RegXUn Step 4: Two-party utility
******************************************************************************
*LIB
gen libdu1 = abs(SelfPlacement - LibPlacement) if SelfPlacement!=12 & LibPlacement!=12
gen libdu2 = abs(SelfPlacement - proxyLib) if SelfPlacement!=12 & LibPlacement==12
gen libdu=.a
replace libdu=libdu1 if libdu1!=.
replace libdu=libdu2 if libdu2!=.

*CON
gen condu1= abs(SelfPlacement - ConPlacement) if SelfPlacement!=12 & ConPlacement!=12
gen condu2= abs(SelfPlacement - proxyCon) if SelfPlacement!=12 & ConPlacement==12
gen condu=.a
replace condu=condu1 if condu1!=.
replace condu=condu2 if condu2!=.

gen indiff= abs(libdu - condu)
by regxun, sort: egen sd_indiff=sd(indiff)

*alienation, indifference, interaction 6/8/2016
order libdu condu, last
egen alien = rowmin(libdu-condu)
by regxun, sort: egen sd_alien=sd(alien)

gen indiff_nonab = libdu-condu
gen interact = alien*indiff_nonab
by regxun, sort: egen sd_interact=sd(interact)

save "AUGUST\2000\2000 regxun distance_2.dta", replace

******************************************************************************
* RegXUn Step 5: Collapsing
******************************************************************************
collapse year sdSelf sdLib sdCon sdNDP sdPartyDis sdPD_lib sdPD_con sdPD_ndp /*
*/ sd_indiff sd_alien sd_interact, by(regxun)
gen sub_n="regxun"

decode regxun, gen(group)
replace group="_1QbU" in 1
replace group="_2QbNonU" in 2
replace group="_3NQbU" in 3
replace group="_4NQbNonU" in 4

order year sub_n regxun group
drop regxun
quietly: reshape wide sdSelf sdLib sdCon sdNDP sdPartyDis sdPD_lib sdPD_con /*
*/ sdPD_ndp sd_indiff sd_alien sd_interact, i(year sub_n) j(group) string
save "AUGUST\2000\2000 regxun sd distance.dta", replace
clear

use "AUGUST\2000\2000 regxun distance_2.dta"
collapse year (mean) meanSelf=cpspla36 meanLib=cpspla33 meanCon=cpspla34 /*
*/ meanNDP=cpspla31 meanPartyDis=partydis meanPD_lib=lib_pd meanPD_con=con_pd /*
*/ meanPD_ndp=ndp_pd mean_indiff=indiff mean_alien=alien mean_interact=interact [pweight=cesnwgt], by(regxun)
gen sub_n="regxun"

decode regxun, gen(group)
replace group="_1QbU" in 1
replace group="_2QbNonU" in 2
replace group="_3NQbU" in 3
replace group="_4NQbNonU" in 4

order year sub_n regxun group

drop regxun
quietly: reshape wide meanSelf meanLib meanCon meanNDP meanPartyDis /*
*/ meanPD_lib meanPD_con meanPD_ndp mean_indiff mean_alien mean_interact, i(year sub_n) j(group) string
save "AUGUST\2000\2000 regxun means distance.dta", replace

merge 1:1 year using "AUGUST\2000\2000 regxun sd distance.dta"
drop _merge 
save "AUGUST\2000\2000 regxun comp distance.dta", replace
clear
