*2000 Party ID
*set directory
cd "M:\Kollman Party Project IFS\Canada"
use "2000\CES 2000 Stata.dta"

***************************************************************************
* Step 1: Condensing the dataset, variable description
***************************************************************************
keep idnum cpsk1a cpsk1b cpsk2a cpsk2b cpsk3a cpsk3b cpsk4a cpspla36 cpspla33 cpspla34 cpspla32 cpspla31 cpsm10 province cpsm9 cpsn6a areacode cesnwgt
numlabel,add

*idnum = participant id
*cpsk1a, cpsk1b  = party id
*cpsk3a, cpsk4a = party closer
*cpsk2a, cpsk2b = strength
*cpspla36 = self-placement, general
*cpspla33 = Liberal placement, general
*cpspla34 = Conservative placement, general
*cpspla32 = Alliance placement, general
*cpspla31 = NDP placement, general
*cpsm10 = religion
*province = region
*cpsm9 = union
*cpsn6a = ethnicity
*areacode = type(urban/rural)
*cesnwgt = weight


***************************************************************************
* Step 2: Creating year variable
***************************************************************************
gen year=2000


***************************************************************************
* Step 3: Creating party id variables
***************************************************************************

gen countv=.
replace countv=1 if cpsk1a!=. | cpsk1b!=.

gen Liberal=.
replace Liberal=1 if cpsk1a==1 | cpsk1b==1
gen Conservative=. 
replace Conservative=1 if cpsk1a==4 | cpsk1b==4
gen NDP=.
replace NDP=1 if cpsk1a==5 | cpsk1b==5
gen Alliance=.
replace Alliance=1 if cpsk1a==3 | cpsk1b==3
gen BlocQuebecois=.
replace BlocQuebecois=1 if cpsk1a==2 | cpsk1b==2
gen Other=.
replace Other=1 if cpsk1a==97
gen None=.
replace None=1 if cpsk1a==0 | cpsk1b==7
gen DontKnow=.
replace DontKnow=1 if cpsk1a==98 | cpsk1b==98
gen Refused=.
replace Refused=1 if cpsk1a==99 | cpsk1b==99

gen ClsrLiberal=.
replace ClsrLiberal=1 if cpsk4a==1 | cpsk3b==1
gen ClsrConservative=.
replace ClsrConservative=1 if cpsk4a==4 | cpsk3b==4
gen ClsrNDP=.
replace ClsrNDP=1 if cpsk4a==5 | cpsk3b==5
gen ClsrBlocQuebecois=.
replace ClsrBlocQuebecois=1 if cpsk4a==2 | cpsk3b==2
gen ClsrAlliance=.
replace ClsrAlliance=1 if cpsk4a==3 | cpsk3b==3
gen ClsrOther=.
replace ClsrOther=1 if cpsk4a==97
gen ClsrNone=.
replace ClsrNone=1 if cpsk3b==7 | cpsk4a==0 | cpsk3a==5
gen ClsrDontKnow=.
replace ClsrDontKnow=1 if cpsk3a==8 | cpsk4a==98 | cpsk3b==98
gen ClsrRefused=.
replace ClsrRefused=1 if cpsk3a==9 | cpsk4a==99 | cpsk3b==99



***************************************************************************************
*  Step 4: Creating Partisan variables (ID or clsr) for Liberal, Conservative, NDP, and others
***************************************************************************************
gen LibPart=.
replace LibPart=1 if  Liberal==1 & ((cpsk2a<8 & cpsk2a!=.) | (cpsk2b<98 & cpsk2b!=.))
label var LibPart "identifies/leans to the Liberals"
label define L3 1 "Liberal partisan"
label values LibPart L3
tab LibPart

gen ConPart=.
replace ConPart=1 if  Conservative==1 & ((cpsk2a<8 & cpsk2a!=.) | (cpsk2b<98 & cpsk2b!=.))
label var ConPart "identifies/leans to Conservative"
label define L2 1 "Conservative partisan"
label values ConPart L2
tab ConPart

gen NDPPart=.
replace NDPPart=1 if  NDP==1 & ((cpsk2a<8 & cpsk2a!=.) | (cpsk2b<98 & cpsk2b!=.))
label var NDPPart "identifies/leans to NDP"
label define L24 1 "NDP partisan"
label values NDPPart L24
tab NDPPart

gen AllPar=.
replace AllPar=1 if Alliance==1 & ((cpsk2a<8 & cpsk2a!=.) | (cpsk2b<98 & cpsk2b!=.))
label var AllPar "identifies/leans to Alliance"
label define allabel 1 "Alliance partisan:
label values AllPar allabel
tab AllPar

gen BlocQPar=.
replace BlocQPar=1 if BlocQuebecois==1 & ((cpsk2a<8 & cpsk2a!=.) | (cpsk2b<98 & cpsk2b!=.))
label var BlocQPar "identifies/leans to Bloc Quebecois"
label define queb 1 "Bloc Quebecois partisan"
label values BlocQPar queb
tab BlocQPar 

gen OtherPart=.
replace OtherPart=1 if  Other==1 & ((cpsk2a<8 & cpsk2a!=.) | (cpsk2b<98 & cpsk2b!=.))
label var OtherPart "identifies/leans to other"
label define L27 1 "other partisan"
label values OtherPart L27
tab OtherPart

gen AllOthersPart=.
replace AllOthersPart=1 if (Alliance==1 | BlocQuebecois==1 | Other==1) & ((cpsk2a<8 & cpsk2a!=.) | (cpsk2b<98 & cpsk2b!=.))
label var AllOthersPart "identifies/leans to another party"
label define L4 1 "all other partisans"
label values AllOthersPart L4
tab AllOthersPart


***************************************************************************
* Step 5: Recoding ID strength
***************************************************************************
tab cpsk2a, m
tab cpsk2b, m
*to see how strength is coded

gen idstr=.
replace idstr=1 if cpsk2a==5 | cpsk2b==5
replace idstr=2 if cpsk2a==3 | cpsk2b==3
replace idstr=3 if cpsk2a==1 | cpsk2b==1
label define idstr2 1 "not very strongly" 2 "fairly strongly" 3 "very strongly" 
label values idstr idstr2


****************************************************************************
*Step 6: Creating Subgroup Variables
****************************************************************************
*religion
tab cpsm10
gen religion=cpsm10
recode religion (0=4) (1=2) (2=1) (4/5=3) (9/99=.)
label define rel1 1 "Catholic" 2 "Other Christian" 3 "Non-Christian"  4 "Non-Religious"
label values religion rel1
label var religion "religion"

*region
tab province
gen region=province
recode region (0/13=1) (24=2) (35=3) (46/59=4)
label var region "region"
label define reg1 1 "Maritimes" 2 "Quebec" 3 "Ontario" 4 "Western Canada"
label values region reg1
label var region "region"

*union
tab cpsm9
gen union=cpsm9
recode union(5=2) (8/9=.)
label define unlab 1 "union" 2 "non-union"
label values union unlab
label var union "union"

*ethnicity
tab cpsn6a
gen ethnicity=cpsn6a
recode ethnicity (1=1) (3=1) (7=1) (9/13=1) (16/19=1) (22/25=1) (35=1) (37=1) (40/44=1) (47/48=1) (50=1) (53=1) (55/56=1) (96=1) (0=2) (4/6=2) (8=2) (14/15=2) (20/21=2) (26/34=2) (36=2) (38/39=2) (45/46=2) (49=2) (51=2) (54=2) (95=2) (98/99=.)
label define etn 1 "European descent" 2 "Non-European descent"
label values ethnicity etn
label var ethnicity "ethnicity"

*partisan
gen partisan=.
replace partisan=1 if LibPart==1
replace partisan=2 if ConPart==1
replace partisan=3 if NDPPart==1
replace partisan=4 if AllOthersPart==1
label define labelp 1 "Liberal Partisan" 2 "Conservative Partisan" 3 "NDP Partisan" 4 "Other-Party Partisan"
label values partisan labelp
label var partisan "partisan"

*type(urban/rural)
tab areacode, m
gen type=2
replace type=1 if areacode==450 | areacode==514 | areacode==416 | areacode==250 | areacode==604
label define labtyp 1 "urban" 2 "not urban"
label values type labtyp
label var type "type"
	//Montreal = 450, 514
	//Toronto = 416
	//Vancouver = 250, 604

*RegionXReligion
gen regxrel=.
replace regxrel=1 if region==2 & religion==1 //Quebec & Catholic
replace regxrel=2 if region==2 & religion==2 //Quebec & non-Cath Christ.
replace regxrel=3 if (region==1 | region==3 | region==4) & religion==1 //non-Queb & Catholic
replace regxrel=4 if (region==1 | region==3 | region==4) & religion==2 //non-Queb & non-Cath Christ.

label define pop 1 "Quebec & Catholic" 2 "Quebec & non-Cath Christ"  /*
*/ 3 "non-Quebec & Catholic" 4 "non-Quebec & non-Cath Christ"
label values regxrel pop

*RegionXUnion
gen regxun=.
replace regxun=1 if region==2 & union==1 //Queb & union
replace regxun=2 if region==2 & union==2 //Queb & non-union
replace regxun=3 if (region==1 | region==3 | region==4) & union==1 //non-Q & union
replace regxun=4 if (region==1 | region==3 | region==4) & union==2 //non-Q & non-union

label define ypy 1 "Quebec & union" 2 "Quebec & non-union" /*
*/ 3 "non-Quebec & union" 4 "non-Quebec & non-union"
label values regxun ypy

****************************************************************************
*Step 7: Save, Collapse, Save
****************************************************************************
save "AUGUST\2000\2000 edited id.dta"
collapse year (sum) observ=countv (sum) Liberal Conservative NDP Alliance BlocQuebecois Other None DontKnow Refused Clsr* [pweight=cesnwgt]
save "AUGUST\2000\2000 total id.dta"
clear






***********************************************************************
***********************************************************************
***********************************************************************
*2000 Party ID, religion
*set directory
cd "M:\Kollman Party Project IFS\Canada"
use "AUGUST\2000\2000 edited id.dta"

count if religion==.
drop if religion==.

sort religion
quietly: by religion: sum idstr

collapse year (count)observ=countv (sum) Liberal Conservative NDP Alliance BlocQuebecois Other None DontKnow Refused Clsr* [pweight=cesnwgt], by(religion)
gen sub_n="religion"

decode religion, gen(group)
replace group="_1cath" in 1
replace group="_2chr" in 2
replace group="_3other" in 3
replace group="_4nrel" in 4

order year sub_n religion group

drop religion
quietly: reshape wide observ Liberal Conservative NDP Alliance BlocQuebecois Other None DontKnow Refused Clsr*, i(year sub_n) j(group) string
save "AUGUST\2000\2000 religion id.dta"
clear




***********************************************************************
*2000 Party ID, region
*set directory
cd "M:\Kollman Party Project IFS\Canada"
use "AUGUST\2000\2000 edited id.dta"

count if region==.
drop if region==.

sort region
quietly: by region: sum idstr

collapse year (count)observ=countv (sum) Liberal Conservative NDP Alliance BlocQuebecois Other None DontKnow Refused Clsr* [pweight=cesnwgt], by(region)
gen sub_n="region"

decode region, gen(group)
replace group="_1Marit" in 1
replace group="_2Queb" in 2
replace group="_3Ontar" in 3
replace group="_4West" in 4

order year sub_n region group

drop region
quietly: reshape wide observ Liberal Conservative NDP Alliance BlocQuebecois Other None DontKnow Refused Clsr*, i(year sub_n) j(group) string
save "AUGUST\2000\2000 region id.dta"
clear



***********************************************************************
*2000 Party ID, union
*set directory
cd "M:\Kollman Party Project IFS\Canada"
use "AUGUST\2000\2000 edited id.dta"

count if union==.
drop if union==.

sort union
quietly: by union: sum idstr

collapse year (count)observ=countv (sum) Liberal Conservative NDP Alliance BlocQuebecois Other None DontKnow Refused Clsr* [pweight=cesnwgt], by(union)
gen sub_n="union"

decode union, gen(group)
replace group="_1union" in 1
replace group="_2nunion" in 2

order year sub_n union group

drop union
quietly: reshape wide observ Liberal Conservative NDP Alliance BlocQuebecois Other None DontKnow Refused Clsr*, i(year sub_n) j(group) string
save "AUGUST\2000\2000 union id.dta"
clear



***********************************************************************
*2000 Party ID, ethnicity
*set directory
cd "M:\Kollman Party Project IFS\Canada"
use "AUGUST\2000\2000 edited id.dta"

count if ethnicity==.
drop if ethnicity==.

sort ethnicity
quietly: by ethnicity: sum idstr

collapse year (count)observ=countv (sum) Liberal Conservative NDP Alliance BlocQuebecois Other None DontKnow Refused Clsr* [pweight=cesnwgt], by(ethnicity)
gen sub_n="ethnicity"

decode ethnicity, gen(group)
replace group="_1Euro" in 1
replace group="_2nEuro" in 2

order year sub_n ethnicity group

drop ethnicity
quietly: reshape wide observ Liberal Conservative NDP Alliance BlocQuebecois Other None DontKnow Refused Clsr*, i(year sub_n) j(group) string
save "AUGUST\2000\2000 ethnicity id.dta"
clear


***********************************************************************
*2000 Party ID, partisan
*set directory
cd "M:\Kollman Party Project IFS\Canada"
use "AUGUST\2000\2000 edited id.dta"

count if partisan==.
drop if partisan==.

sort partisan
quietly: by partisan: sum idstr

collapse year (count)observ=countv (sum) Liberal Conservative NDP Alliance BlocQuebecois Other None DontKnow Refused Clsr* [pweight=cesnwgt], by(partisan)
gen sub_n="partisan"

decode partisan, gen(group)
replace group="_1LibPar" in 1
replace group="_2ConPar" in 2
replace group="_3NDPPar" in 3
replace group="_4OtherPar" in 4

order year sub_n partisan group

drop partisan
quietly: reshape wide observ Liberal Conservative NDP Alliance BlocQuebecois Other None DontKnow Refused Clsr*, i(year sub_n) j(group) string
save "AUGUST\2000\2000 partisan id.dta"
clear





***********************************************************************
*2000 Party ID, type
*set directory
cd "M:\Kollman Party Project IFS\Canada"
use "AUGUST\2000\2000 edited id.dta"

count if type==.
drop if type==.

sort type
quietly: by type: sum idstr

collapse year (count)observ=countv (sum) Liberal Conservative NDP Alliance BlocQuebecois Other None DontKnow Refused Clsr* [pweight=cesnwgt], by(type)
gen sub_n="type"

decode type, gen(group)
replace group="_1urban" in 1
replace group="_2nurban" in 2

order year sub_n type group

drop type
quietly: reshape wide observ Liberal Conservative NDP Alliance BlocQuebecois Other None DontKnow Refused Clsr*, i(year sub_n) j(group) string
save "AUGUST\2000\2000 type id.dta"
clear



***********************************************************************
*2000 Party ID, regxrel
*set directory
cd "M:\Kollman Party Project IFS\Canada"
use "AUGUST\2000\2000 edited id.dta"

count if regxrel==.
drop if regxrel==.

sort regxrel
quietly: by regxrel: sum idstr

collapse year (count)observ=countv (sum) Liberal Conservative NDP Alliance BlocQuebecois Other None DontKnow Refused Clsr* [pweight=cesnwgt], by(regxrel)
gen sub_n="regxrel"

decode regxrel, gen(group)
replace group="_1QbCat" in 1
replace group="_2QbChr" in 2
replace group="_3NQbCat" in 3
replace group="_4NQbChr" in 4

order year sub_n regxrel group

drop regxrel
quietly: reshape wide observ Liberal Conservative NDP Alliance BlocQuebecois Other None DontKnow Refused Clsr*, i(year sub_n) j(group) string
save "AUGUST\2000\2000 regxrel id.dta"
clear





***********************************************************************
*2000 Party ID, regxun
*set directory
cd "M:\Kollman Party Project IFS\Canada"
use "AUGUST\2000\2000 edited id.dta"

count if regxun==.
drop if regxun==.

sort regxun
quietly: by regxun: sum idstr

collapse year (count)observ=countv (sum) Liberal Conservative NDP Alliance BlocQuebecois Other None DontKnow Refused Clsr* [pweight=cesnwgt], by(regxun)
gen sub_n="regxun"

decode regxun, gen(group)
replace group="_1QbU" in 1
replace group="_2QbNonU" in 2
replace group="_3NQbU" in 3
replace group="_4NQbNonU" in 4

order year sub_n regxun group

drop regxun
quietly: reshape wide observ Liberal Conservative NDP Alliance BlocQuebecois Other None DontKnow Refused Clsr*, i(year sub_n) j(group) string
save "AUGUST\2000\2000 regxun id.dta"
clear
