*2004 Party ID
*set directory
cd "M:\Kollman Party Project IFS\Canada"
use "2004\CES 2004 Stata.dta"

***************************************************************************
* Step 1: Condensing the dataset, variable description
***************************************************************************
keep idnum cps_q1a cps_q2 cps_q3 cps_q4 mbs_h10 mbs_h11a mbs_h11b mbs_h11c cps_s9 province cps_s6a cps_s6b cps_s14 areacode cesnwgt
numlabel, add

*idnum = participant id
*cps_q1a = party id
*cps_q3, cps_q4 = party closer
*cps_q2 = strength
*mbs_h10 = self-placement
*mbs_h11a = Liberal placement
*mbs_h11b = Conservative placement
*mbs_h11c = NDP placement
*cps_s9 = religion
*province = region
*cps_s6a, cps_s6b = union
*cps_s14 = ethnicity
*areacode = type(urban/rural)
*cesnwgt = weight

***************************************************************************
* Step 2: Creating year variable
***************************************************************************
gen year=2004


***************************************************************************
* Step 3: Creating party id variables
***************************************************************************
gen partyid=cps_q1a

gen countv=partyid
recode countv (0/99=1)

gen Liberal=.
replace Liberal=1 if partyid==1
gen Conservative=. 
replace Conservative=1 if partyid==2
gen NDP=.
replace NDP=1 if partyid==3
gen BlocQuebecois=.
replace BlocQuebecois=1 if partyid==4
gen Alliance=.
replace Alliance=1 if partyid==5
gen ProgressiveC=.
replace ProgressiveC=1 if partyid==6
gen Green=.
replace Green=1 if partyid==8
gen Other=.
replace Other=1 if partyid==97
gen None=.
replace None=1 if partyid==0
gen DontKnow=.
replace DontKnow=1 if partyid==98
gen Refused=.
replace Refused=1 if partyid==99

tab cps_q3
tab cps_q4


gen ClsrLiberal=.
replace ClsrLiberal=1 if cps_q4==1
gen ClsrConservative=.
replace ClsrConservative=1 if cps_q4==2
gen ClsrNDP=.
replace ClsrNDP=1 if cps_q4==3
gen ClsrBlocQuebecois=.
replace ClsrBlocQ=1 if cps_q4==4
gen ClsrAlliance=.
replace ClsrAlli=1 if cps_q4==5
gen ClsrProgressiveC=.
replace ClsrProgressiveC=1 if cps_q4==6
gen ClsrGreen=.
replace ClsrGreen=1 if cps_q4==8
gen ClsrOther=.
replace ClsrOther=1 if cps_q4==97
gen ClsrNone=.
replace ClsrNone=1 if cps_q4==0 | cps_q3==5
gen ClsrDontKnow=.
replace ClsrDontKnow=1 if cps_q4==98 | cps_q3==8
gen ClsrRefused=.
replace ClsrRefused=1 if cps_q4==99 | cps_q3==9


***************************************************************************************
*  Step 4: Creating Partisan variables (ID or clsr) for Liberal, Conservative, NDP, and others
***************************************************************************************
gen LibPart=.
replace LibPart=1 if  Liberal==1 & (cps_q2<8 & cps_q2!=.) 
label var LibPart "identifies/leans to the Liberals"
label define L3 1 "Liberal partisan"
label values LibPart L3
tab LibPart

gen ConPart=.
replace ConPart=1 if  Conservative==1 & (cps_q2<8 & cps_q2!=.) 
label var ConPart "identifies/leans to Conservative"
label define L2 1 "Conservative partisan"
label values ConPart L2
tab ConPart

gen NDPPart=.
replace NDPPart=1 if  NDP==1 & (cps_q2<8 & cps_q2!=.) 
label var NDPPart "identifies/leans to NDP"
label define L24 1 "NDP partisan"
label values NDPPart L24
tab NDPPart

gen BlocQPart=.
replace BlocQPar=1 if BlocQuebecois==1 & (cps_q2<8 & cps_q2!=.) 
label var BlocQPar "identifies/leans to Bloc Quebecois"
label define queb 1 "Bloc Quebecois partisan"
label values BlocQPar queb
tab BlocQPar

gen AlliancePart=.
replace AlliancePart=1 if Alliance==1 & (cps_q2<8 & cps_q2!=.) 

gen ProgCPart=.
replace ProgCPart=1 if ProgressiveC==1 & (cps_q2<8 & cps_q2!=.) 

gen GreenPart=.
replace GreenPart=1 if Green==1 & (cps_q2<8 & cps_q2!=.) 

gen OtherPart=.
replace OtherPart=1 if  Other==1 & (cps_q2<8 & cps_q2!=.) 
label var OtherPart "identifies/leans to other"
label define L27 1 "other partisan"
label values OtherPart L27
tab OtherPart

gen AllOthersPart=.
replace AllOthersPart=1 if (BlocQuebecois==1 | Alliance==1 | ProgressiveC==1 | Green==1 | Other==1) & (cps_q2<8 & cps_q2!=.) 
label var AllOthersPart "identifies/leans to another party"
label define L4 1 "all other partisans"
label values AllOthersPart L4
tab AllOthersPart


***************************************************************************
* Step 5: Recoding ID strength
***************************************************************************
tab cps_q2
*to see how strength is coded

gen idstr=cps_q2
recode idstr (1=3) (3=2) (5=1) (8=.)
label define idstr2 1 "not very strongly" 2 "fairly strongly" 3 "very strongly" 
label values idstr idstr2
tab cps_q2 idstr
*this is a check to see that the recoding is correct


****************************************************************************
*Step 6: Creating Subgroup Variables
****************************************************************************
*religion
tab cps_s9
gen religion=cps_s9
*5 is Ukranian Catholic
recode religion (0=4) (1=2) (4/5=1) (6/8=3) (9/10=2) (11=3) (12/14=2) (15=3) (16/20=2) (97=3) (98/99=.)
label define rel1 1 "Catholic" 2 "Other Christian" 3 "Non-Christian"  4 "Non-Religious"
label values religion rel1
label var religion "religion"

*region
gen region=province
recode region (10/13=1) (24=2) (35=3) (46/59=4)
label var region "region"
label define reg1 1 "Maritimes" 2 "Quebec" 3 "Ontario" 4 "Western Canada"
label values region reg1
label var region "region"

*union
tab cps_s6a
tab cps_s6b
gen union=.
replace union=2 if cps_s6a==5 | cps_s6b==5
replace union=1 if cps_s6a==1 | cps_s6b==1
label define unlab 1 "union" 2 "non-union"
label values union unlab
label var union "union"

*ethnicity
tab cps_s14
gen ethnicity=cps_s14
recode ethnicity (3=1) (7=1) (9/13=1) (16/19=1) (22/25=1) (37=1) (40/44=1) (47/48=1) (50=1) (53=1) (55/56=1) (58=1) (70=1) (94=1) (96=1) (4/6=2) (8=2) (14/15=2) (20/21=2) (26/34=2) (38/39=2) (45=2) (49=2) (51/52=2) (54=2) (57=2) (59/64=2) (95=2) (98/99=.)
label define etn 1 "European descent" 2 "Non-European descent"
label values ethnicity etn
label var ethnicity "ethnicity"

*partisan
gen partisan=.
replace partisan=1 if LibPart==1
replace partisan=2 if ConPart==1
replace partisan=3 if NDPPart==1
replace partisan=4 if AllOthersPart==1
label define labelp 1 "Liberal Partisan" 2 "Conservative Partisan" 3 "NDP Partisan" 4 "Other-Party Partisan"
label values partisan labelp
tab partisan
label var partisan "partisan"

*type(urban/rural)
*2004
tab areacode, m
gen type=2
replace type=1 if areacode==450 | areacode==514 | areacode==416 | areacode==250 | areacode==604
label define labtyp 1 "urban" 2 "not urban"
label values type labtyp
label var type "type"
	//Montreal = 450, 514
	//Toronto = 416
	//Vancouver = 250, 604

*RegionXReligion
gen regxrel=.
replace regxrel=1 if region==2 & religion==1 //Quebec & Catholic
replace regxrel=2 if region==2 & religion==2 //Quebec & non-Cath Christ.
replace regxrel=3 if (region==1 | region==3 | region==4) & religion==1 //non-Queb & Catholic
replace regxrel=4 if (region==1 | region==3 | region==4) & religion==2 //non-Queb & non-Cath Christ.

label define pop 1 "Quebec & Catholic" 2 "Quebec & non-Cath Christ"  /*
*/ 3 "non-Quebec & Catholic" 4 "non-Quebec & non-Cath Christ"
label values regxrel pop

*RegionXUnion
gen regxun=.
replace regxun=1 if region==2 & union==1 //Queb & union
replace regxun=2 if region==2 & union==2 //Queb & non-union
replace regxun=3 if (region==1 | region==3 | region==4) & union==1 //non-Q & union
replace regxun=4 if (region==1 | region==3 | region==4) & union==2 //non-Q & non-union

label define ypy 1 "Quebec & union" 2 "Quebec & non-union" /*
*/ 3 "non-Quebec & union" 4 "non-Quebec & non-union"
label values regxun ypy

****************************************************************************
*Step 7: Save, Collapse, Save
****************************************************************************
save "AUGUST\2004\2004 edited id.dta"
collapse year (count) observ=countv (sum) Liberal Conservative NDP BlocQuebecois Alliance ProgressiveC Green Other None DontKnow Refused Clsr* [pweight=cesnwgt] 
save "AUGUST\2004\2004 total id.dta"
clear



***********************************************************************
***********************************************************************
***********************************************************************
*2004 Party ID, religion
*set directory
cd "M:\Kollman Party Project IFS\Canada"
use "AUGUST\2004\2004 edited id.dta"

count if religion==.
drop if religion==.

sort religion
quietly: by religion: sum idstr

collapse year (count)observ=countv (sum) Liberal Conservative NDP BlocQuebecois Alliance ProgressiveC Green Other None DontKnow Refused Clsr* [pweight=cesnwgt], by(religion)
gen sub_n="religion"

decode religion, gen(group)
replace group="_1cath" in 1
replace group="_2chr" in 2
replace group="_3other" in 3
replace group="_4nrel" in 4

order year sub_n religion group

drop religion
quietly: reshape wide observ Liberal Conservative NDP BlocQuebecois Alliance ProgressiveC Green Other None DontKnow Refused Clsr*, i(year sub_n) j(group) string
save "AUGUST\2004\2004 religion id.dta"
clear




***********************************************************************
*2004 Party ID, region
*set directory
cd "M:\Kollman Party Project IFS\Canada"
use "AUGUST\2004\2004 edited id.dta"

count if region==.
drop if region==.

sort region
quietly: by region: sum idstr

collapse year (count)observ=countv (sum) Liberal Conservative NDP BlocQuebecois Alliance ProgressiveC Green Other None DontKnow Refused Clsr* [pweight=cesnwgt], by(region)
gen sub_n="region"

decode region, gen(group)
replace group="_1Marit" in 1
replace group="_2Queb" in 2
replace group="_3Ontar" in 3
replace group="_4West" in 4

order year sub_n region group

drop region
quietly: reshape wide observ Liberal Conservative NDP BlocQuebecois Alliance ProgressiveC Green Other None DontKnow Refused Clsr*, i(year sub_n) j(group) string
save "AUGUST\2004\2004 region id.dta"
clear



***********************************************************************
*2004 Party ID, union
*set directory
cd "M:\Kollman Party Project IFS\Canada"
use "AUGUST\2004\2004 edited id.dta"

count if union==.
drop if union==.

sort union
quietly: by union: sum idstr

collapse year (count)observ=countv (sum) Liberal Conservative NDP BlocQuebecois Alliance ProgressiveC Green Other None DontKnow Refused Clsr* [pweight=cesnwgt], by(union)
gen sub_n="union"

decode union, gen(group)
replace group="_1union" in 1
replace group="_2nunion" in 2

order year sub_n union group

drop union
quietly: reshape wide observ Liberal Conservative NDP BlocQuebecois Alliance ProgressiveC Green Other None DontKnow Refused Clsr*, i(year sub_n) j(group) string
save "AUGUST\2004\2004 union id.dta"
clear



***********************************************************************
*2004 Party ID, ethnicity
*set directory
cd "M:\Kollman Party Project IFS\Canada"
use "AUGUST\2004\2004 edited id.dta"

count if ethnicity==.
drop if ethnicity==.

sort ethnicity
quietly: by ethnicity: sum idstr

collapse year (count)observ=countv (sum) Liberal Conservative NDP BlocQuebecois Alliance ProgressiveC Green Other None DontKnow Refused Clsr* [pweight=cesnwgt], by(ethnicity)
gen sub_n="ethnicity"

decode ethnicity, gen(group)
replace group="_1Euro" in 1
replace group="_2nEuro" in 2

order year sub_n ethnicity group

drop ethnicity
quietly: reshape wide observ Liberal Conservative NDP BlocQuebecois Alliance ProgressiveC Green Other None DontKnow Refused Clsr*, i(year sub_n) j(group) string
save "AUGUST\2004\2004 ethnicity id.dta"
clear


***********************************************************************
*2004 Party ID, partisan
*set directory
cd "M:\Kollman Party Project IFS\Canada"
use "AUGUST\2004\2004 edited id.dta"

count if partisan==.
drop if partisan==.

sort partisan
quietly: by partisan: sum idstr

collapse year (count)observ=countv (sum) Liberal Conservative NDP BlocQuebecois Alliance ProgressiveC Green Other None DontKnow Refused Clsr* [pweight=cesnwgt], by(partisan)
gen sub_n="partisan"

decode partisan, gen(group)
replace group="_1LibPar" in 1
replace group="_2ConPar" in 2
replace group="_3NDPPar" in 3
replace group="_4OtherPar" in 4

order year sub_n partisan group

drop partisan
quietly: reshape wide observ Liberal Conservative NDP BlocQuebecois Alliance ProgressiveC Green Other None DontKnow Refused Clsr*, i(year sub_n) j(group) string
save "AUGUST\2004\2004 partisan id.dta"
clear






***********************************************************************
*2004 Party ID, type
*set directory
cd "M:\Kollman Party Project IFS\Canada"
use "AUGUST\2004\2004 edited id.dta"

count if type==.
drop if type==.

sort type
quietly: by type: sum idstr

collapse year (count)observ=countv (sum) Liberal Conservative NDP BlocQuebecois Alliance ProgressiveC Green Other None DontKnow Refused Clsr* [pweight=cesnwgt], by(type)
gen sub_n="type"

decode type, gen(group)
replace group="_1urban" in 1
replace group="_2nurban" in 2

order year sub_n type group

drop type
quietly: reshape wide observ Liberal Conservative NDP BlocQuebecois Alliance ProgressiveC Green Other None DontKnow Refused Clsr*, i(year sub_n) j(group) string
save "AUGUST\2004\2004 type id.dta"
clear



***********************************************************************
*2004 Party ID, regxrel
*set directory
cd "M:\Kollman Party Project IFS\Canada"
use "AUGUST\2004\2004 edited id.dta"

count if regxrel==.
drop if regxrel==.

sort regxrel
quietly: by regxrel: sum idstr

collapse year (count)observ=countv (sum) Liberal Conservative NDP BlocQuebecois Alliance ProgressiveC Green Other None DontKnow Refused Clsr* [pweight=cesnwgt], by(regxrel)
gen sub_n="regxrel"

decode regxrel, gen(group)
replace group="_1QbCat" in 1
replace group="_2QbChr" in 2
replace group="_3NQbCat" in 3
replace group="_4NQbChr" in 4

order year sub_n regxrel group

drop regxrel
quietly: reshape wide observ Liberal Conservative NDP BlocQuebecois Alliance ProgressiveC Green Other None DontKnow Refused Clsr*, i(year sub_n) j(group) string
save "AUGUST\2004\2004 regxrel id.dta"
clear


***********************************************************************
*2004 Party ID, regxun
*set directory
cd "M:\Kollman Party Project IFS\Canada"
use "AUGUST\2004\2004 edited id.dta"

count if regxun==.
drop if regxun==.

sort regxun
quietly: by regxun: sum idstr

collapse year (count)observ=countv (sum) Liberal Conservative NDP BlocQuebecois Alliance ProgressiveC Green Other None DontKnow Refused Clsr* [pweight=cesnwgt], by(regxun)
gen sub_n="regxun"

decode regxun, gen(group)
replace group="_1QbU" in 1
replace group="_2QbNonU" in 2
replace group="_3NQbU" in 3
replace group="_4NQbNonU" in 4

order year sub_n regxun group

drop regxun
quietly: reshape wide observ Liberal Conservative NDP BlocQuebecois Alliance ProgressiveC Green Other None DontKnow Refused Clsr*, i(year sub_n) j(group) string
save "AUGUST\2004\2004 regxun id.dta"
clear
