*2011 Party ID
*set directory
cd "M:\Kollman Party Project IFS\Canada"
use "2011\CES 2011 Stata.dta"

***************************************************************************
* Step 1: Condensing the dataset, variable description
***************************************************************************
keep CES11_IDNUM CPS11_71 CPS11_72 MBS11_K5 MBS11_K6a MBS11_K6b MBS11_K6c CPS11_80 PROVINCE CPS11_85 PES11_93 PES11_94 REGION11 WGTPOP
numlabel, add

*CES11_IDNUM = participant id
*CPS11_71= party ID
*CPS11_72 = strength
*MBS11_K5 = self-placement
*MBS11_K6a =  Conservative placement
*MBS11_K6b = Liberal placement
*MBS11_K6c = NDP placement
*CPS11_80 = religion 
*PROVINCE = region
*CPS11_85 = ethnicity
*PES11_93, PES11_94 = union
*REGION11 = type (urban/rural)
*WGTPOP = weight

gen weight=WGTPOP/10000

***************************************************************************
* Step 2: Creating year variable
***************************************************************************
gen year=2011


***************************************************************************
*  Step 3: Creating party id variables
***************************************************************************
gen partyid=CPS11_71

gen countv=partyid
recode countv (0/9=1)

tab CPS11_71, m

gen Liberal=.
replace Liberal=1 if partyid==1
gen Conservative=. 
replace Conservative=1 if partyid==2
gen NDP=.
replace NDP=1 if partyid==3
gen BlocQuebecois=.
replace BlocQuebecois=1 if partyid==4
gen Green=.
replace Green=1 if partyid==5
gen Other=.
replace Other=1 if partyid==0
gen None=.
replace None=1 if partyid==6
gen DontKnow=.
replace DontKnow=1 if partyid==8
gen Refused=.
replace Refused=1 if partyid==9


***************************************************************************************
*  Step 4: Creating Partisan variables (ID or clsr) for Liberal, Conservative,  NDP, and others
***************************************************************************************
gen LibPart=.
replace LibPart=1 if  Liberal==1 & (CPS11_72<8 & CPS11_72!=.)
label var LibPart "identifies/leans to the Liberals"
label define L3 1 "Liberal partisan"
label values LibPart L3
tab LibPart

gen ConPart=.
replace ConPart=1 if  Conservative==1 & (CPS11_72<8 & CPS11_72!=.)
label var ConPart "identifies/leans to Conservative"
label define L2 1 "Conservative partisan"
label values ConPart L2
tab ConPart

gen NDPPart=.
replace NDPPart=1 if  NDP==1 & (CPS11_72<8 & CPS11_72!=.)
label var NDPPart "identifies/leans to NDP"
label define L24 1 "NDP partisan"
label values NDPPart L24
tab NDPPart

gen BlocQPar=.
replace BlocQPar=1 if BlocQuebecois==1 & (CPS11_72<8 & CPS11_72!=.)
label var BlocQPar "identifies/leans to Bloc Quebecois"
label define queb 1 "Bloc Quebecois partisan"
label values BlocQPar queb
tab BlocQPar

gen GreenPart=.
replace GreenPart=1 if  Green==1 & (CPS11_72<8 & CPS11_72!=.)
label var GreenPart "identifies/leans to Green"
label define L6 1 "Green partisan"
label values GreenPart L6
tab GreenPart

gen OtherPart=.
replace OtherPart=1 if  Other==1 & (CPS11_72<8 & CPS11_72!=.)
label var OtherPart "identifies/leans to other"
label define L27 1 "other partisan"
label values OtherPart L27
tab OtherPart

gen AllOthersPart=.
replace AllOthersPart=1 if (BlocQuebecois==1 | Green==1| Other==1) & (CPS11_72<8 & CPS11_72!=.)
label var AllOthersPart "identifies/leans to another party"
label define L4 1 "all other partisans"
label values AllOthersPart L4
tab AllOthersPart


***************************************************************************
* Step 5: Recoding ID strength
***************************************************************************
tab CPS11_72
*to see how strength is coded

gen idstr=CPS11_72
recode idstr (1=3) (3=2) (5=1) (8/9=.)
label define idstr2 1 "not very strongly" 2 "fairly strongly" 3 "very strongly" 
label values idstr idstr2
tab CPS11_72 idstr
*this is a check to see that the recoding is correct


****************************************************************************
*Step 6: Creating group variables
****************************************************************************
*religion
tab CPS11_80
gen religion=CPS11_80
*5 is Ukranian Catholic
recode religion (0=4) (1/2=2) (4/5=1) (6/8=3) (9/10=2) (11=3) (12/20=2) (97=3) (98/99=.)
label define rel1 1 "Catholic" 2 "Other Christian" 3 "Non-Christian"  4 "Non-Religious"
label values religion rel1
label var religion "religion"

*region
tab PROVINCE11
gen region=PROVINCE11
recode region (10/13=1) (24=2) (35=3) (46/59=4)
label var region "region"
label define reg1 1 "Maritimes" 2 "Quebec" 3 "Ontario" 4 "Western Canada"
label values region reg1
label var region "region"

*union
tab PES11_93
tab PES11_94
gen union=.
replace union=2 if PES11_93==5 | PES11_94==5
replace union=1 if PES11_93==1 | PES11_94==1
label define unlab 1 "union" 2 "non-union"
label values union unlab
label var union "union"

*ethnicity
gen ethnicity=CPS11_85
recode ethnicity (3=1) (7=1) (9/19=1) (22/25=1) (37=1) (40/44=1) (47/48=1) (50=1) (53/56=1) (58=1) (70=1) (94=1) (96=1) (5/6=2) (8=2) (20/21=2) (26/32=2) (38/39=2) (45=2) (49=2) (51=2) (57=2) (59/66=2) (95=2) (98/99=.)
label define etn 1 "European descent" 2 "Non-European descent"
label values ethnicity etn
label var ethnicity "ethnicity"

*partisan
gen partisan=.
replace partisan=1 if LibPart==1
replace partisan=2 if ConPart==1
replace partisan=3 if NDPPart==1
replace partisan=4 if AllOthersPart==1
label define labelp 1 "Liberal Partisan" 2 "Conservative Partisan" 3 "NDP Partisan" 4 "Other-Party Partisan"
label values partisan labelp
label var partisan "partisan"

*type (urban/rural)
tab REG, m
gen type=2
replace type=1 if REG==24 | REG==37 | REG==59
label define labtyp 1 "urban" 2 "not urban"
label values type labtyp
label var type "type"

*RegionXReligion
gen regxrel=.
replace regxrel=1 if region==2 & religion==1 //Quebec & Catholic
replace regxrel=2 if region==2 & religion==2 //Quebec & non-Cath Christ.
replace regxrel=3 if (region==1 | region==3 | region==4) & religion==1 //non-Queb & Catholic
replace regxrel=4 if (region==1 | region==3 | region==4) & religion==2 //non-Queb & non-Cath Christ.

label define pop 1 "Quebec & Catholic" 2 "Quebec & non-Cath Christ"  /*
*/ 3 "non-Quebec & Catholic" 4 "non-Quebec & non-Cath Christ"
label values regxrel pop

*RegionXUnion
gen regxun=.
replace regxun=1 if region==2 & union==1 //Queb & union
replace regxun=2 if region==2 & union==2 //Queb & non-union
replace regxun=3 if (region==1 | region==3 | region==4) & union==1 //non-Q & union
replace regxun=4 if (region==1 | region==3 | region==4) & union==2 //non-Q & non-union

label define ypy 1 "Quebec & union" 2 "Quebec & non-union" /*
*/ 3 "non-Quebec & union" 4 "non-Quebec & non-union"
label values regxun ypy


****************************************************************************
*Step 7: Save, Collapse, Save
****************************************************************************
save "AUGUST\2011\2011 edited id.dta"
collapse year (count) observ=countv (sum) Liberal Conservative NDP BlocQuebecois Green Other None DontKnow Refused *Part [pweight=weight]
save "AUGUST\2011\2011 total id.dta"
clear




***********************************************************************
***********************************************************************
***********************************************************************
*2011 Party ID, religion
*set directory
cd "M:\Kollman Party Project IFS\Canada"
use "AUGUST\2011\2011 edited id.dta"

count if religion==.
drop if religion==.

sort religion
quietly: by religion: sum idstr

collapse year (count)observ=countv (sum) Liberal Conservative NDP BlocQuebecois Green Other None DontKnow Refused [pweight=weight], by(religion)
gen sub_n="religion"

decode religion, gen(group)
replace group="_1cath" in 1
replace group="_2chr" in 2
replace group="_3other" in 3
replace group="_4nrel" in 4

order year sub_n religion group

drop religion
quietly: reshape wide observ Liberal Conservative NDP BlocQuebecois Green Other None DontKnow Refused, i(year sub_n) j(group) string
save "AUGUST\2011\2011 religion id.dta"
clear



***********************************************************************
*2011 Party ID, region
*set directory
cd "M:\Kollman Party Project IFS\Canada"
use "AUGUST\2011\2011 edited id.dta"

count if region==.
drop if region==.

sort region
quietly: by region: sum idstr

collapse year (count) observ=countv (sum) Liberal Conservative NDP BlocQuebecois Green Other None DontKnow Refused [pweight=weight], by(region)
gen sub_n="region"

decode region, gen(group)
replace group="_1Marit" in 1
replace group="_2Queb" in 2
replace group="_3Ontar" in 3
replace group="_4West" in 4

order year sub_n region group

drop region
quietly: reshape wide observ Liberal Conservative NDP BlocQuebecois Green Other None DontKnow Refused, i(year sub_n) j(group) string
save "AUGUST\2011\2011 region id.dta"
clear




***********************************************************************
*2011 Party ID, union
*set directory
cd "M:\Kollman Party Project IFS\Canada"
use "AUGUST\2011\2011 edited id.dta"

count if union==.
drop if union==.

sort union
quietly: by union: sum idstr

collapse year (count) observ=countv (sum) Liberal Conservative NDP BlocQuebecois Green Other None DontKnow Refused [pweight=weight], by(union)
gen sub_n="union"

decode union, gen(group)
replace group="_1union" in 1
replace group="_2nunion" in 2

order year sub_n union group

drop union
quietly: reshape wide observ Liberal Conservative NDP BlocQuebecois Green Other None DontKnow Refused, i(year sub_n) j(group) string
save "AUGUST\2011\2011 union id.dta"
clear


***********************************************************************
*2011 Party ID, ethnicity
*set directory
cd "M:\Kollman Party Project IFS\Canada"
use "AUGUST\2011\2011 edited id.dta"

count if ethnicity==.
drop if ethnicity==.

sort ethnicity
quietly: by ethnicity: sum idstr

collapse year (count) observ=countv (sum) Liberal Conservative NDP BlocQuebecois Green Other None DontKnow Refused [pweight=weight], by(ethnicity)
gen sub_n="ethnicity"

decode ethnicity, gen(group)
replace group="_1Euro" in 1
replace group="_2nEuro" in 2

order year sub_n ethnicity group

drop ethnicity
quietly: reshape wide observ Liberal Conservative NDP BlocQuebecois Green Other None DontKnow Refused, i(year sub_n) j(group) string
save "AUGUST\2011\2011 ethnicity id.dta"
clear


***********************************************************************
*2011 Party ID, partisan
*set directory
cd "M:\Kollman Party Project IFS\Canada"
use "AUGUST\2011\2011 edited id.dta"

count if partisan==.
drop if partisan==.

sort partisan
quietly: by partisan: sum idstr

collapse year (count) observ=countv (sum) Liberal Conservative NDP BlocQuebecois Green Other None DontKnow Refused [pweight=weight], by(partisan)
gen sub_n="partisan"

decode partisan, gen(group)
replace group="_1LibPar" in 1
replace group="_2ConPar" in 2
replace group="_3NDPPar" in 3
replace group="_4OtherPar" in 4

order year sub_n partisan group

drop partisan
quietly: reshape wide observ Liberal Conservative NDP BlocQuebecois Green Other None DontKnow Refused, i(year sub_n) j(group) string
save "AUGUST\2011\2011 partisan id.dta"
clear




***********************************************************************
*2011 Party ID, region
*set directory
cd "M:\Kollman Party Project IFS\Canada"
use "AUGUST\2011\2011 edited id.dta"

count if type==.
drop if type==.

sort type
quietly: by type: sum idstr

collapse year (count) observ=countv (sum) Liberal Conservative NDP BlocQuebecois Green Other None DontKnow Refused [pweight=weight], by(type)
gen sub_n="type"

decode type, gen(group)
replace group="_1urban" in 1
replace group="_2nurban" in 2

order year sub_n type group

drop type
quietly: reshape wide observ Liberal Conservative NDP BlocQuebecois Green Other None DontKnow Refused, i(year sub_n) j(group) string
save "AUGUST\2011\2011 type id.dta"
clear





***********************************************************************
*2011 Party ID, regxrel
*set directory
cd "M:\Kollman Party Project IFS\Canada"
use "AUGUST\2011\2011 edited id.dta"

count if regxrel==.
drop if regxrel==.

sort regxrel
quietly: by regxrel: sum idstr

collapse year (count) observ=countv (sum) Liberal Conservative NDP BlocQuebecois Green Other None DontKnow Refused [pweight=weight], by(regxrel)
gen sub_n="regxrel"

decode regxrel, gen(group)
replace group="_1QbCat" in 1
replace group="_2QbChr" in 2
replace group="_3NQbCat" in 3
replace group="_4NQbChr" in 4

order year sub_n regxrel group

drop regxrel
quietly: reshape wide observ Liberal Conservative NDP BlocQuebecois Green Other None DontKnow Refused, i(year sub_n) j(group) string
save "AUGUST\2011\2011 regxrel id.dta"
clear




***********************************************************************
*2011 Party ID, regxun
*set directory
cd "M:\Kollman Party Project IFS\Canada"
use "AUGUST\2011\2011 edited id.dta"

count if regxun==.
drop if regxun==.

sort regxun
quietly: by regxun: sum idstr

collapse year (count) observ=countv (sum) Liberal Conservative NDP BlocQuebecois Green Other None DontKnow Refused [pweight=weight], by(regxun)
gen sub_n="regxun"

decode regxun, gen(group)
replace group="_1QbU" in 1
replace group="_2QbNonU" in 2
replace group="_3NQbU" in 3
replace group="_4NQbNonU" in 4

order year sub_n regxun group

drop regxun
quietly: reshape wide observ Liberal Conservative NDP BlocQuebecois Green Other None DontKnow Refused, i(year sub_n) j(group) string
save "AUGUST\2011\2011 regxun id.dta"
clear

